# generated by datamodel-codegen:
#   filename:  instill_task_keypoint_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import List


@dataclass
class BoundingBox:
    height: float
    left: float
    top: float
    width: float


@dataclass
class Keypoints:
    v: float
    x: float
    y: float


@dataclass
class Object:
    bounding_box: BoundingBox
    keypoints: List[Keypoints]
    score: float


@dataclass
class Model:
    objects: List[Object]
