# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vdp/pipeline/v1beta/pipeline.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.healthcheck.v1beta import healthcheck_pb2 as common_dot_healthcheck_dot_v1beta_dot_healthcheck__pb2
from core.mgmt.v1beta import mgmt_pb2 as core_dot_mgmt_dot_v1beta_dot_mgmt__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.longrunning import operations_pb2 as google_dot_longrunning_dot_operations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from vdp.pipeline.v1beta import common_pb2 as vdp_dot_pipeline_dot_v1beta_dot_common__pb2
from vdp.pipeline.v1beta import connector_pb2 as vdp_dot_pipeline_dot_v1beta_dot_connector__pb2
from vdp.pipeline.v1beta import connector_definition_pb2 as vdp_dot_pipeline_dot_v1beta_dot_connector__definition__pb2
from vdp.pipeline.v1beta import operator_definition_pb2 as vdp_dot_pipeline_dot_v1beta_dot_operator__definition__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"vdp/pipeline/v1beta/pipeline.proto\x12\x13vdp.pipeline.v1beta\x1a+common/healthcheck/v1beta/healthcheck.proto\x1a\x1b\x63ore/mgmt/v1beta/mgmt.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a#google/longrunning/operations.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a vdp/pipeline/v1beta/common.proto\x1a#vdp/pipeline/v1beta/connector.proto\x1a.vdp/pipeline/v1beta/connector_definition.proto\x1a-vdp/pipeline/v1beta/operator_definition.proto\"\x96\x01\n\x0fLivenessRequest\x12j\n\x14health_check_request\x18\x01 \x01(\x0b\x32-.common.healthcheck.v1beta.HealthCheckRequestB\x04\xe2\x41\x01\x01H\x00R\x12healthCheckRequest\x88\x01\x01\x42\x17\n\x15_health_check_request\"v\n\x10LivenessResponse\x12\x62\n\x15health_check_response\x18\x01 \x01(\x0b\x32..common.healthcheck.v1beta.HealthCheckResponseR\x13healthCheckResponse\"\x97\x01\n\x10ReadinessRequest\x12j\n\x14health_check_request\x18\x01 \x01(\x0b\x32-.common.healthcheck.v1beta.HealthCheckRequestB\x04\xe2\x41\x01\x01H\x00R\x12healthCheckRequest\x88\x01\x01\x42\x17\n\x15_health_check_request\"w\n\x11ReadinessResponse\x12\x62\n\x15health_check_response\x18\x01 \x01(\x0b\x32..common.healthcheck.v1beta.HealthCheckResponseR\x13healthCheckResponse\"\x97\x04\n\tComponent\x12\x14\n\x02id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x02id\x12+\n\rresource_name\x18\x02 \x01(\tB\x06\xfa\x41\x03\n\x01*R\x0cresourceName\x12@\n\x08resource\x18\x03 \x01(\x0b\x32\x1e.vdp.pipeline.v1beta.ConnectorB\x04\xe2\x41\x01\x03R\x08resource\x12=\n\rconfiguration\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructR\rconfiguration\x12<\n\x04type\x18\x06 \x01(\x0e\x32\".vdp.pipeline.v1beta.ComponentTypeB\x04\xe2\x41\x01\x03R\x04type\x12\x33\n\x0f\x64\x65\x66inition_name\x18\x07 \x01(\tB\n\xe2\x41\x01\x02\xfa\x41\x03\n\x01*R\x0e\x64\x65\x66initionName\x12`\n\x13operator_definition\x18\x08 \x01(\x0b\x32\'.vdp.pipeline.v1beta.OperatorDefinitionB\x04\xe2\x41\x01\x03H\x00R\x12operatorDefinition\x12\x63\n\x14\x63onnector_definition\x18\t \x01(\x0b\x32(.vdp.pipeline.v1beta.ConnectorDefinitionB\x04\xe2\x41\x01\x03H\x00R\x13\x63onnectorDefinitionB\x0c\n\ndefinition\"b\n\x06Recipe\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12>\n\ncomponents\x18\x02 \x03(\x0b\x32\x1e.vdp.pipeline.v1beta.ComponentR\ncomponents\"\xd3\t\n\x08Pipeline\x12.\n\x04name\x18\x01 \x01(\tB\x1a\x92\x41\x13\xca>\x10\xfa\x02\rpipeline_name\xe2\x41\x01\x03R\x04name\x12\x16\n\x03uid\x18\x02 \x01(\tB\x04\xe2\x41\x01\x03R\x03uid\x12\x14\n\x02id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x05R\x02id\x12+\n\x0b\x64\x65scription\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01H\x00R\x0b\x64\x65scription\x88\x01\x01\x12\x39\n\x06recipe\x18\x05 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.RecipeB\x04\xe2\x41\x01\x05R\x06recipe\x12\x41\n\x0b\x63reate_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12\x41\n\x0bupdate_time\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\nupdateTime\x12\x44\n\x0eopenapi_schema\x18\r \x01(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x03R\ropenapiSchema\x12\x41\n\x0b\x64\x65lete_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ndeleteTime\x12\x36\n\x07sharing\x18\x0f \x01(\x0b\x32\x1c.vdp.pipeline.v1beta.SharingR\x07sharing\x12\x33\n\x08metadata\x18\x10 \x01(\x0b\x32\x17.google.protobuf.StructR\x08metadata\x12#\n\nowner_name\x18\x11 \x01(\tB\x04\xe2\x41\x01\x03R\townerName\x12\x46\n\x08releases\x18\x13 \x03(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseB\x04\xe2\x41\x01\x03R\x08releases\x12\x1c\n\x06readme\x18\x14 \x01(\tB\x04\xe2\x41\x01\x01R\x06readme\x12\x45\n\npermission\x18\x15 \x01(\x0b\x32\x1f.vdp.pipeline.v1beta.PermissionB\x04\xe2\x41\x01\x03R\npermission\x12N\n\nvisibility\x18\x16 \x01(\x0e\x32(.vdp.pipeline.v1beta.Pipeline.VisibilityB\x04\xe2\x41\x01\x03R\nvisibility\x12\x39\n\x05owner\x18\x17 \x01(\x0b\x32\x17.core.mgmt.v1beta.OwnerB\x05\xe2\x41\x02\x01\x03H\x01R\x05owner\x88\x01\x01\"L\n\x04View\x12\x14\n\x10VIEW_UNSPECIFIED\x10\x00\x12\x0e\n\nVIEW_BASIC\x10\x01\x12\r\n\tVIEW_FULL\x10\x02\x12\x0f\n\x0bVIEW_RECIPE\x10\x03\"W\n\nVisibility\x12\x1a\n\x16VISIBILITY_UNSPECIFIED\x10\x00\x12\x16\n\x12VISIBILITY_PRIVATE\x10\x01\x12\x15\n\x11VISIBILITY_PUBLIC\x10\x02:a\xea\x41^\n\x19\x61pi.instill.tech/Pipeline\x12\'users/{user.id}/pipelines/{pipeline.id}\x12\x18pipelines/{pipeline.uid}B\x0e\n\x0c_descriptionB\x08\n\x06_ownerJ\x04\x08\x12\x10\x13\"\xb2\x01\n\x0fTriggerMetadata\x12H\n\x06traces\x18\x01 \x03(\x0b\x32\x30.vdp.pipeline.v1beta.TriggerMetadata.TracesEntryR\x06traces\x1aU\n\x0bTracesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.vdp.pipeline.v1beta.TraceR\x05value:\x02\x38\x01\"\xee\x02\n\x05Trace\x12=\n\x08statuses\x18\x01 \x03(\x0e\x32!.vdp.pipeline.v1beta.Trace.StatusR\x08statuses\x12/\n\x06inputs\x18\x02 \x03(\x0b\x32\x17.google.protobuf.StructR\x06inputs\x12\x31\n\x07outputs\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructR\x07outputs\x12-\n\x05\x65rror\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructR\x05\x65rror\x12\x35\n\x17\x63ompute_time_in_seconds\x18\x05 \x01(\x02R\x14\x63omputeTimeInSeconds\"\\\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x14\n\x10STATUS_COMPLETED\x10\x01\x12\x12\n\x0eSTATUS_SKIPPED\x10\x02\x12\x10\n\x0cSTATUS_ERROR\x10\x03\"\xcb\x05\n\x0fPipelineRelease\x12\x36\n\x04name\x18\x01 \x01(\tB\"\x92\x41\x1b\xca>\x18\xfa\x02\x15pipeline_release_name\xe2\x41\x01\x03R\x04name\x12\x16\n\x03uid\x18\x02 \x01(\tB\x04\xe2\x41\x01\x03R\x03uid\x12\x14\n\x02id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x05R\x02id\x12+\n\x0b\x64\x65scription\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01H\x00R\x0b\x64\x65scription\x88\x01\x01\x12\x39\n\x06recipe\x18\x05 \x01(\x0b\x32\x1b.vdp.pipeline.v1beta.RecipeB\x04\xe2\x41\x01\x03R\x06recipe\x12\x41\n\x0b\x63reate_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12\x41\n\x0bupdate_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\nupdateTime\x12\x44\n\x0eopenapi_schema\x18\t \x01(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x03R\ropenapiSchema\x12\x41\n\x0b\x64\x65lete_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ndeleteTime\x12\x1a\n\x05\x61lias\x18\x0b \x01(\tB\x04\xe2\x41\x01\x03R\x05\x61lias\x12\x33\n\x08metadata\x18\x0c \x01(\x0b\x32\x17.google.protobuf.StructR\x08metadata\x12\x1c\n\x06readme\x18\r \x01(\tB\x04\xe2\x41\x01\x01R\x06readme:\\\xea\x41Y\n\x18\x61pi.instill.tech/Release\x12=users/{user.id}/pipelines/{pipeline.id}/releases/{release.id}B\x0e\n\x0c_description\"\xa2\x03\n\x14ListPipelinesRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12\x41\n\x04view\x18\x03 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x04\xe2\x41\x01\x01H\x02R\x04view\x88\x01\x01\x12!\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01H\x03R\x06\x66ilter\x88\x01\x01\x12,\n\x0cshow_deleted\x18\x05 \x01(\x08\x42\x04\xe2\x41\x01\x01H\x04R\x0bshowDeleted\x88\x01\x01\x12S\n\nvisibility\x18\x06 \x01(\x0e\x32(.vdp.pipeline.v1beta.Pipeline.VisibilityB\x04\xe2\x41\x01\x01H\x05R\nvisibility\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filterB\x0f\n\r_show_deletedB\r\n\x0b_visibility\"\x9b\x01\n\x15ListPipelinesResponse\x12;\n\tpipelines\x18\x01 \x03(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\tpipelines\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\x87\x01\n\x15LookUpPipelineRequest\x12\"\n\tpermalink\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\tpermalink\x12\x41\n\x04view\x18\x02 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"S\n\x16LookUpPipelineResponse\x12\x39\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\"\xa4\x01\n\x19\x43reateUserPipelineRequest\x12\x39\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\x12L\n\x06parent\x18\x02 \x01(\tB4\x92\x41\x0f\xca>\x0c\xfa\x02\tuser_name\xe2\x41\x01\x02\xfa\x41\x1b\x12\x19\x61pi.instill.tech/PipelineR\x06parent\"W\n\x1a\x43reateUserPipelineResponse\x12\x39\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\"\xf4\x03\n\x18ListUserPipelinesRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12\x41\n\x04view\x18\x03 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x04\xe2\x41\x01\x01H\x02R\x04view\x88\x01\x01\x12!\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01H\x03R\x06\x66ilter\x88\x01\x01\x12L\n\x06parent\x18\x05 \x01(\tB4\x92\x41\x0f\xca>\x0c\xfa\x02\tuser_name\xe2\x41\x01\x02\xfa\x41\x1b\x12\x19\x61pi.instill.tech/PipelineR\x06parent\x12,\n\x0cshow_deleted\x18\x06 \x01(\x08\x42\x04\xe2\x41\x01\x01H\x04R\x0bshowDeleted\x88\x01\x01\x12S\n\nvisibility\x18\x07 \x01(\x0e\x32(.vdp.pipeline.v1beta.Pipeline.VisibilityB\x04\xe2\x41\x01\x01H\x05R\nvisibility\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filterB\x0f\n\r_show_deletedB\r\n\x0b_visibility\"\x9f\x01\n\x19ListUserPipelinesResponse\x12;\n\tpipelines\x18\x01 \x03(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\tpipelines\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\xb7\x01\n\x16GetUserPipelineRequest\x12Q\n\x04name\x18\x01 \x01(\tB=\x92\x41\x18\xca>\x15\xfa\x02\x12user_pipeline_name\xe2\x41\x01\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\x12\x41\n\x04view\x18\x02 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"T\n\x17GetUserPipelineResponse\x12\x39\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\"\x9f\x01\n\x19UpdateUserPipelineRequest\x12?\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineB\x04\xe2\x41\x01\x02R\x08pipeline\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x02R\nupdateMask\"W\n\x1aUpdateUserPipelineResponse\x12\x39\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\"n\n\x19\x44\x65leteUserPipelineRequest\x12Q\n\x04name\x18\x01 \x01(\tB=\x92\x41\x18\xca>\x15\xfa\x02\x12user_pipeline_name\xe2\x41\x01\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\"\x1c\n\x1a\x44\x65leteUserPipelineResponse\"p\n\x1bValidateUserPipelineRequest\x12Q\n\x04name\x18\x01 \x01(\tB=\x92\x41\x18\xca>\x15\xfa\x02\x12user_pipeline_name\xe2\x41\x01\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\"Y\n\x1cValidateUserPipelineResponse\x12\x39\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\"\x9c\x01\n\x19RenameUserPipelineRequest\x12Q\n\x04name\x18\x01 \x01(\tB=\x92\x41\x18\xca>\x15\xfa\x02\x12user_pipeline_name\xe2\x41\x01\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\x12,\n\x0fnew_pipeline_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\rnewPipelineId\"W\n\x1aRenameUserPipelineResponse\x12\x39\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\"\x8b\x01\n\x18\x43loneUserPipelineRequest\x12Q\n\x04name\x18\x01 \x01(\tB=\x92\x41\x18\xca>\x15\xfa\x02\x12user_pipeline_name\xe2\x41\x01\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\x12\x1c\n\x06target\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x06target\"V\n\x19\x43loneUserPipelineResponse\x12\x39\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\"\xa6\x01\n\x1aTriggerUserPipelineRequest\x12Q\n\x04name\x18\x01 \x01(\tB=\x92\x41\x18\xca>\x15\xfa\x02\x12user_pipeline_name\xe2\x41\x01\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\x12\x35\n\x06inputs\x18\x02 \x03(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x02R\x06inputs\"\x92\x01\n\x1bTriggerUserPipelineResponse\x12\x31\n\x07outputs\x18\x01 \x03(\x0b\x32\x17.google.protobuf.StructR\x07outputs\x12@\n\x08metadata\x18\x02 \x01(\x0b\x32$.vdp.pipeline.v1beta.TriggerMetadataR\x08metadata\"\xab\x01\n\x1fTriggerAsyncUserPipelineRequest\x12Q\n\x04name\x18\x01 \x01(\tB=\x92\x41\x18\xca>\x15\xfa\x02\x12user_pipeline_name\xe2\x41\x01\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\x12\x35\n\x06inputs\x18\x02 \x03(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x02R\x06inputs\"e\n TriggerAsyncUserPipelineResponse\x12\x41\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x04\xe2\x41\x01\x03R\toperation\"\xb7\x01\n CreateUserPipelineReleaseRequest\x12>\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x07release\x12S\n\x06parent\x18\x02 \x01(\tB;\x92\x41\x0f\xca>\x0c\xfa\x02\tuser_name\xe2\x41\x01\x02\xfa\x41\"\x12 api.instill.tech/PipelineReleaseR\x06parent\"c\n!CreateUserPipelineReleaseResponse\x12>\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x07release\"\x9e\x03\n\x1fListUserPipelineReleasesRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12\x41\n\x04view\x18\x03 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x04\xe2\x41\x01\x01H\x02R\x04view\x88\x01\x01\x12!\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01H\x03R\x06\x66ilter\x88\x01\x01\x12S\n\x06parent\x18\x05 \x01(\tB;\x92\x41\x0f\xca>\x0c\xfa\x02\tuser_name\xe2\x41\x01\x02\xfa\x41\"\x12 api.instill.tech/PipelineReleaseR\x06parent\x12,\n\x0cshow_deleted\x18\x06 \x01(\x08\x42\x04\xe2\x41\x01\x01H\x04R\x0bshowDeleted\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filterB\x0f\n\r_show_deleted\"\xab\x01\n ListUserPipelineReleasesResponse\x12@\n\x08releases\x18\x01 \x03(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x08releases\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\xcd\x01\n\x1dGetUserPipelineReleaseRequest\x12`\n\x04name\x18\x01 \x01(\tBL\x92\x41 \xca>\x1d\xfa\x02\x1auser_pipeline_release_name\xe2\x41\x01\x02\xfa\x41\"\n api.instill.tech/PipelineReleaseR\x04name\x12\x41\n\x04view\x18\x02 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"`\n\x1eGetUserPipelineReleaseResponse\x12>\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x07release\"\xab\x01\n UpdateUserPipelineReleaseRequest\x12\x44\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseB\x04\xe2\x41\x01\x02R\x07release\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x02R\nupdateMask\"c\n!UpdateUserPipelineReleaseResponse\x12>\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x07release\"\x84\x01\n DeleteUserPipelineReleaseRequest\x12`\n\x04name\x18\x01 \x01(\tBL\x92\x41 \xca>\x1d\xfa\x02\x1auser_pipeline_release_name\xe2\x41\x01\x02\xfa\x41\"\n api.instill.tech/PipelineReleaseR\x04name\"#\n!DeleteUserPipelineReleaseResponse\"\x85\x01\n!RestoreUserPipelineReleaseRequest\x12`\n\x04name\x18\x01 \x01(\tBL\x92\x41 \xca>\x1d\xfa\x02\x1auser_pipeline_release_name\xe2\x41\x01\x02\xfa\x41\"\n api.instill.tech/PipelineReleaseR\x04name\"d\n\"RestoreUserPipelineReleaseResponse\x12>\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x07release\"\xc1\x01\n RenameUserPipelineReleaseRequest\x12`\n\x04name\x18\x01 \x01(\tBL\x92\x41 \xca>\x1d\xfa\x02\x1auser_pipeline_release_name\xe2\x41\x01\x02\xfa\x41\"\n api.instill.tech/PipelineReleaseR\x04name\x12;\n\x17new_pipeline_release_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x14newPipelineReleaseId\"c\n!RenameUserPipelineReleaseResponse\x12>\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x07release\"\x83\x01\n\x1fWatchUserPipelineReleaseRequest\x12`\n\x04name\x18\x01 \x01(\tBL\x92\x41 \xca>\x1d\xfa\x02\x1auser_pipeline_release_name\xe2\x41\x01\x02\xfa\x41\"\n api.instill.tech/PipelineReleaseR\x04name\"T\n WatchUserPipelineReleaseResponse\x12\x30\n\x05state\x18\x01 \x01(\x0e\x32\x1a.vdp.pipeline.v1beta.StateR\x05state\"\xbc\x01\n!TriggerUserPipelineReleaseRequest\x12`\n\x04name\x18\x01 \x01(\tBL\x92\x41 \xca>\x1d\xfa\x02\x1auser_pipeline_release_name\xe2\x41\x01\x02\xfa\x41\"\n api.instill.tech/PipelineReleaseR\x04name\x12\x35\n\x06inputs\x18\x02 \x03(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x02R\x06inputs\"\x99\x01\n\"TriggerUserPipelineReleaseResponse\x12\x31\n\x07outputs\x18\x01 \x03(\x0b\x32\x17.google.protobuf.StructR\x07outputs\x12@\n\x08metadata\x18\x02 \x01(\x0b\x32$.vdp.pipeline.v1beta.TriggerMetadataR\x08metadata\"\xc1\x01\n&TriggerAsyncUserPipelineReleaseRequest\x12`\n\x04name\x18\x01 \x01(\tBL\x92\x41 \xca>\x1d\xfa\x02\x1auser_pipeline_release_name\xe2\x41\x01\x02\xfa\x41\"\n api.instill.tech/PipelineReleaseR\x04name\x12\x35\n\x06inputs\x18\x02 \x03(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x02R\x06inputs\"l\n\'TriggerAsyncUserPipelineReleaseResponse\x12\x41\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x04\xe2\x41\x01\x03R\toperation\"\xb4\x01\n!CreateOrganizationPipelineRequest\x12\x39\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\x12T\n\x06parent\x18\x02 \x01(\tB<\x92\x41\x17\xca>\x14\xfa\x02\x11organization_name\xe2\x41\x01\x02\xfa\x41\x1b\x12\x19\x61pi.instill.tech/PipelineR\x06parent\"_\n\"CreateOrganizationPipelineResponse\x12\x39\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\"\x84\x04\n ListOrganizationPipelinesRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12\x41\n\x04view\x18\x03 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x04\xe2\x41\x01\x01H\x02R\x04view\x88\x01\x01\x12!\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01H\x03R\x06\x66ilter\x88\x01\x01\x12T\n\x06parent\x18\x05 \x01(\tB<\x92\x41\x17\xca>\x14\xfa\x02\x11organization_name\xe2\x41\x01\x02\xfa\x41\x1b\x12\x19\x61pi.instill.tech/PipelineR\x06parent\x12,\n\x0cshow_deleted\x18\x06 \x01(\x08\x42\x04\xe2\x41\x01\x01H\x04R\x0bshowDeleted\x88\x01\x01\x12S\n\nvisibility\x18\x07 \x01(\x0e\x32(.vdp.pipeline.v1beta.Pipeline.VisibilityB\x04\xe2\x41\x01\x01H\x05R\nvisibility\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filterB\x0f\n\r_show_deletedB\r\n\x0b_visibility\"\xa7\x01\n!ListOrganizationPipelinesResponse\x12;\n\tpipelines\x18\x01 \x03(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\tpipelines\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\xc7\x01\n\x1eGetOrganizationPipelineRequest\x12Y\n\x04name\x18\x01 \x01(\tBE\x92\x41 \xca>\x1d\xfa\x02\x1aorganization_pipeline_name\xe2\x41\x01\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\x12\x41\n\x04view\x18\x02 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"\\\n\x1fGetOrganizationPipelineResponse\x12\x39\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\"\xa7\x01\n!UpdateOrganizationPipelineRequest\x12?\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineB\x04\xe2\x41\x01\x02R\x08pipeline\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x02R\nupdateMask\"_\n\"UpdateOrganizationPipelineResponse\x12\x39\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\"~\n!DeleteOrganizationPipelineRequest\x12Y\n\x04name\x18\x01 \x01(\tBE\x92\x41 \xca>\x1d\xfa\x02\x1aorganization_pipeline_name\xe2\x41\x01\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\"$\n\"DeleteOrganizationPipelineResponse\"\x80\x01\n#ValidateOrganizationPipelineRequest\x12Y\n\x04name\x18\x01 \x01(\tBE\x92\x41 \xca>\x1d\xfa\x02\x1aorganization_pipeline_name\xe2\x41\x01\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\"a\n$ValidateOrganizationPipelineResponse\x12\x39\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\"\xac\x01\n!RenameOrganizationPipelineRequest\x12Y\n\x04name\x18\x01 \x01(\tBE\x92\x41 \xca>\x1d\xfa\x02\x1aorganization_pipeline_name\xe2\x41\x01\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\x12,\n\x0fnew_pipeline_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\rnewPipelineId\"_\n\"RenameOrganizationPipelineResponse\x12\x39\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\"\x93\x01\n CloneOrganizationPipelineRequest\x12Q\n\x04name\x18\x01 \x01(\tB=\x92\x41\x18\xca>\x15\xfa\x02\x12user_pipeline_name\xe2\x41\x01\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\x12\x1c\n\x06target\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x06target\"^\n!CloneOrganizationPipelineResponse\x12\x39\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline\"\xb6\x01\n\"TriggerOrganizationPipelineRequest\x12Y\n\x04name\x18\x01 \x01(\tBE\x92\x41 \xca>\x1d\xfa\x02\x1aorganization_pipeline_name\xe2\x41\x01\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\x12\x35\n\x06inputs\x18\x02 \x03(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x02R\x06inputs\"\x9a\x01\n#TriggerOrganizationPipelineResponse\x12\x31\n\x07outputs\x18\x01 \x03(\x0b\x32\x17.google.protobuf.StructR\x07outputs\x12@\n\x08metadata\x18\x02 \x01(\x0b\x32$.vdp.pipeline.v1beta.TriggerMetadataR\x08metadata\"\xbb\x01\n\'TriggerAsyncOrganizationPipelineRequest\x12Y\n\x04name\x18\x01 \x01(\tBE\x92\x41 \xca>\x1d\xfa\x02\x1aorganization_pipeline_name\xe2\x41\x01\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\x04name\x12\x35\n\x06inputs\x18\x02 \x03(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x02R\x06inputs\"m\n(TriggerAsyncOrganizationPipelineResponse\x12\x41\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x04\xe2\x41\x01\x03R\toperation\"\xc7\x01\n(CreateOrganizationPipelineReleaseRequest\x12>\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x07release\x12[\n\x06parent\x18\x02 \x01(\tBC\x92\x41\x17\xca>\x14\xfa\x02\x11organization_name\xe2\x41\x01\x02\xfa\x41\"\x12 api.instill.tech/PipelineReleaseR\x06parent\"k\n)CreateOrganizationPipelineReleaseResponse\x12>\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x07release\"\xae\x03\n\'ListOrganizationPipelineReleasesRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12\x41\n\x04view\x18\x03 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x04\xe2\x41\x01\x01H\x02R\x04view\x88\x01\x01\x12!\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01H\x03R\x06\x66ilter\x88\x01\x01\x12[\n\x06parent\x18\x05 \x01(\tBC\x92\x41\x17\xca>\x14\xfa\x02\x11organization_name\xe2\x41\x01\x02\xfa\x41\"\x12 api.instill.tech/PipelineReleaseR\x06parent\x12,\n\x0cshow_deleted\x18\x06 \x01(\x08\x42\x04\xe2\x41\x01\x01H\x04R\x0bshowDeleted\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filterB\x0f\n\r_show_deleted\"\xb3\x01\n(ListOrganizationPipelineReleasesResponse\x12@\n\x08releases\x18\x01 \x03(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x08releases\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\xdd\x01\n%GetOrganizationPipelineReleaseRequest\x12h\n\x04name\x18\x01 \x01(\tBT\x92\x41(\xca>%\xfa\x02\"organization_pipeline_release_name\xe2\x41\x01\x02\xfa\x41\"\n api.instill.tech/PipelineReleaseR\x04name\x12\x41\n\x04view\x18\x02 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"h\n&GetOrganizationPipelineReleaseResponse\x12>\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x07release\"\xb3\x01\n(UpdateOrganizationPipelineReleaseRequest\x12\x44\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseB\x04\xe2\x41\x01\x02R\x07release\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x02R\nupdateMask\"k\n)UpdateOrganizationPipelineReleaseResponse\x12>\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x07release\"\x94\x01\n(DeleteOrganizationPipelineReleaseRequest\x12h\n\x04name\x18\x01 \x01(\tBT\x92\x41(\xca>%\xfa\x02\"organization_pipeline_release_name\xe2\x41\x01\x02\xfa\x41\"\n api.instill.tech/PipelineReleaseR\x04name\"+\n)DeleteOrganizationPipelineReleaseResponse\"\x95\x01\n)RestoreOrganizationPipelineReleaseRequest\x12h\n\x04name\x18\x01 \x01(\tBT\x92\x41(\xca>%\xfa\x02\"organization_pipeline_release_name\xe2\x41\x01\x02\xfa\x41\"\n api.instill.tech/PipelineReleaseR\x04name\"l\n*RestoreOrganizationPipelineReleaseResponse\x12>\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x07release\"\xd1\x01\n(RenameOrganizationPipelineReleaseRequest\x12h\n\x04name\x18\x01 \x01(\tBT\x92\x41(\xca>%\xfa\x02\"organization_pipeline_release_name\xe2\x41\x01\x02\xfa\x41\"\n api.instill.tech/PipelineReleaseR\x04name\x12;\n\x17new_pipeline_release_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x14newPipelineReleaseId\"k\n)RenameOrganizationPipelineReleaseResponse\x12>\n\x07release\x18\x01 \x01(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x07release\"\x93\x01\n\'WatchOrganizationPipelineReleaseRequest\x12h\n\x04name\x18\x01 \x01(\tBT\x92\x41(\xca>%\xfa\x02\"organization_pipeline_release_name\xe2\x41\x01\x02\xfa\x41\"\n api.instill.tech/PipelineReleaseR\x04name\"\\\n(WatchOrganizationPipelineReleaseResponse\x12\x30\n\x05state\x18\x01 \x01(\x0e\x32\x1a.vdp.pipeline.v1beta.StateR\x05state\"\xcc\x01\n)TriggerOrganizationPipelineReleaseRequest\x12h\n\x04name\x18\x01 \x01(\tBT\x92\x41(\xca>%\xfa\x02\"organization_pipeline_release_name\xe2\x41\x01\x02\xfa\x41\"\n api.instill.tech/PipelineReleaseR\x04name\x12\x35\n\x06inputs\x18\x02 \x03(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x02R\x06inputs\"\xa1\x01\n*TriggerOrganizationPipelineReleaseResponse\x12\x31\n\x07outputs\x18\x01 \x03(\x0b\x32\x17.google.protobuf.StructR\x07outputs\x12@\n\x08metadata\x18\x02 \x01(\x0b\x32$.vdp.pipeline.v1beta.TriggerMetadataR\x08metadata\"\xd1\x01\n.TriggerAsyncOrganizationPipelineReleaseRequest\x12h\n\x04name\x18\x01 \x01(\tBT\x92\x41(\xca>%\xfa\x02\"organization_pipeline_release_name\xe2\x41\x01\x02\xfa\x41\"\n api.instill.tech/PipelineReleaseR\x04name\x12\x35\n\x06inputs\x18\x02 \x03(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x02R\x06inputs\"t\n/TriggerAsyncOrganizationPipelineReleaseResponse\x12\x41\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x04\xe2\x41\x01\x03R\toperation\"/\n\x13GetOperationRequest\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x04name\"Y\n\x14GetOperationResponse\x12\x41\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x04\xe2\x41\x01\x03R\toperation\"\xc3\x02\n\x19ListPipelinesAdminRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12\x41\n\x04view\x18\x03 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x04\xe2\x41\x01\x01H\x02R\x04view\x88\x01\x01\x12!\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01H\x03R\x06\x66ilter\x88\x01\x01\x12,\n\x0cshow_deleted\x18\x05 \x01(\x08\x42\x04\xe2\x41\x01\x01H\x04R\x0bshowDeleted\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filterB\x0f\n\r_show_deleted\"\xa0\x01\n\x1aListPipelinesAdminResponse\x12;\n\tpipelines\x18\x01 \x03(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\tpipelines\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\xca\x02\n ListPipelineReleasesAdminRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12\x41\n\x04view\x18\x03 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x04\xe2\x41\x01\x01H\x02R\x04view\x88\x01\x01\x12!\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01H\x03R\x06\x66ilter\x88\x01\x01\x12,\n\x0cshow_deleted\x18\x05 \x01(\x08\x42\x04\xe2\x41\x01\x01H\x04R\x0bshowDeleted\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filterB\x0f\n\r_show_deleted\"\xac\x01\n!ListPipelineReleasesAdminResponse\x12@\n\x08releases\x18\x01 \x03(\x0b\x32$.vdp.pipeline.v1beta.PipelineReleaseR\x08releases\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\xc5\x01\n\x1aLookUpPipelineAdminRequest\x12[\n\tpermalink\x18\x01 \x01(\tB=\x92\x41\x18\xca>\x15\xfa\x02\x12pipeline_permalink\xe2\x41\x01\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/PipelineR\tpermalink\x12\x41\n\x04view\x18\x02 \x01(\x0e\x32\".vdp.pipeline.v1beta.Pipeline.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"X\n\x1bLookUpPipelineAdminResponse\x12\x39\n\x08pipeline\x18\x01 \x01(\x0b\x32\x1d.vdp.pipeline.v1beta.PipelineR\x08pipeline*\xb9\x01\n\rComponentType\x12\x1e\n\x1a\x43OMPONENT_TYPE_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x43OMPONENT_TYPE_CONNECTOR_AI\x10\x01\x12!\n\x1d\x43OMPONENT_TYPE_CONNECTOR_DATA\x10\x02\x12\'\n#COMPONENT_TYPE_CONNECTOR_BLOCKCHAIN\x10\x03\x12\x1b\n\x17\x43OMPONENT_TYPE_OPERATOR\x10\x04*U\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x12\n\x0eSTATE_INACTIVE\x10\x01\x12\x10\n\x0cSTATE_ACTIVE\x10\x02\x12\x0f\n\x0bSTATE_ERROR\x10\x03\x42\xdc\x01\n\x17\x63om.vdp.pipeline.v1betaB\rPipelineProtoP\x01ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\xa2\x02\x03VPX\xaa\x02\x13Vdp.Pipeline.V1beta\xca\x02\x13Vdp\\Pipeline\\V1beta\xe2\x02\x1fVdp\\Pipeline\\V1beta\\GPBMetadata\xea\x02\x15Vdp::Pipeline::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vdp.pipeline.v1beta.pipeline_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.vdp.pipeline.v1betaB\rPipelineProtoP\001ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\242\002\003VPX\252\002\023Vdp.Pipeline.V1beta\312\002\023Vdp\\Pipeline\\V1beta\342\002\037Vdp\\Pipeline\\V1beta\\GPBMetadata\352\002\025Vdp::Pipeline::V1beta'
  _LIVENESSREQUEST.fields_by_name['health_check_request']._options = None
  _LIVENESSREQUEST.fields_by_name['health_check_request']._serialized_options = b'\342A\001\001'
  _READINESSREQUEST.fields_by_name['health_check_request']._options = None
  _READINESSREQUEST.fields_by_name['health_check_request']._serialized_options = b'\342A\001\001'
  _COMPONENT.fields_by_name['id']._options = None
  _COMPONENT.fields_by_name['id']._serialized_options = b'\342A\001\002'
  _COMPONENT.fields_by_name['resource_name']._options = None
  _COMPONENT.fields_by_name['resource_name']._serialized_options = b'\372A\003\n\001*'
  _COMPONENT.fields_by_name['resource']._options = None
  _COMPONENT.fields_by_name['resource']._serialized_options = b'\342A\001\003'
  _COMPONENT.fields_by_name['type']._options = None
  _COMPONENT.fields_by_name['type']._serialized_options = b'\342A\001\003'
  _COMPONENT.fields_by_name['definition_name']._options = None
  _COMPONENT.fields_by_name['definition_name']._serialized_options = b'\342A\001\002\372A\003\n\001*'
  _COMPONENT.fields_by_name['operator_definition']._options = None
  _COMPONENT.fields_by_name['operator_definition']._serialized_options = b'\342A\001\003'
  _COMPONENT.fields_by_name['connector_definition']._options = None
  _COMPONENT.fields_by_name['connector_definition']._serialized_options = b'\342A\001\003'
  _PIPELINE.fields_by_name['name']._options = None
  _PIPELINE.fields_by_name['name']._serialized_options = b'\222A\023\312>\020\372\002\rpipeline_name\342A\001\003'
  _PIPELINE.fields_by_name['uid']._options = None
  _PIPELINE.fields_by_name['uid']._serialized_options = b'\342A\001\003'
  _PIPELINE.fields_by_name['id']._options = None
  _PIPELINE.fields_by_name['id']._serialized_options = b'\342A\001\005'
  _PIPELINE.fields_by_name['description']._options = None
  _PIPELINE.fields_by_name['description']._serialized_options = b'\342A\001\001'
  _PIPELINE.fields_by_name['recipe']._options = None
  _PIPELINE.fields_by_name['recipe']._serialized_options = b'\342A\001\005'
  _PIPELINE.fields_by_name['create_time']._options = None
  _PIPELINE.fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _PIPELINE.fields_by_name['update_time']._options = None
  _PIPELINE.fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _PIPELINE.fields_by_name['openapi_schema']._options = None
  _PIPELINE.fields_by_name['openapi_schema']._serialized_options = b'\342A\001\003'
  _PIPELINE.fields_by_name['delete_time']._options = None
  _PIPELINE.fields_by_name['delete_time']._serialized_options = b'\342A\001\003'
  _PIPELINE.fields_by_name['owner_name']._options = None
  _PIPELINE.fields_by_name['owner_name']._serialized_options = b'\342A\001\003'
  _PIPELINE.fields_by_name['releases']._options = None
  _PIPELINE.fields_by_name['releases']._serialized_options = b'\342A\001\003'
  _PIPELINE.fields_by_name['readme']._options = None
  _PIPELINE.fields_by_name['readme']._serialized_options = b'\342A\001\001'
  _PIPELINE.fields_by_name['permission']._options = None
  _PIPELINE.fields_by_name['permission']._serialized_options = b'\342A\001\003'
  _PIPELINE.fields_by_name['visibility']._options = None
  _PIPELINE.fields_by_name['visibility']._serialized_options = b'\342A\001\003'
  _PIPELINE.fields_by_name['owner']._options = None
  _PIPELINE.fields_by_name['owner']._serialized_options = b'\342A\002\001\003'
  _PIPELINE._options = None
  _PIPELINE._serialized_options = b'\352A^\n\031api.instill.tech/Pipeline\022\'users/{user.id}/pipelines/{pipeline.id}\022\030pipelines/{pipeline.uid}'
  _TRIGGERMETADATA_TRACESENTRY._options = None
  _TRIGGERMETADATA_TRACESENTRY._serialized_options = b'8\001'
  _PIPELINERELEASE.fields_by_name['name']._options = None
  _PIPELINERELEASE.fields_by_name['name']._serialized_options = b'\222A\033\312>\030\372\002\025pipeline_release_name\342A\001\003'
  _PIPELINERELEASE.fields_by_name['uid']._options = None
  _PIPELINERELEASE.fields_by_name['uid']._serialized_options = b'\342A\001\003'
  _PIPELINERELEASE.fields_by_name['id']._options = None
  _PIPELINERELEASE.fields_by_name['id']._serialized_options = b'\342A\001\005'
  _PIPELINERELEASE.fields_by_name['description']._options = None
  _PIPELINERELEASE.fields_by_name['description']._serialized_options = b'\342A\001\001'
  _PIPELINERELEASE.fields_by_name['recipe']._options = None
  _PIPELINERELEASE.fields_by_name['recipe']._serialized_options = b'\342A\001\003'
  _PIPELINERELEASE.fields_by_name['create_time']._options = None
  _PIPELINERELEASE.fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _PIPELINERELEASE.fields_by_name['update_time']._options = None
  _PIPELINERELEASE.fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _PIPELINERELEASE.fields_by_name['openapi_schema']._options = None
  _PIPELINERELEASE.fields_by_name['openapi_schema']._serialized_options = b'\342A\001\003'
  _PIPELINERELEASE.fields_by_name['delete_time']._options = None
  _PIPELINERELEASE.fields_by_name['delete_time']._serialized_options = b'\342A\001\003'
  _PIPELINERELEASE.fields_by_name['alias']._options = None
  _PIPELINERELEASE.fields_by_name['alias']._serialized_options = b'\342A\001\003'
  _PIPELINERELEASE.fields_by_name['readme']._options = None
  _PIPELINERELEASE.fields_by_name['readme']._serialized_options = b'\342A\001\001'
  _PIPELINERELEASE._options = None
  _PIPELINERELEASE._serialized_options = b'\352AY\n\030api.instill.tech/Release\022=users/{user.id}/pipelines/{pipeline.id}/releases/{release.id}'
  _LISTPIPELINESREQUEST.fields_by_name['page_size']._options = None
  _LISTPIPELINESREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTPIPELINESREQUEST.fields_by_name['page_token']._options = None
  _LISTPIPELINESREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTPIPELINESREQUEST.fields_by_name['view']._options = None
  _LISTPIPELINESREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTPIPELINESREQUEST.fields_by_name['filter']._options = None
  _LISTPIPELINESREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTPIPELINESREQUEST.fields_by_name['show_deleted']._options = None
  _LISTPIPELINESREQUEST.fields_by_name['show_deleted']._serialized_options = b'\342A\001\001'
  _LISTPIPELINESREQUEST.fields_by_name['visibility']._options = None
  _LISTPIPELINESREQUEST.fields_by_name['visibility']._serialized_options = b'\342A\001\001'
  _LOOKUPPIPELINEREQUEST.fields_by_name['permalink']._options = None
  _LOOKUPPIPELINEREQUEST.fields_by_name['permalink']._serialized_options = b'\342A\001\002'
  _LOOKUPPIPELINEREQUEST.fields_by_name['view']._options = None
  _LOOKUPPIPELINEREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _CREATEUSERPIPELINEREQUEST.fields_by_name['parent']._options = None
  _CREATEUSERPIPELINEREQUEST.fields_by_name['parent']._serialized_options = b'\222A\017\312>\014\372\002\tuser_name\342A\001\002\372A\033\022\031api.instill.tech/Pipeline'
  _LISTUSERPIPELINESREQUEST.fields_by_name['page_size']._options = None
  _LISTUSERPIPELINESREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTUSERPIPELINESREQUEST.fields_by_name['page_token']._options = None
  _LISTUSERPIPELINESREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTUSERPIPELINESREQUEST.fields_by_name['view']._options = None
  _LISTUSERPIPELINESREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTUSERPIPELINESREQUEST.fields_by_name['filter']._options = None
  _LISTUSERPIPELINESREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTUSERPIPELINESREQUEST.fields_by_name['parent']._options = None
  _LISTUSERPIPELINESREQUEST.fields_by_name['parent']._serialized_options = b'\222A\017\312>\014\372\002\tuser_name\342A\001\002\372A\033\022\031api.instill.tech/Pipeline'
  _LISTUSERPIPELINESREQUEST.fields_by_name['show_deleted']._options = None
  _LISTUSERPIPELINESREQUEST.fields_by_name['show_deleted']._serialized_options = b'\342A\001\001'
  _LISTUSERPIPELINESREQUEST.fields_by_name['visibility']._options = None
  _LISTUSERPIPELINESREQUEST.fields_by_name['visibility']._serialized_options = b'\342A\001\001'
  _GETUSERPIPELINEREQUEST.fields_by_name['name']._options = None
  _GETUSERPIPELINEREQUEST.fields_by_name['name']._serialized_options = b'\222A\030\312>\025\372\002\022user_pipeline_name\342A\001\002\372A\033\n\031api.instill.tech/Pipeline'
  _GETUSERPIPELINEREQUEST.fields_by_name['view']._options = None
  _GETUSERPIPELINEREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _UPDATEUSERPIPELINEREQUEST.fields_by_name['pipeline']._options = None
  _UPDATEUSERPIPELINEREQUEST.fields_by_name['pipeline']._serialized_options = b'\342A\001\002'
  _UPDATEUSERPIPELINEREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEUSERPIPELINEREQUEST.fields_by_name['update_mask']._serialized_options = b'\342A\001\002'
  _DELETEUSERPIPELINEREQUEST.fields_by_name['name']._options = None
  _DELETEUSERPIPELINEREQUEST.fields_by_name['name']._serialized_options = b'\222A\030\312>\025\372\002\022user_pipeline_name\342A\001\002\372A\033\n\031api.instill.tech/Pipeline'
  _VALIDATEUSERPIPELINEREQUEST.fields_by_name['name']._options = None
  _VALIDATEUSERPIPELINEREQUEST.fields_by_name['name']._serialized_options = b'\222A\030\312>\025\372\002\022user_pipeline_name\342A\001\002\372A\033\n\031api.instill.tech/Pipeline'
  _RENAMEUSERPIPELINEREQUEST.fields_by_name['name']._options = None
  _RENAMEUSERPIPELINEREQUEST.fields_by_name['name']._serialized_options = b'\222A\030\312>\025\372\002\022user_pipeline_name\342A\001\002\372A\033\n\031api.instill.tech/Pipeline'
  _RENAMEUSERPIPELINEREQUEST.fields_by_name['new_pipeline_id']._options = None
  _RENAMEUSERPIPELINEREQUEST.fields_by_name['new_pipeline_id']._serialized_options = b'\342A\001\002'
  _CLONEUSERPIPELINEREQUEST.fields_by_name['name']._options = None
  _CLONEUSERPIPELINEREQUEST.fields_by_name['name']._serialized_options = b'\222A\030\312>\025\372\002\022user_pipeline_name\342A\001\002\372A\033\n\031api.instill.tech/Pipeline'
  _CLONEUSERPIPELINEREQUEST.fields_by_name['target']._options = None
  _CLONEUSERPIPELINEREQUEST.fields_by_name['target']._serialized_options = b'\342A\001\002'
  _TRIGGERUSERPIPELINEREQUEST.fields_by_name['name']._options = None
  _TRIGGERUSERPIPELINEREQUEST.fields_by_name['name']._serialized_options = b'\222A\030\312>\025\372\002\022user_pipeline_name\342A\001\002\372A\033\n\031api.instill.tech/Pipeline'
  _TRIGGERUSERPIPELINEREQUEST.fields_by_name['inputs']._options = None
  _TRIGGERUSERPIPELINEREQUEST.fields_by_name['inputs']._serialized_options = b'\342A\001\002'
  _TRIGGERASYNCUSERPIPELINEREQUEST.fields_by_name['name']._options = None
  _TRIGGERASYNCUSERPIPELINEREQUEST.fields_by_name['name']._serialized_options = b'\222A\030\312>\025\372\002\022user_pipeline_name\342A\001\002\372A\033\n\031api.instill.tech/Pipeline'
  _TRIGGERASYNCUSERPIPELINEREQUEST.fields_by_name['inputs']._options = None
  _TRIGGERASYNCUSERPIPELINEREQUEST.fields_by_name['inputs']._serialized_options = b'\342A\001\002'
  _TRIGGERASYNCUSERPIPELINERESPONSE.fields_by_name['operation']._options = None
  _TRIGGERASYNCUSERPIPELINERESPONSE.fields_by_name['operation']._serialized_options = b'\342A\001\003'
  _CREATEUSERPIPELINERELEASEREQUEST.fields_by_name['parent']._options = None
  _CREATEUSERPIPELINERELEASEREQUEST.fields_by_name['parent']._serialized_options = b'\222A\017\312>\014\372\002\tuser_name\342A\001\002\372A\"\022 api.instill.tech/PipelineRelease'
  _LISTUSERPIPELINERELEASESREQUEST.fields_by_name['page_size']._options = None
  _LISTUSERPIPELINERELEASESREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTUSERPIPELINERELEASESREQUEST.fields_by_name['page_token']._options = None
  _LISTUSERPIPELINERELEASESREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTUSERPIPELINERELEASESREQUEST.fields_by_name['view']._options = None
  _LISTUSERPIPELINERELEASESREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTUSERPIPELINERELEASESREQUEST.fields_by_name['filter']._options = None
  _LISTUSERPIPELINERELEASESREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTUSERPIPELINERELEASESREQUEST.fields_by_name['parent']._options = None
  _LISTUSERPIPELINERELEASESREQUEST.fields_by_name['parent']._serialized_options = b'\222A\017\312>\014\372\002\tuser_name\342A\001\002\372A\"\022 api.instill.tech/PipelineRelease'
  _LISTUSERPIPELINERELEASESREQUEST.fields_by_name['show_deleted']._options = None
  _LISTUSERPIPELINERELEASESREQUEST.fields_by_name['show_deleted']._serialized_options = b'\342A\001\001'
  _GETUSERPIPELINERELEASEREQUEST.fields_by_name['name']._options = None
  _GETUSERPIPELINERELEASEREQUEST.fields_by_name['name']._serialized_options = b'\222A \312>\035\372\002\032user_pipeline_release_name\342A\001\002\372A\"\n api.instill.tech/PipelineRelease'
  _GETUSERPIPELINERELEASEREQUEST.fields_by_name['view']._options = None
  _GETUSERPIPELINERELEASEREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _UPDATEUSERPIPELINERELEASEREQUEST.fields_by_name['release']._options = None
  _UPDATEUSERPIPELINERELEASEREQUEST.fields_by_name['release']._serialized_options = b'\342A\001\002'
  _UPDATEUSERPIPELINERELEASEREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEUSERPIPELINERELEASEREQUEST.fields_by_name['update_mask']._serialized_options = b'\342A\001\002'
  _DELETEUSERPIPELINERELEASEREQUEST.fields_by_name['name']._options = None
  _DELETEUSERPIPELINERELEASEREQUEST.fields_by_name['name']._serialized_options = b'\222A \312>\035\372\002\032user_pipeline_release_name\342A\001\002\372A\"\n api.instill.tech/PipelineRelease'
  _RESTOREUSERPIPELINERELEASEREQUEST.fields_by_name['name']._options = None
  _RESTOREUSERPIPELINERELEASEREQUEST.fields_by_name['name']._serialized_options = b'\222A \312>\035\372\002\032user_pipeline_release_name\342A\001\002\372A\"\n api.instill.tech/PipelineRelease'
  _RENAMEUSERPIPELINERELEASEREQUEST.fields_by_name['name']._options = None
  _RENAMEUSERPIPELINERELEASEREQUEST.fields_by_name['name']._serialized_options = b'\222A \312>\035\372\002\032user_pipeline_release_name\342A\001\002\372A\"\n api.instill.tech/PipelineRelease'
  _RENAMEUSERPIPELINERELEASEREQUEST.fields_by_name['new_pipeline_release_id']._options = None
  _RENAMEUSERPIPELINERELEASEREQUEST.fields_by_name['new_pipeline_release_id']._serialized_options = b'\342A\001\002'
  _WATCHUSERPIPELINERELEASEREQUEST.fields_by_name['name']._options = None
  _WATCHUSERPIPELINERELEASEREQUEST.fields_by_name['name']._serialized_options = b'\222A \312>\035\372\002\032user_pipeline_release_name\342A\001\002\372A\"\n api.instill.tech/PipelineRelease'
  _TRIGGERUSERPIPELINERELEASEREQUEST.fields_by_name['name']._options = None
  _TRIGGERUSERPIPELINERELEASEREQUEST.fields_by_name['name']._serialized_options = b'\222A \312>\035\372\002\032user_pipeline_release_name\342A\001\002\372A\"\n api.instill.tech/PipelineRelease'
  _TRIGGERUSERPIPELINERELEASEREQUEST.fields_by_name['inputs']._options = None
  _TRIGGERUSERPIPELINERELEASEREQUEST.fields_by_name['inputs']._serialized_options = b'\342A\001\002'
  _TRIGGERASYNCUSERPIPELINERELEASEREQUEST.fields_by_name['name']._options = None
  _TRIGGERASYNCUSERPIPELINERELEASEREQUEST.fields_by_name['name']._serialized_options = b'\222A \312>\035\372\002\032user_pipeline_release_name\342A\001\002\372A\"\n api.instill.tech/PipelineRelease'
  _TRIGGERASYNCUSERPIPELINERELEASEREQUEST.fields_by_name['inputs']._options = None
  _TRIGGERASYNCUSERPIPELINERELEASEREQUEST.fields_by_name['inputs']._serialized_options = b'\342A\001\002'
  _TRIGGERASYNCUSERPIPELINERELEASERESPONSE.fields_by_name['operation']._options = None
  _TRIGGERASYNCUSERPIPELINERELEASERESPONSE.fields_by_name['operation']._serialized_options = b'\342A\001\003'
  _CREATEORGANIZATIONPIPELINEREQUEST.fields_by_name['parent']._options = None
  _CREATEORGANIZATIONPIPELINEREQUEST.fields_by_name['parent']._serialized_options = b'\222A\027\312>\024\372\002\021organization_name\342A\001\002\372A\033\022\031api.instill.tech/Pipeline'
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['page_size']._options = None
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['page_token']._options = None
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['view']._options = None
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['filter']._options = None
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['parent']._options = None
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['parent']._serialized_options = b'\222A\027\312>\024\372\002\021organization_name\342A\001\002\372A\033\022\031api.instill.tech/Pipeline'
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['show_deleted']._options = None
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['show_deleted']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['visibility']._options = None
  _LISTORGANIZATIONPIPELINESREQUEST.fields_by_name['visibility']._serialized_options = b'\342A\001\001'
  _GETORGANIZATIONPIPELINEREQUEST.fields_by_name['name']._options = None
  _GETORGANIZATIONPIPELINEREQUEST.fields_by_name['name']._serialized_options = b'\222A \312>\035\372\002\032organization_pipeline_name\342A\001\002\372A\033\n\031api.instill.tech/Pipeline'
  _GETORGANIZATIONPIPELINEREQUEST.fields_by_name['view']._options = None
  _GETORGANIZATIONPIPELINEREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _UPDATEORGANIZATIONPIPELINEREQUEST.fields_by_name['pipeline']._options = None
  _UPDATEORGANIZATIONPIPELINEREQUEST.fields_by_name['pipeline']._serialized_options = b'\342A\001\002'
  _UPDATEORGANIZATIONPIPELINEREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEORGANIZATIONPIPELINEREQUEST.fields_by_name['update_mask']._serialized_options = b'\342A\001\002'
  _DELETEORGANIZATIONPIPELINEREQUEST.fields_by_name['name']._options = None
  _DELETEORGANIZATIONPIPELINEREQUEST.fields_by_name['name']._serialized_options = b'\222A \312>\035\372\002\032organization_pipeline_name\342A\001\002\372A\033\n\031api.instill.tech/Pipeline'
  _VALIDATEORGANIZATIONPIPELINEREQUEST.fields_by_name['name']._options = None
  _VALIDATEORGANIZATIONPIPELINEREQUEST.fields_by_name['name']._serialized_options = b'\222A \312>\035\372\002\032organization_pipeline_name\342A\001\002\372A\033\n\031api.instill.tech/Pipeline'
  _RENAMEORGANIZATIONPIPELINEREQUEST.fields_by_name['name']._options = None
  _RENAMEORGANIZATIONPIPELINEREQUEST.fields_by_name['name']._serialized_options = b'\222A \312>\035\372\002\032organization_pipeline_name\342A\001\002\372A\033\n\031api.instill.tech/Pipeline'
  _RENAMEORGANIZATIONPIPELINEREQUEST.fields_by_name['new_pipeline_id']._options = None
  _RENAMEORGANIZATIONPIPELINEREQUEST.fields_by_name['new_pipeline_id']._serialized_options = b'\342A\001\002'
  _CLONEORGANIZATIONPIPELINEREQUEST.fields_by_name['name']._options = None
  _CLONEORGANIZATIONPIPELINEREQUEST.fields_by_name['name']._serialized_options = b'\222A\030\312>\025\372\002\022user_pipeline_name\342A\001\002\372A\033\n\031api.instill.tech/Pipeline'
  _CLONEORGANIZATIONPIPELINEREQUEST.fields_by_name['target']._options = None
  _CLONEORGANIZATIONPIPELINEREQUEST.fields_by_name['target']._serialized_options = b'\342A\001\002'
  _TRIGGERORGANIZATIONPIPELINEREQUEST.fields_by_name['name']._options = None
  _TRIGGERORGANIZATIONPIPELINEREQUEST.fields_by_name['name']._serialized_options = b'\222A \312>\035\372\002\032organization_pipeline_name\342A\001\002\372A\033\n\031api.instill.tech/Pipeline'
  _TRIGGERORGANIZATIONPIPELINEREQUEST.fields_by_name['inputs']._options = None
  _TRIGGERORGANIZATIONPIPELINEREQUEST.fields_by_name['inputs']._serialized_options = b'\342A\001\002'
  _TRIGGERASYNCORGANIZATIONPIPELINEREQUEST.fields_by_name['name']._options = None
  _TRIGGERASYNCORGANIZATIONPIPELINEREQUEST.fields_by_name['name']._serialized_options = b'\222A \312>\035\372\002\032organization_pipeline_name\342A\001\002\372A\033\n\031api.instill.tech/Pipeline'
  _TRIGGERASYNCORGANIZATIONPIPELINEREQUEST.fields_by_name['inputs']._options = None
  _TRIGGERASYNCORGANIZATIONPIPELINEREQUEST.fields_by_name['inputs']._serialized_options = b'\342A\001\002'
  _TRIGGERASYNCORGANIZATIONPIPELINERESPONSE.fields_by_name['operation']._options = None
  _TRIGGERASYNCORGANIZATIONPIPELINERESPONSE.fields_by_name['operation']._serialized_options = b'\342A\001\003'
  _CREATEORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['parent']._options = None
  _CREATEORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['parent']._serialized_options = b'\222A\027\312>\024\372\002\021organization_name\342A\001\002\372A\"\022 api.instill.tech/PipelineRelease'
  _LISTORGANIZATIONPIPELINERELEASESREQUEST.fields_by_name['page_size']._options = None
  _LISTORGANIZATIONPIPELINERELEASESREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONPIPELINERELEASESREQUEST.fields_by_name['page_token']._options = None
  _LISTORGANIZATIONPIPELINERELEASESREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONPIPELINERELEASESREQUEST.fields_by_name['view']._options = None
  _LISTORGANIZATIONPIPELINERELEASESREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONPIPELINERELEASESREQUEST.fields_by_name['filter']._options = None
  _LISTORGANIZATIONPIPELINERELEASESREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONPIPELINERELEASESREQUEST.fields_by_name['parent']._options = None
  _LISTORGANIZATIONPIPELINERELEASESREQUEST.fields_by_name['parent']._serialized_options = b'\222A\027\312>\024\372\002\021organization_name\342A\001\002\372A\"\022 api.instill.tech/PipelineRelease'
  _LISTORGANIZATIONPIPELINERELEASESREQUEST.fields_by_name['show_deleted']._options = None
  _LISTORGANIZATIONPIPELINERELEASESREQUEST.fields_by_name['show_deleted']._serialized_options = b'\342A\001\001'
  _GETORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['name']._options = None
  _GETORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['name']._serialized_options = b'\222A(\312>%\372\002\"organization_pipeline_release_name\342A\001\002\372A\"\n api.instill.tech/PipelineRelease'
  _GETORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['view']._options = None
  _GETORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _UPDATEORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['release']._options = None
  _UPDATEORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['release']._serialized_options = b'\342A\001\002'
  _UPDATEORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['update_mask']._serialized_options = b'\342A\001\002'
  _DELETEORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['name']._options = None
  _DELETEORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['name']._serialized_options = b'\222A(\312>%\372\002\"organization_pipeline_release_name\342A\001\002\372A\"\n api.instill.tech/PipelineRelease'
  _RESTOREORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['name']._options = None
  _RESTOREORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['name']._serialized_options = b'\222A(\312>%\372\002\"organization_pipeline_release_name\342A\001\002\372A\"\n api.instill.tech/PipelineRelease'
  _RENAMEORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['name']._options = None
  _RENAMEORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['name']._serialized_options = b'\222A(\312>%\372\002\"organization_pipeline_release_name\342A\001\002\372A\"\n api.instill.tech/PipelineRelease'
  _RENAMEORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['new_pipeline_release_id']._options = None
  _RENAMEORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['new_pipeline_release_id']._serialized_options = b'\342A\001\002'
  _WATCHORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['name']._options = None
  _WATCHORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['name']._serialized_options = b'\222A(\312>%\372\002\"organization_pipeline_release_name\342A\001\002\372A\"\n api.instill.tech/PipelineRelease'
  _TRIGGERORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['name']._options = None
  _TRIGGERORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['name']._serialized_options = b'\222A(\312>%\372\002\"organization_pipeline_release_name\342A\001\002\372A\"\n api.instill.tech/PipelineRelease'
  _TRIGGERORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['inputs']._options = None
  _TRIGGERORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['inputs']._serialized_options = b'\342A\001\002'
  _TRIGGERASYNCORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['name']._options = None
  _TRIGGERASYNCORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['name']._serialized_options = b'\222A(\312>%\372\002\"organization_pipeline_release_name\342A\001\002\372A\"\n api.instill.tech/PipelineRelease'
  _TRIGGERASYNCORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['inputs']._options = None
  _TRIGGERASYNCORGANIZATIONPIPELINERELEASEREQUEST.fields_by_name['inputs']._serialized_options = b'\342A\001\002'
  _TRIGGERASYNCORGANIZATIONPIPELINERELEASERESPONSE.fields_by_name['operation']._options = None
  _TRIGGERASYNCORGANIZATIONPIPELINERELEASERESPONSE.fields_by_name['operation']._serialized_options = b'\342A\001\003'
  _GETOPERATIONREQUEST.fields_by_name['name']._options = None
  _GETOPERATIONREQUEST.fields_by_name['name']._serialized_options = b'\342A\001\002'
  _GETOPERATIONRESPONSE.fields_by_name['operation']._options = None
  _GETOPERATIONRESPONSE.fields_by_name['operation']._serialized_options = b'\342A\001\003'
  _LISTPIPELINESADMINREQUEST.fields_by_name['page_size']._options = None
  _LISTPIPELINESADMINREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTPIPELINESADMINREQUEST.fields_by_name['page_token']._options = None
  _LISTPIPELINESADMINREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTPIPELINESADMINREQUEST.fields_by_name['view']._options = None
  _LISTPIPELINESADMINREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTPIPELINESADMINREQUEST.fields_by_name['filter']._options = None
  _LISTPIPELINESADMINREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTPIPELINESADMINREQUEST.fields_by_name['show_deleted']._options = None
  _LISTPIPELINESADMINREQUEST.fields_by_name['show_deleted']._serialized_options = b'\342A\001\001'
  _LISTPIPELINERELEASESADMINREQUEST.fields_by_name['page_size']._options = None
  _LISTPIPELINERELEASESADMINREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTPIPELINERELEASESADMINREQUEST.fields_by_name['page_token']._options = None
  _LISTPIPELINERELEASESADMINREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTPIPELINERELEASESADMINREQUEST.fields_by_name['view']._options = None
  _LISTPIPELINERELEASESADMINREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTPIPELINERELEASESADMINREQUEST.fields_by_name['filter']._options = None
  _LISTPIPELINERELEASESADMINREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTPIPELINERELEASESADMINREQUEST.fields_by_name['show_deleted']._options = None
  _LISTPIPELINERELEASESADMINREQUEST.fields_by_name['show_deleted']._serialized_options = b'\342A\001\001'
  _LOOKUPPIPELINEADMINREQUEST.fields_by_name['permalink']._options = None
  _LOOKUPPIPELINEADMINREQUEST.fields_by_name['permalink']._serialized_options = b'\222A\030\312>\025\372\002\022pipeline_permalink\342A\001\002\372A\033\n\031api.instill.tech/Pipeline'
  _LOOKUPPIPELINEADMINREQUEST.fields_by_name['view']._options = None
  _LOOKUPPIPELINEADMINREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _globals['_COMPONENTTYPE']._serialized_start=18726
  _globals['_COMPONENTTYPE']._serialized_end=18911
  _globals['_STATE']._serialized_start=18913
  _globals['_STATE']._serialized_end=18998
  _globals['_LIVENESSREQUEST']._serialized_start=542
  _globals['_LIVENESSREQUEST']._serialized_end=692
  _globals['_LIVENESSRESPONSE']._serialized_start=694
  _globals['_LIVENESSRESPONSE']._serialized_end=812
  _globals['_READINESSREQUEST']._serialized_start=815
  _globals['_READINESSREQUEST']._serialized_end=966
  _globals['_READINESSRESPONSE']._serialized_start=968
  _globals['_READINESSRESPONSE']._serialized_end=1087
  _globals['_COMPONENT']._serialized_start=1090
  _globals['_COMPONENT']._serialized_end=1625
  _globals['_RECIPE']._serialized_start=1627
  _globals['_RECIPE']._serialized_end=1725
  _globals['_PIPELINE']._serialized_start=1728
  _globals['_PIPELINE']._serialized_end=2963
  _globals['_PIPELINE_VIEW']._serialized_start=2667
  _globals['_PIPELINE_VIEW']._serialized_end=2743
  _globals['_PIPELINE_VISIBILITY']._serialized_start=2745
  _globals['_PIPELINE_VISIBILITY']._serialized_end=2832
  _globals['_TRIGGERMETADATA']._serialized_start=2966
  _globals['_TRIGGERMETADATA']._serialized_end=3144
  _globals['_TRIGGERMETADATA_TRACESENTRY']._serialized_start=3059
  _globals['_TRIGGERMETADATA_TRACESENTRY']._serialized_end=3144
  _globals['_TRACE']._serialized_start=3147
  _globals['_TRACE']._serialized_end=3513
  _globals['_TRACE_STATUS']._serialized_start=3421
  _globals['_TRACE_STATUS']._serialized_end=3513
  _globals['_PIPELINERELEASE']._serialized_start=3516
  _globals['_PIPELINERELEASE']._serialized_end=4231
  _globals['_LISTPIPELINESREQUEST']._serialized_start=4234
  _globals['_LISTPIPELINESREQUEST']._serialized_end=4652
  _globals['_LISTPIPELINESRESPONSE']._serialized_start=4655
  _globals['_LISTPIPELINESRESPONSE']._serialized_end=4810
  _globals['_LOOKUPPIPELINEREQUEST']._serialized_start=4813
  _globals['_LOOKUPPIPELINEREQUEST']._serialized_end=4948
  _globals['_LOOKUPPIPELINERESPONSE']._serialized_start=4950
  _globals['_LOOKUPPIPELINERESPONSE']._serialized_end=5033
  _globals['_CREATEUSERPIPELINEREQUEST']._serialized_start=5036
  _globals['_CREATEUSERPIPELINEREQUEST']._serialized_end=5200
  _globals['_CREATEUSERPIPELINERESPONSE']._serialized_start=5202
  _globals['_CREATEUSERPIPELINERESPONSE']._serialized_end=5289
  _globals['_LISTUSERPIPELINESREQUEST']._serialized_start=5292
  _globals['_LISTUSERPIPELINESREQUEST']._serialized_end=5792
  _globals['_LISTUSERPIPELINESRESPONSE']._serialized_start=5795
  _globals['_LISTUSERPIPELINESRESPONSE']._serialized_end=5954
  _globals['_GETUSERPIPELINEREQUEST']._serialized_start=5957
  _globals['_GETUSERPIPELINEREQUEST']._serialized_end=6140
  _globals['_GETUSERPIPELINERESPONSE']._serialized_start=6142
  _globals['_GETUSERPIPELINERESPONSE']._serialized_end=6226
  _globals['_UPDATEUSERPIPELINEREQUEST']._serialized_start=6229
  _globals['_UPDATEUSERPIPELINEREQUEST']._serialized_end=6388
  _globals['_UPDATEUSERPIPELINERESPONSE']._serialized_start=6390
  _globals['_UPDATEUSERPIPELINERESPONSE']._serialized_end=6477
  _globals['_DELETEUSERPIPELINEREQUEST']._serialized_start=6479
  _globals['_DELETEUSERPIPELINEREQUEST']._serialized_end=6589
  _globals['_DELETEUSERPIPELINERESPONSE']._serialized_start=6591
  _globals['_DELETEUSERPIPELINERESPONSE']._serialized_end=6619
  _globals['_VALIDATEUSERPIPELINEREQUEST']._serialized_start=6621
  _globals['_VALIDATEUSERPIPELINEREQUEST']._serialized_end=6733
  _globals['_VALIDATEUSERPIPELINERESPONSE']._serialized_start=6735
  _globals['_VALIDATEUSERPIPELINERESPONSE']._serialized_end=6824
  _globals['_RENAMEUSERPIPELINEREQUEST']._serialized_start=6827
  _globals['_RENAMEUSERPIPELINEREQUEST']._serialized_end=6983
  _globals['_RENAMEUSERPIPELINERESPONSE']._serialized_start=6985
  _globals['_RENAMEUSERPIPELINERESPONSE']._serialized_end=7072
  _globals['_CLONEUSERPIPELINEREQUEST']._serialized_start=7075
  _globals['_CLONEUSERPIPELINEREQUEST']._serialized_end=7214
  _globals['_CLONEUSERPIPELINERESPONSE']._serialized_start=7216
  _globals['_CLONEUSERPIPELINERESPONSE']._serialized_end=7302
  _globals['_TRIGGERUSERPIPELINEREQUEST']._serialized_start=7305
  _globals['_TRIGGERUSERPIPELINEREQUEST']._serialized_end=7471
  _globals['_TRIGGERUSERPIPELINERESPONSE']._serialized_start=7474
  _globals['_TRIGGERUSERPIPELINERESPONSE']._serialized_end=7620
  _globals['_TRIGGERASYNCUSERPIPELINEREQUEST']._serialized_start=7623
  _globals['_TRIGGERASYNCUSERPIPELINEREQUEST']._serialized_end=7794
  _globals['_TRIGGERASYNCUSERPIPELINERESPONSE']._serialized_start=7796
  _globals['_TRIGGERASYNCUSERPIPELINERESPONSE']._serialized_end=7897
  _globals['_CREATEUSERPIPELINERELEASEREQUEST']._serialized_start=7900
  _globals['_CREATEUSERPIPELINERELEASEREQUEST']._serialized_end=8083
  _globals['_CREATEUSERPIPELINERELEASERESPONSE']._serialized_start=8085
  _globals['_CREATEUSERPIPELINERELEASERESPONSE']._serialized_end=8184
  _globals['_LISTUSERPIPELINERELEASESREQUEST']._serialized_start=8187
  _globals['_LISTUSERPIPELINERELEASESREQUEST']._serialized_end=8601
  _globals['_LISTUSERPIPELINERELEASESRESPONSE']._serialized_start=8604
  _globals['_LISTUSERPIPELINERELEASESRESPONSE']._serialized_end=8775
  _globals['_GETUSERPIPELINERELEASEREQUEST']._serialized_start=8778
  _globals['_GETUSERPIPELINERELEASEREQUEST']._serialized_end=8983
  _globals['_GETUSERPIPELINERELEASERESPONSE']._serialized_start=8985
  _globals['_GETUSERPIPELINERELEASERESPONSE']._serialized_end=9081
  _globals['_UPDATEUSERPIPELINERELEASEREQUEST']._serialized_start=9084
  _globals['_UPDATEUSERPIPELINERELEASEREQUEST']._serialized_end=9255
  _globals['_UPDATEUSERPIPELINERELEASERESPONSE']._serialized_start=9257
  _globals['_UPDATEUSERPIPELINERELEASERESPONSE']._serialized_end=9356
  _globals['_DELETEUSERPIPELINERELEASEREQUEST']._serialized_start=9359
  _globals['_DELETEUSERPIPELINERELEASEREQUEST']._serialized_end=9491
  _globals['_DELETEUSERPIPELINERELEASERESPONSE']._serialized_start=9493
  _globals['_DELETEUSERPIPELINERELEASERESPONSE']._serialized_end=9528
  _globals['_RESTOREUSERPIPELINERELEASEREQUEST']._serialized_start=9531
  _globals['_RESTOREUSERPIPELINERELEASEREQUEST']._serialized_end=9664
  _globals['_RESTOREUSERPIPELINERELEASERESPONSE']._serialized_start=9666
  _globals['_RESTOREUSERPIPELINERELEASERESPONSE']._serialized_end=9766
  _globals['_RENAMEUSERPIPELINERELEASEREQUEST']._serialized_start=9769
  _globals['_RENAMEUSERPIPELINERELEASEREQUEST']._serialized_end=9962
  _globals['_RENAMEUSERPIPELINERELEASERESPONSE']._serialized_start=9964
  _globals['_RENAMEUSERPIPELINERELEASERESPONSE']._serialized_end=10063
  _globals['_WATCHUSERPIPELINERELEASEREQUEST']._serialized_start=10066
  _globals['_WATCHUSERPIPELINERELEASEREQUEST']._serialized_end=10197
  _globals['_WATCHUSERPIPELINERELEASERESPONSE']._serialized_start=10199
  _globals['_WATCHUSERPIPELINERELEASERESPONSE']._serialized_end=10283
  _globals['_TRIGGERUSERPIPELINERELEASEREQUEST']._serialized_start=10286
  _globals['_TRIGGERUSERPIPELINERELEASEREQUEST']._serialized_end=10474
  _globals['_TRIGGERUSERPIPELINERELEASERESPONSE']._serialized_start=10477
  _globals['_TRIGGERUSERPIPELINERELEASERESPONSE']._serialized_end=10630
  _globals['_TRIGGERASYNCUSERPIPELINERELEASEREQUEST']._serialized_start=10633
  _globals['_TRIGGERASYNCUSERPIPELINERELEASEREQUEST']._serialized_end=10826
  _globals['_TRIGGERASYNCUSERPIPELINERELEASERESPONSE']._serialized_start=10828
  _globals['_TRIGGERASYNCUSERPIPELINERELEASERESPONSE']._serialized_end=10936
  _globals['_CREATEORGANIZATIONPIPELINEREQUEST']._serialized_start=10939
  _globals['_CREATEORGANIZATIONPIPELINEREQUEST']._serialized_end=11119
  _globals['_CREATEORGANIZATIONPIPELINERESPONSE']._serialized_start=11121
  _globals['_CREATEORGANIZATIONPIPELINERESPONSE']._serialized_end=11216
  _globals['_LISTORGANIZATIONPIPELINESREQUEST']._serialized_start=11219
  _globals['_LISTORGANIZATIONPIPELINESREQUEST']._serialized_end=11735
  _globals['_LISTORGANIZATIONPIPELINESRESPONSE']._serialized_start=11738
  _globals['_LISTORGANIZATIONPIPELINESRESPONSE']._serialized_end=11905
  _globals['_GETORGANIZATIONPIPELINEREQUEST']._serialized_start=11908
  _globals['_GETORGANIZATIONPIPELINEREQUEST']._serialized_end=12107
  _globals['_GETORGANIZATIONPIPELINERESPONSE']._serialized_start=12109
  _globals['_GETORGANIZATIONPIPELINERESPONSE']._serialized_end=12201
  _globals['_UPDATEORGANIZATIONPIPELINEREQUEST']._serialized_start=12204
  _globals['_UPDATEORGANIZATIONPIPELINEREQUEST']._serialized_end=12371
  _globals['_UPDATEORGANIZATIONPIPELINERESPONSE']._serialized_start=12373
  _globals['_UPDATEORGANIZATIONPIPELINERESPONSE']._serialized_end=12468
  _globals['_DELETEORGANIZATIONPIPELINEREQUEST']._serialized_start=12470
  _globals['_DELETEORGANIZATIONPIPELINEREQUEST']._serialized_end=12596
  _globals['_DELETEORGANIZATIONPIPELINERESPONSE']._serialized_start=12598
  _globals['_DELETEORGANIZATIONPIPELINERESPONSE']._serialized_end=12634
  _globals['_VALIDATEORGANIZATIONPIPELINEREQUEST']._serialized_start=12637
  _globals['_VALIDATEORGANIZATIONPIPELINEREQUEST']._serialized_end=12765
  _globals['_VALIDATEORGANIZATIONPIPELINERESPONSE']._serialized_start=12767
  _globals['_VALIDATEORGANIZATIONPIPELINERESPONSE']._serialized_end=12864
  _globals['_RENAMEORGANIZATIONPIPELINEREQUEST']._serialized_start=12867
  _globals['_RENAMEORGANIZATIONPIPELINEREQUEST']._serialized_end=13039
  _globals['_RENAMEORGANIZATIONPIPELINERESPONSE']._serialized_start=13041
  _globals['_RENAMEORGANIZATIONPIPELINERESPONSE']._serialized_end=13136
  _globals['_CLONEORGANIZATIONPIPELINEREQUEST']._serialized_start=13139
  _globals['_CLONEORGANIZATIONPIPELINEREQUEST']._serialized_end=13286
  _globals['_CLONEORGANIZATIONPIPELINERESPONSE']._serialized_start=13288
  _globals['_CLONEORGANIZATIONPIPELINERESPONSE']._serialized_end=13382
  _globals['_TRIGGERORGANIZATIONPIPELINEREQUEST']._serialized_start=13385
  _globals['_TRIGGERORGANIZATIONPIPELINEREQUEST']._serialized_end=13567
  _globals['_TRIGGERORGANIZATIONPIPELINERESPONSE']._serialized_start=13570
  _globals['_TRIGGERORGANIZATIONPIPELINERESPONSE']._serialized_end=13724
  _globals['_TRIGGERASYNCORGANIZATIONPIPELINEREQUEST']._serialized_start=13727
  _globals['_TRIGGERASYNCORGANIZATIONPIPELINEREQUEST']._serialized_end=13914
  _globals['_TRIGGERASYNCORGANIZATIONPIPELINERESPONSE']._serialized_start=13916
  _globals['_TRIGGERASYNCORGANIZATIONPIPELINERESPONSE']._serialized_end=14025
  _globals['_CREATEORGANIZATIONPIPELINERELEASEREQUEST']._serialized_start=14028
  _globals['_CREATEORGANIZATIONPIPELINERELEASEREQUEST']._serialized_end=14227
  _globals['_CREATEORGANIZATIONPIPELINERELEASERESPONSE']._serialized_start=14229
  _globals['_CREATEORGANIZATIONPIPELINERELEASERESPONSE']._serialized_end=14336
  _globals['_LISTORGANIZATIONPIPELINERELEASESREQUEST']._serialized_start=14339
  _globals['_LISTORGANIZATIONPIPELINERELEASESREQUEST']._serialized_end=14769
  _globals['_LISTORGANIZATIONPIPELINERELEASESRESPONSE']._serialized_start=14772
  _globals['_LISTORGANIZATIONPIPELINERELEASESRESPONSE']._serialized_end=14951
  _globals['_GETORGANIZATIONPIPELINERELEASEREQUEST']._serialized_start=14954
  _globals['_GETORGANIZATIONPIPELINERELEASEREQUEST']._serialized_end=15175
  _globals['_GETORGANIZATIONPIPELINERELEASERESPONSE']._serialized_start=15177
  _globals['_GETORGANIZATIONPIPELINERELEASERESPONSE']._serialized_end=15281
  _globals['_UPDATEORGANIZATIONPIPELINERELEASEREQUEST']._serialized_start=15284
  _globals['_UPDATEORGANIZATIONPIPELINERELEASEREQUEST']._serialized_end=15463
  _globals['_UPDATEORGANIZATIONPIPELINERELEASERESPONSE']._serialized_start=15465
  _globals['_UPDATEORGANIZATIONPIPELINERELEASERESPONSE']._serialized_end=15572
  _globals['_DELETEORGANIZATIONPIPELINERELEASEREQUEST']._serialized_start=15575
  _globals['_DELETEORGANIZATIONPIPELINERELEASEREQUEST']._serialized_end=15723
  _globals['_DELETEORGANIZATIONPIPELINERELEASERESPONSE']._serialized_start=15725
  _globals['_DELETEORGANIZATIONPIPELINERELEASERESPONSE']._serialized_end=15768
  _globals['_RESTOREORGANIZATIONPIPELINERELEASEREQUEST']._serialized_start=15771
  _globals['_RESTOREORGANIZATIONPIPELINERELEASEREQUEST']._serialized_end=15920
  _globals['_RESTOREORGANIZATIONPIPELINERELEASERESPONSE']._serialized_start=15922
  _globals['_RESTOREORGANIZATIONPIPELINERELEASERESPONSE']._serialized_end=16030
  _globals['_RENAMEORGANIZATIONPIPELINERELEASEREQUEST']._serialized_start=16033
  _globals['_RENAMEORGANIZATIONPIPELINERELEASEREQUEST']._serialized_end=16242
  _globals['_RENAMEORGANIZATIONPIPELINERELEASERESPONSE']._serialized_start=16244
  _globals['_RENAMEORGANIZATIONPIPELINERELEASERESPONSE']._serialized_end=16351
  _globals['_WATCHORGANIZATIONPIPELINERELEASEREQUEST']._serialized_start=16354
  _globals['_WATCHORGANIZATIONPIPELINERELEASEREQUEST']._serialized_end=16501
  _globals['_WATCHORGANIZATIONPIPELINERELEASERESPONSE']._serialized_start=16503
  _globals['_WATCHORGANIZATIONPIPELINERELEASERESPONSE']._serialized_end=16595
  _globals['_TRIGGERORGANIZATIONPIPELINERELEASEREQUEST']._serialized_start=16598
  _globals['_TRIGGERORGANIZATIONPIPELINERELEASEREQUEST']._serialized_end=16802
  _globals['_TRIGGERORGANIZATIONPIPELINERELEASERESPONSE']._serialized_start=16805
  _globals['_TRIGGERORGANIZATIONPIPELINERELEASERESPONSE']._serialized_end=16966
  _globals['_TRIGGERASYNCORGANIZATIONPIPELINERELEASEREQUEST']._serialized_start=16969
  _globals['_TRIGGERASYNCORGANIZATIONPIPELINERELEASEREQUEST']._serialized_end=17178
  _globals['_TRIGGERASYNCORGANIZATIONPIPELINERELEASERESPONSE']._serialized_start=17180
  _globals['_TRIGGERASYNCORGANIZATIONPIPELINERELEASERESPONSE']._serialized_end=17296
  _globals['_GETOPERATIONREQUEST']._serialized_start=17298
  _globals['_GETOPERATIONREQUEST']._serialized_end=17345
  _globals['_GETOPERATIONRESPONSE']._serialized_start=17347
  _globals['_GETOPERATIONRESPONSE']._serialized_end=17436
  _globals['_LISTPIPELINESADMINREQUEST']._serialized_start=17439
  _globals['_LISTPIPELINESADMINREQUEST']._serialized_end=17762
  _globals['_LISTPIPELINESADMINRESPONSE']._serialized_start=17765
  _globals['_LISTPIPELINESADMINRESPONSE']._serialized_end=17925
  _globals['_LISTPIPELINERELEASESADMINREQUEST']._serialized_start=17928
  _globals['_LISTPIPELINERELEASESADMINREQUEST']._serialized_end=18258
  _globals['_LISTPIPELINERELEASESADMINRESPONSE']._serialized_start=18261
  _globals['_LISTPIPELINERELEASESADMINRESPONSE']._serialized_end=18433
  _globals['_LOOKUPPIPELINEADMINREQUEST']._serialized_start=18436
  _globals['_LOOKUPPIPELINEADMINREQUEST']._serialized_end=18633
  _globals['_LOOKUPPIPELINEADMINRESPONSE']._serialized_start=18635
  _globals['_LOOKUPPIPELINEADMINRESPONSE']._serialized_end=18723
# @@protoc_insertion_point(module_scope)
