# generated by datamodel-codegen:
#   filename:  json_task_unmarshal_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Any, Dict


@dataclass
class Output:
    object: Dict[str, Any]
