# generated by datamodel-codegen:
#   filename:  instill_definitions.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Any, Optional, Union


@dataclass
class InstillModelConnectorInternalMode:
    mode: Optional[Any] = None


@dataclass
class InstillModelConnectorExternalMode:
    api_token: str
    server_url: str
    mode: Optional[Any] = None


InstillModelConnector = Union[
    InstillModelConnectorInternalMode, InstillModelConnectorExternalMode
]
