# generated by datamodel-codegen:
#   filename:  googlesearch_definitions.json

from __future__ import annotations

from dataclasses import dataclass


@dataclass
class GoogleSearchConnectorSpec:
    api_key: str
    cse_id: str
