# generated by datamodel-codegen:
#   filename:  huggingface_task_audio_classification_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import List


@dataclass
class Class:
    label: str
    score: float


@dataclass
class Output:
    classes: List[Class]
