# generated by datamodel-codegen:
#   filename:  huggingface_task_token_classification_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import List, Optional


@dataclass
class Result:
    end: Optional[int] = None
    entity_group: Optional[str] = None
    score: Optional[float] = None
    start: Optional[int] = None
    word: Optional[str] = None


@dataclass
class Output:
    results: List[Result]
