# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from model.model.v1alpha import model_definition_pb2 as model_dot_model_dot_v1alpha_dot_model__definition__pb2
from model.model.v1alpha import model_pb2 as model_dot_model_dot_v1alpha_dot_model__pb2


class ModelPublicServiceStub(object):
    """Model

    ModelPublicService exposes the public endpoints that allow clients to manage
    models.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Liveness = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/Liveness',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.LivenessRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.LivenessResponse.FromString,
                )
        self.Readiness = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/Readiness',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ReadinessRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ReadinessResponse.FromString,
                )
        self.ListModelDefinitions = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/ListModelDefinitions',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.ListModelDefinitionsRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.ListModelDefinitionsResponse.FromString,
                )
        self.GetModelDefinition = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetModelDefinition',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.GetModelDefinitionRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.GetModelDefinitionResponse.FromString,
                )
        self.ListModels = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/ListModels',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsResponse.FromString,
                )
        self.LookUpModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/LookUpModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelResponse.FromString,
                )
        self.ListUserModels = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/ListUserModels',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelsRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelsResponse.FromString,
                )
        self.CreateUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/CreateUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelResponse.FromString,
                )
        self.CreateUserModelBinaryFileUpload = channel.stream_unary(
                '/model.model.v1alpha.ModelPublicService/CreateUserModelBinaryFileUpload',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelBinaryFileUploadRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelBinaryFileUploadResponse.FromString,
                )
        self.GetUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelResponse.FromString,
                )
        self.UpdateUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/UpdateUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateUserModelResponse.FromString,
                )
        self.DeleteUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/DeleteUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelResponse.FromString,
                )
        self.RenameUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/RenameUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameUserModelResponse.FromString,
                )
        self.PublishUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/PublishUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.PublishUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.PublishUserModelResponse.FromString,
                )
        self.UnpublishUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/UnpublishUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UnpublishUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UnpublishUserModelResponse.FromString,
                )
        self.DeployUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/DeployUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployUserModelResponse.FromString,
                )
        self.UndeployUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/UndeployUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployUserModelResponse.FromString,
                )
        self.GetUserModelCard = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetUserModelCard',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelCardRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelCardResponse.FromString,
                )
        self.WatchUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/WatchUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserModelResponse.FromString,
                )
        self.TriggerUserModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerUserModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelResponse.FromString,
                )
        self.TriggerUserModelBinaryFileUpload = channel.stream_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerUserModelBinaryFileUpload',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelBinaryFileUploadRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelBinaryFileUploadResponse.FromString,
                )
        self.ListOrganizationModels = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/ListOrganizationModels',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelsRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelsResponse.FromString,
                )
        self.CreateOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/CreateOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelResponse.FromString,
                )
        self.CreateOrganizationModelBinaryFileUpload = channel.stream_unary(
                '/model.model.v1alpha.ModelPublicService/CreateOrganizationModelBinaryFileUpload',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelBinaryFileUploadRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelBinaryFileUploadResponse.FromString,
                )
        self.GetOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelResponse.FromString,
                )
        self.UpdateOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/UpdateOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateOrganizationModelResponse.FromString,
                )
        self.DeleteOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/DeleteOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelResponse.FromString,
                )
        self.RenameOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/RenameOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameOrganizationModelResponse.FromString,
                )
        self.PublishOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/PublishOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.PublishOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.PublishOrganizationModelResponse.FromString,
                )
        self.UnpublishOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/UnpublishOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UnpublishOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UnpublishOrganizationModelResponse.FromString,
                )
        self.DeployOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/DeployOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployOrganizationModelResponse.FromString,
                )
        self.UndeployOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/UndeployOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployOrganizationModelResponse.FromString,
                )
        self.GetOrganizationModelCard = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetOrganizationModelCard',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelCardRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelCardResponse.FromString,
                )
        self.WatchOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/WatchOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationModelResponse.FromString,
                )
        self.TriggerOrganizationModel = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerOrganizationModel',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelResponse.FromString,
                )
        self.TriggerOrganizationModelBinaryFileUpload = channel.stream_unary(
                '/model.model.v1alpha.ModelPublicService/TriggerOrganizationModelBinaryFileUpload',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelBinaryFileUploadRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelBinaryFileUploadResponse.FromString,
                )
        self.GetModelOperation = channel.unary_unary(
                '/model.model.v1alpha.ModelPublicService/GetModelOperation',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetModelOperationRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetModelOperationResponse.FromString,
                )


class ModelPublicServiceServicer(object):
    """Model

    ModelPublicService exposes the public endpoints that allow clients to manage
    models.
    """

    def Liveness(self, request, context):
        """Check if the model server is alive

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Readiness(self, request, context):
        """Check if the model server is ready

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListModelDefinitions(self, request, context):
        """List model definitions

        Returns a paginated list of model definitions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelDefinition(self, request, context):
        """Get a model definition

        Returns the details of a model definition.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListModels(self, request, context):
        """List models

        Returns a paginated list of models.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LookUpModel(self, request, context):
        """Get a model by UID

        Returns the details of a model by a permalink defined by the resource UID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUserModels(self, request, context):
        """List user models

        Returns a paginated list of models that belong to the specified user. The
        parent user may be different from the authenticated user, in which case
        the results will contain the models that are visible to the latter.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateUserModel(self, request, context):
        """Create a new model

        Creates a new model under the parenthood of a user. This is an
        asynchronous endpoint, i.e., the server will not wait for the model to be
        created in order to respond. Instead, it will return a response with the
        necessary information to access the result and status of the creation
        operation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateUserModelBinaryFileUpload(self, request_iterator, context):
        """Upload model binary

        Creates a new model by upploading its binary content.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserModel(self, request, context):
        """Get a model

        Returns the detail of a model, accessing it by the model ID and its parent user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserModel(self, request, context):
        """Update a model

        Updates a model, accessing it by its resource name, which is defined by
        the parent user and the ID of the model.

        In REST requests, only the supplied model fields will be taken into
        account when updating the resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteUserModel(self, request, context):
        """Delete a model

        Deletes a model, accesing it by its resource name, which is defined by the
        parent user and the ID of the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RenameUserModel(self, request, context):
        """Rename a model

        Renames a model, accesing it by its resource name, which is defined by the
        parent user and the ID of the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PublishUserModel(self, request, context):
        """Publish a model

        Updates the visibility in a model to PUBLIC. The model is accessed by its
        resource name, defined by the model ID and its parent user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnpublishUserModel(self, request, context):
        """Unpublish a model

        Updates the visibility in a model to PRIVATE. The model is accessed by its
        resource name, defined by the model ID and its parent user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeployUserModel(self, request, context):
        """Deploy a model

        Transitions the model into an ONLINE state. The model is accessed by its
        resource name, defined by the model ID and its parent user.

        While this operation is being performed, the state of the model will
        transition to UNSPECIFIED. As completing the deployment might take time,
        the server will not wait to complete the operation to return a response.
        The state of the model can be used to track the completion of the
        operation. This can be done by using the `watch` operation on the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UndeployUserModel(self, request, context):
        """Undeploy a model

        Transitions the model into an OFFLINE state. The model is accessed by its
        resource name, defined by the model ID and its parent user.

        While this operation is being performed, the state of the model will
        transition to UNSPECIFIED. As completing the teardown might take time,
        the server will not wait to complete the operation to return a response.
        The state of the model can be used to track the completion of the
        operation. This can be done by using the `watch` operation on the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserModelCard(self, request, context):
        """Get a model card

        Returns the README file that accompanies a model, describing it and
        enhancing it with metadata. The model is accessed by its resource name.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchUserModel(self, request, context):
        """Watch the state of a model

        Returns the state of a model. The deploy / undeploy actions take some
        time, during which a model will be in an UNSPECIFIED state. This endpoint
        allows clients to track the state and progress of the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerUserModel(self, request, context):
        """/////////////////////////////////////////////////////

        Trigger model inference

        Triggers a deployed model to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerUserModelBinaryFileUpload(self, request_iterator, context):
        """Trigger model inference with a binary input

        Triggers a deployed model to infer the result of a task or question,
        submitted as a binary file.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOrganizationModels(self, request, context):
        """List organization models

        Returns a paginated list of models that belong to the specified organization. The
        parent organization may be different from the authenticated organization, in which case
        the results will contain the models that are visible to the latter.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateOrganizationModel(self, request, context):
        """Create a new model

        Creates a new model under the parenthood of an organization. This is an
        asynchronous endpoint, i.e., the server will not wait for the model to be
        created in order to respond. Instead, it will return a response with the
        necessary information to access the result and status of the creation
        operation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateOrganizationModelBinaryFileUpload(self, request_iterator, context):
        """Upload model binary

        Creates a new model by upploading its binary content.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationModel(self, request, context):
        """Get a model

        Returns the detail of a model, accessing it by the model ID and its parent organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateOrganizationModel(self, request, context):
        """Update a model

        Updates a model, accessing it by its resource name, which is defined by
        the parent organization and the ID of the model.

        In REST requests, only the supplied model fields will be taken into
        account when updating the resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOrganizationModel(self, request, context):
        """Delete a model

        Deletes a model, accesing it by its resource name, which is defined by the
        parent organization and the ID of the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RenameOrganizationModel(self, request, context):
        """Rename a model

        Renames a model, accesing it by its resource name, which is defined by the
        parent organization and the ID of the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PublishOrganizationModel(self, request, context):
        """Publish a model

        Updates the visibility in a model to PUBLIC. The model is accessed by its
        resource name, defined by the model ID and its parent organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnpublishOrganizationModel(self, request, context):
        """Unpublish a model

        Updates the visibility in a model to PRIVATE. The model is accessed by its
        resource name, defined by the model ID and its parent organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeployOrganizationModel(self, request, context):
        """Deploy a model

        Transitions the model into an ONLINE state. The model is accessed by its
        resource name, defined by the model ID and its parent organization.

        While this operation is being performed, the state of the model will
        transition to UNSPECIFIED. As completing the deployment might take time,
        the server will not wait to complete the operation to return a response.
        The state of the model can be used to track the completion of the
        operation. This can be done by using the `watch` operation on the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UndeployOrganizationModel(self, request, context):
        """Undeploy a model

        Transitions the model into an OFFLINE state. The model is accessed by its
        resource name, defined by the model ID and its parent organization.

        While this operation is being performed, the state of the model will
        transition to UNSPECIFIED. As completing the teardown might take time,
        the server will not wait to complete the operation to return a response.
        The state of the model can be used to track the completion of the
        operation. This can be done by using the `watch` operation on the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationModelCard(self, request, context):
        """Get a model card

        Returns the README file that accompanies a model, describing it and
        enhancing it with metadata. The model is accessed by its resource name.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchOrganizationModel(self, request, context):
        """Watch the state of a model

        Returns the state of a model. The deploy / undeploy actions take some
        time, during which a model will be in an UNSPECIFIED state. This endpoint
        allows clients to track the state and progress of the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerOrganizationModel(self, request, context):
        """/////////////////////////////////////////////////////

        Trigger model inference

        Triggers a deployed model to infer the result of a set of task or
        questions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerOrganizationModelBinaryFileUpload(self, request_iterator, context):
        """Trigger model inference with a binary input

        Triggers a deployed model to infer the result of a task or question,
        submitted as a binary file.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelOperation(self, request, context):
        """Get the details of a long-running operation

        This method allows requesters to request the status and outcome of
        long-running operations in a model, such as deployment.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ModelPublicServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Liveness': grpc.unary_unary_rpc_method_handler(
                    servicer.Liveness,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.LivenessRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.LivenessResponse.SerializeToString,
            ),
            'Readiness': grpc.unary_unary_rpc_method_handler(
                    servicer.Readiness,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ReadinessRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ReadinessResponse.SerializeToString,
            ),
            'ListModelDefinitions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModelDefinitions,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.ListModelDefinitionsRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.ListModelDefinitionsResponse.SerializeToString,
            ),
            'GetModelDefinition': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelDefinition,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.GetModelDefinitionRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__definition__pb2.GetModelDefinitionResponse.SerializeToString,
            ),
            'ListModels': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModels,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsResponse.SerializeToString,
            ),
            'LookUpModel': grpc.unary_unary_rpc_method_handler(
                    servicer.LookUpModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelResponse.SerializeToString,
            ),
            'ListUserModels': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUserModels,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelsRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelsResponse.SerializeToString,
            ),
            'CreateUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelResponse.SerializeToString,
            ),
            'CreateUserModelBinaryFileUpload': grpc.stream_unary_rpc_method_handler(
                    servicer.CreateUserModelBinaryFileUpload,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelBinaryFileUploadRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelBinaryFileUploadResponse.SerializeToString,
            ),
            'GetUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelResponse.SerializeToString,
            ),
            'UpdateUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateUserModelResponse.SerializeToString,
            ),
            'DeleteUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelResponse.SerializeToString,
            ),
            'RenameUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.RenameUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameUserModelResponse.SerializeToString,
            ),
            'PublishUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.PublishUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.PublishUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.PublishUserModelResponse.SerializeToString,
            ),
            'UnpublishUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.UnpublishUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UnpublishUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UnpublishUserModelResponse.SerializeToString,
            ),
            'DeployUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployUserModelResponse.SerializeToString,
            ),
            'UndeployUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.UndeployUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployUserModelResponse.SerializeToString,
            ),
            'GetUserModelCard': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserModelCard,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelCardRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelCardResponse.SerializeToString,
            ),
            'WatchUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.WatchUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserModelResponse.SerializeToString,
            ),
            'TriggerUserModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerUserModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelResponse.SerializeToString,
            ),
            'TriggerUserModelBinaryFileUpload': grpc.stream_unary_rpc_method_handler(
                    servicer.TriggerUserModelBinaryFileUpload,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelBinaryFileUploadRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelBinaryFileUploadResponse.SerializeToString,
            ),
            'ListOrganizationModels': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOrganizationModels,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelsRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelsResponse.SerializeToString,
            ),
            'CreateOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelResponse.SerializeToString,
            ),
            'CreateOrganizationModelBinaryFileUpload': grpc.stream_unary_rpc_method_handler(
                    servicer.CreateOrganizationModelBinaryFileUpload,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelBinaryFileUploadRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelBinaryFileUploadResponse.SerializeToString,
            ),
            'GetOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelResponse.SerializeToString,
            ),
            'UpdateOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UpdateOrganizationModelResponse.SerializeToString,
            ),
            'DeleteOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelResponse.SerializeToString,
            ),
            'RenameOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.RenameOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.RenameOrganizationModelResponse.SerializeToString,
            ),
            'PublishOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.PublishOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.PublishOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.PublishOrganizationModelResponse.SerializeToString,
            ),
            'UnpublishOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.UnpublishOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UnpublishOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UnpublishOrganizationModelResponse.SerializeToString,
            ),
            'DeployOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployOrganizationModelResponse.SerializeToString,
            ),
            'UndeployOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.UndeployOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployOrganizationModelResponse.SerializeToString,
            ),
            'GetOrganizationModelCard': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationModelCard,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelCardRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelCardResponse.SerializeToString,
            ),
            'WatchOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.WatchOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationModelResponse.SerializeToString,
            ),
            'TriggerOrganizationModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerOrganizationModel,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelResponse.SerializeToString,
            ),
            'TriggerOrganizationModelBinaryFileUpload': grpc.stream_unary_rpc_method_handler(
                    servicer.TriggerOrganizationModelBinaryFileUpload,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelBinaryFileUploadRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelBinaryFileUploadResponse.SerializeToString,
            ),
            'GetModelOperation': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelOperation,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetModelOperationRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.GetModelOperationResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'model.model.v1alpha.ModelPublicService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ModelPublicService(object):
    """Model

    ModelPublicService exposes the public endpoints that allow clients to manage
    models.
    """

    @staticmethod
    def Liveness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/Liveness',
            model_dot_model_dot_v1alpha_dot_model__pb2.LivenessRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.LivenessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Readiness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/Readiness',
            model_dot_model_dot_v1alpha_dot_model__pb2.ReadinessRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ReadinessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListModelDefinitions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/ListModelDefinitions',
            model_dot_model_dot_v1alpha_dot_model__definition__pb2.ListModelDefinitionsRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__definition__pb2.ListModelDefinitionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelDefinition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetModelDefinition',
            model_dot_model_dot_v1alpha_dot_model__definition__pb2.GetModelDefinitionRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__definition__pb2.GetModelDefinitionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/ListModels',
            model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LookUpModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/LookUpModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUserModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/ListUserModels',
            model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelsRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ListUserModelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/CreateUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateUserModelBinaryFileUpload(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/model.model.v1alpha.ModelPublicService/CreateUserModelBinaryFileUpload',
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelBinaryFileUploadRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateUserModelBinaryFileUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/UpdateUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.UpdateUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.UpdateUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/DeleteUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RenameUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/RenameUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.RenameUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.RenameUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PublishUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/PublishUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.PublishUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.PublishUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnpublishUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/UnpublishUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.UnpublishUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.UnpublishUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeployUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/DeployUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.DeployUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.DeployUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UndeployUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/UndeployUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.UndeployUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.UndeployUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserModelCard(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetUserModelCard',
            model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelCardRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.GetUserModelCardResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WatchUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/WatchUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerUserModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerUserModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerUserModelBinaryFileUpload(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/model.model.v1alpha.ModelPublicService/TriggerUserModelBinaryFileUpload',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelBinaryFileUploadRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerUserModelBinaryFileUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOrganizationModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/ListOrganizationModels',
            model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelsRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ListOrganizationModelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/CreateOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateOrganizationModelBinaryFileUpload(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/model.model.v1alpha.ModelPublicService/CreateOrganizationModelBinaryFileUpload',
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelBinaryFileUploadRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.CreateOrganizationModelBinaryFileUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/UpdateOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.UpdateOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.UpdateOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/DeleteOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.DeleteOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RenameOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/RenameOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.RenameOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.RenameOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PublishOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/PublishOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.PublishOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.PublishOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnpublishOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/UnpublishOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.UnpublishOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.UnpublishOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeployOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/DeployOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.DeployOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.DeployOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UndeployOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/UndeployOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.UndeployOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.UndeployOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationModelCard(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetOrganizationModelCard',
            model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelCardRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.GetOrganizationModelCardResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WatchOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/WatchOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.WatchOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerOrganizationModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/TriggerOrganizationModel',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerOrganizationModelBinaryFileUpload(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/model.model.v1alpha.ModelPublicService/TriggerOrganizationModelBinaryFileUpload',
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelBinaryFileUploadRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.TriggerOrganizationModelBinaryFileUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelOperation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPublicService/GetModelOperation',
            model_dot_model_dot_v1alpha_dot_model__pb2.GetModelOperationRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.GetModelOperationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
