# generated by datamodel-codegen:
#   filename:  instill_task_image_to_image_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import List


@dataclass
class Output:
    images: List[str]
