# generated by datamodel-codegen:
#   filename:  openai_task_speech_recognition_output.json

from __future__ import annotations

from dataclasses import dataclass


@dataclass
class Output:
    text: str
