# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vdp/pipeline/v1beta/pipeline_public_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from vdp.pipeline.v1beta import common_pb2 as vdp_dot_pipeline_dot_v1beta_dot_common__pb2
from vdp.pipeline.v1beta import connector_pb2 as vdp_dot_pipeline_dot_v1beta_dot_connector__pb2
from vdp.pipeline.v1beta import connector_definition_pb2 as vdp_dot_pipeline_dot_v1beta_dot_connector__definition__pb2
from vdp.pipeline.v1beta import operator_definition_pb2 as vdp_dot_pipeline_dot_v1beta_dot_operator__definition__pb2
from vdp.pipeline.v1beta import pipeline_pb2 as vdp_dot_pipeline_dot_v1beta_dot_pipeline__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1vdp/pipeline/v1beta/pipeline_public_service.proto\x12\x13vdp.pipeline.v1beta\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1bgoogle/api/visibility.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a vdp/pipeline/v1beta/common.proto\x1a#vdp/pipeline/v1beta/connector.proto\x1a.vdp/pipeline/v1beta/connector_definition.proto\x1a-vdp/pipeline/v1beta/operator_definition.proto\x1a\"vdp/pipeline/v1beta/pipeline.proto2\xe2v\n\x15PipelinePublicService\x12\x9e\x01\n\x08Liveness\x12$.vdp.pipeline.v1beta.LivenessRequest\x1a%.vdp.pipeline.v1beta.LivenessResponse\"E\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02/\x12\x12/v1beta/__livenessZ\x19\x12\x17/v1beta/health/pipeline\x12\x87\x01\n\tReadiness\x12%.vdp.pipeline.v1beta.ReadinessRequest\x1a&.vdp.pipeline.v1beta.ReadinessResponse\"+\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x15\x12\x13/v1beta/__readiness\x12\x81\x01\n\rListPipelines\x12).vdp.pipeline.v1beta.ListPipelinesRequest\x1a*.vdp.pipeline.v1beta.ListPipelinesResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v1beta/pipelines\x12\xa5\x01\n\x0eLookUpPipeline\x12*.vdp.pipeline.v1beta.LookUpPipelineRequest\x1a+.vdp.pipeline.v1beta.LookUpPipelineResponse\":\xda\x41\tpermalink\x82\xd3\xe4\x93\x02(\x12&/v1beta/{permalink=pipelines/*}/lookUp\x12\xbd\x01\n\x12\x43reateUserPipeline\x12..vdp.pipeline.v1beta.CreateUserPipelineRequest\x1a/.vdp.pipeline.v1beta.CreateUserPipelineResponse\"F\xda\x41\x0fparent,pipeline\x82\xd3\xe4\x93\x02.\"\"/v1beta/{parent=users/*}/pipelines:\x08pipeline\x12\xa7\x01\n\x11ListUserPipelines\x12-.vdp.pipeline.v1beta.ListUserPipelinesRequest\x1a..vdp.pipeline.v1beta.ListUserPipelinesResponse\"3\xda\x41\x06parent\x82\xd3\xe4\x93\x02$\x12\"/v1beta/{parent=users/*}/pipelines\x12\x9f\x01\n\x0fGetUserPipeline\x12+.vdp.pipeline.v1beta.GetUserPipelineRequest\x1a,.vdp.pipeline.v1beta.GetUserPipelineResponse\"1\xda\x41\x04name\x82\xd3\xe4\x93\x02$\x12\"/v1beta/{name=users/*/pipelines/*}\x12\xcb\x01\n\x12UpdateUserPipeline\x12..vdp.pipeline.v1beta.UpdateUserPipelineRequest\x1a/.vdp.pipeline.v1beta.UpdateUserPipelineResponse\"T\xda\x41\x14pipeline,update_mask\x82\xd3\xe4\x93\x02\x37\x32+/v1beta/{pipeline.name=users/*/pipelines/*}:\x08pipeline\x12\xa8\x01\n\x12\x44\x65leteUserPipeline\x12..vdp.pipeline.v1beta.DeleteUserPipelineRequest\x1a/.vdp.pipeline.v1beta.DeleteUserPipelineResponse\"1\xda\x41\x04name\x82\xd3\xe4\x93\x02$*\"/v1beta/{name=users/*/pipelines/*}\x12\xba\x01\n\x14ValidateUserPipeline\x12\x30.vdp.pipeline.v1beta.ValidateUserPipelineRequest\x1a\x31.vdp.pipeline.v1beta.ValidateUserPipelineResponse\"=\xda\x41\x04name\x82\xd3\xe4\x93\x02\x30\"+/v1beta/{name=users/*/pipelines/*}/validate:\x01*\x12\xc2\x01\n\x12RenameUserPipeline\x12..vdp.pipeline.v1beta.RenameUserPipelineRequest\x1a/.vdp.pipeline.v1beta.RenameUserPipelineResponse\"K\xda\x41\x14name,new_pipeline_id\x82\xd3\xe4\x93\x02.\")/v1beta/{name=users/*/pipelines/*}/rename:\x01*\x12\xb5\x01\n\x11\x43loneUserPipeline\x12-.vdp.pipeline.v1beta.CloneUserPipelineRequest\x1a..vdp.pipeline.v1beta.CloneUserPipelineResponse\"A\xda\x41\x0bname,target\x82\xd3\xe4\x93\x02-\"(/v1beta/{name=users/*/pipelines/*}/clone:\x01*\x12\xbd\x01\n\x13TriggerUserPipeline\x12/.vdp.pipeline.v1beta.TriggerUserPipelineRequest\x1a\x30.vdp.pipeline.v1beta.TriggerUserPipelineResponse\"C\xda\x41\x0bname,inputs\x82\xd3\xe4\x93\x02/\"*/v1beta/{name=users/*/pipelines/*}/trigger:\x01*\x12\xd1\x01\n\x18TriggerAsyncUserPipeline\x12\x34.vdp.pipeline.v1beta.TriggerAsyncUserPipelineRequest\x1a\x35.vdp.pipeline.v1beta.TriggerAsyncUserPipelineResponse\"H\xda\x41\x0bname,inputs\x82\xd3\xe4\x93\x02\x34\"//v1beta/{name=users/*/pipelines/*}/triggerAsync:\x01*\x12\xdb\x01\n\x19\x43reateUserPipelineRelease\x12\x35.vdp.pipeline.v1beta.CreateUserPipelineReleaseRequest\x1a\x36.vdp.pipeline.v1beta.CreateUserPipelineReleaseResponse\"O\xda\x41\x0eparent,release\x82\xd3\xe4\x93\x02\x38\"-/v1beta/{parent=users/*/pipelines/*}/releases:\x07release\x12\xca\x01\n\x18ListUserPipelineReleases\x12\x34.vdp.pipeline.v1beta.ListUserPipelineReleasesRequest\x1a\x35.vdp.pipeline.v1beta.ListUserPipelineReleasesResponse\"A\xda\x41\tpipelines\x82\xd3\xe4\x93\x02/\x12-/v1beta/{parent=users/*/pipelines/*}/releases\x12\xbf\x01\n\x16GetUserPipelineRelease\x12\x32.vdp.pipeline.v1beta.GetUserPipelineReleaseRequest\x1a\x33.vdp.pipeline.v1beta.GetUserPipelineReleaseResponse\"<\xda\x41\x04name\x82\xd3\xe4\x93\x02/\x12-/v1beta/{name=users/*/pipelines/*/releases/*}\x12\xe8\x01\n\x19UpdateUserPipelineRelease\x12\x35.vdp.pipeline.v1beta.UpdateUserPipelineReleaseRequest\x1a\x36.vdp.pipeline.v1beta.UpdateUserPipelineReleaseResponse\"\\\xda\x41\x13release,update_mask\x82\xd3\xe4\x93\x02@25/v1beta/{release.name=users/*/pipelines/*/releases/*}:\x07release\x12\xc8\x01\n\x19\x44\x65leteUserPipelineRelease\x12\x35.vdp.pipeline.v1beta.DeleteUserPipelineReleaseRequest\x1a\x36.vdp.pipeline.v1beta.DeleteUserPipelineReleaseResponse\"<\xda\x41\x04name\x82\xd3\xe4\x93\x02/*-/v1beta/{name=users/*/pipelines/*/releases/*}\x12\xd3\x01\n\x1aRestoreUserPipelineRelease\x12\x36.vdp.pipeline.v1beta.RestoreUserPipelineReleaseRequest\x1a\x37.vdp.pipeline.v1beta.RestoreUserPipelineReleaseResponse\"D\xda\x41\x04name\x82\xd3\xe4\x93\x02\x37\"5/v1beta/{name=users/*/pipelines/*/releases/*}/restore\x12\xcb\x01\n\x18WatchUserPipelineRelease\x12\x34.vdp.pipeline.v1beta.WatchUserPipelineReleaseRequest\x1a\x35.vdp.pipeline.v1beta.WatchUserPipelineReleaseResponse\"B\xda\x41\x04name\x82\xd3\xe4\x93\x02\x35\x12\x33/v1beta/{name=users/*/pipelines/*/releases/*}/watch\x12\xea\x01\n\x19RenameUserPipelineRelease\x12\x35.vdp.pipeline.v1beta.RenameUserPipelineReleaseRequest\x1a\x36.vdp.pipeline.v1beta.RenameUserPipelineReleaseResponse\"^\xda\x41\x1cname,new_pipeline_release_id\x82\xd3\xe4\x93\x02\x39\"4/v1beta/{name=users/*/pipelines/*/releases/*}/rename:\x01*\x12\xdd\x01\n\x1aTriggerUserPipelineRelease\x12\x36.vdp.pipeline.v1beta.TriggerUserPipelineReleaseRequest\x1a\x37.vdp.pipeline.v1beta.TriggerUserPipelineReleaseResponse\"N\xda\x41\x0bname,inputs\x82\xd3\xe4\x93\x02:\"5/v1beta/{name=users/*/pipelines/*/releases/*}/trigger:\x01*\x12\xf1\x01\n\x1fTriggerAsyncUserPipelineRelease\x12;.vdp.pipeline.v1beta.TriggerAsyncUserPipelineReleaseRequest\x1a<.vdp.pipeline.v1beta.TriggerAsyncUserPipelineReleaseResponse\"S\xda\x41\x0bname,inputs\x82\xd3\xe4\x93\x02?\":/v1beta/{name=users/*/pipelines/*/releases/*}/triggerAsync:\x01*\x12\xdd\x01\n\x1a\x43reateOrganizationPipeline\x12\x36.vdp.pipeline.v1beta.CreateOrganizationPipelineRequest\x1a\x37.vdp.pipeline.v1beta.CreateOrganizationPipelineResponse\"N\xda\x41\x0fparent,pipeline\x82\xd3\xe4\x93\x02\x36\"*/v1beta/{parent=organizations/*}/pipelines:\x08pipeline\x12\xc7\x01\n\x19ListOrganizationPipelines\x12\x35.vdp.pipeline.v1beta.ListOrganizationPipelinesRequest\x1a\x36.vdp.pipeline.v1beta.ListOrganizationPipelinesResponse\";\xda\x41\x06parent\x82\xd3\xe4\x93\x02,\x12*/v1beta/{parent=organizations/*}/pipelines\x12\xbf\x01\n\x17GetOrganizationPipeline\x12\x33.vdp.pipeline.v1beta.GetOrganizationPipelineRequest\x1a\x34.vdp.pipeline.v1beta.GetOrganizationPipelineResponse\"9\xda\x41\x04name\x82\xd3\xe4\x93\x02,\x12*/v1beta/{name=organizations/*/pipelines/*}\x12\xeb\x01\n\x1aUpdateOrganizationPipeline\x12\x36.vdp.pipeline.v1beta.UpdateOrganizationPipelineRequest\x1a\x37.vdp.pipeline.v1beta.UpdateOrganizationPipelineResponse\"\\\xda\x41\x14pipeline,update_mask\x82\xd3\xe4\x93\x02?23/v1beta/{pipeline.name=organizations/*/pipelines/*}:\x08pipeline\x12\xc8\x01\n\x1a\x44\x65leteOrganizationPipeline\x12\x36.vdp.pipeline.v1beta.DeleteOrganizationPipelineRequest\x1a\x37.vdp.pipeline.v1beta.DeleteOrganizationPipelineResponse\"9\xda\x41\x04name\x82\xd3\xe4\x93\x02,**/v1beta/{name=organizations/*/pipelines/*}\x12\xda\x01\n\x1cValidateOrganizationPipeline\x12\x38.vdp.pipeline.v1beta.ValidateOrganizationPipelineRequest\x1a\x39.vdp.pipeline.v1beta.ValidateOrganizationPipelineResponse\"E\xda\x41\x04name\x82\xd3\xe4\x93\x02\x38\"3/v1beta/{name=organizations/*/pipelines/*}/validate:\x01*\x12\xe2\x01\n\x1aRenameOrganizationPipeline\x12\x36.vdp.pipeline.v1beta.RenameOrganizationPipelineRequest\x1a\x37.vdp.pipeline.v1beta.RenameOrganizationPipelineResponse\"S\xda\x41\x14name,new_pipeline_id\x82\xd3\xe4\x93\x02\x36\"1/v1beta/{name=organizations/*/pipelines/*}/rename:\x01*\x12\xd5\x01\n\x19\x43loneOrganizationPipeline\x12\x35.vdp.pipeline.v1beta.CloneOrganizationPipelineRequest\x1a\x36.vdp.pipeline.v1beta.CloneOrganizationPipelineResponse\"I\xda\x41\x0bname,target\x82\xd3\xe4\x93\x02\x35\"0/v1beta/{name=organizations/*/pipelines/*}/clone:\x01*\x12\xdd\x01\n\x1bTriggerOrganizationPipeline\x12\x37.vdp.pipeline.v1beta.TriggerOrganizationPipelineRequest\x1a\x38.vdp.pipeline.v1beta.TriggerOrganizationPipelineResponse\"K\xda\x41\x0bname,inputs\x82\xd3\xe4\x93\x02\x37\"2/v1beta/{name=organizations/*/pipelines/*}/trigger:\x01*\x12\xf1\x01\n TriggerAsyncOrganizationPipeline\x12<.vdp.pipeline.v1beta.TriggerAsyncOrganizationPipelineRequest\x1a=.vdp.pipeline.v1beta.TriggerAsyncOrganizationPipelineResponse\"P\xda\x41\x0bname,inputs\x82\xd3\xe4\x93\x02<\"7/v1beta/{name=organizations/*/pipelines/*}/triggerAsync:\x01*\x12\xfb\x01\n!CreateOrganizationPipelineRelease\x12=.vdp.pipeline.v1beta.CreateOrganizationPipelineReleaseRequest\x1a>.vdp.pipeline.v1beta.CreateOrganizationPipelineReleaseResponse\"W\xda\x41\x0eparent,release\x82\xd3\xe4\x93\x02@\"5/v1beta/{parent=organizations/*/pipelines/*}/releases:\x07release\x12\xea\x01\n ListOrganizationPipelineReleases\x12<.vdp.pipeline.v1beta.ListOrganizationPipelineReleasesRequest\x1a=.vdp.pipeline.v1beta.ListOrganizationPipelineReleasesResponse\"I\xda\x41\tpipelines\x82\xd3\xe4\x93\x02\x37\x12\x35/v1beta/{parent=organizations/*/pipelines/*}/releases\x12\xdf\x01\n\x1eGetOrganizationPipelineRelease\x12:.vdp.pipeline.v1beta.GetOrganizationPipelineReleaseRequest\x1a;.vdp.pipeline.v1beta.GetOrganizationPipelineReleaseResponse\"D\xda\x41\x04name\x82\xd3\xe4\x93\x02\x37\x12\x35/v1beta/{name=organizations/*/pipelines/*/releases/*}\x12\x88\x02\n!UpdateOrganizationPipelineRelease\x12=.vdp.pipeline.v1beta.UpdateOrganizationPipelineReleaseRequest\x1a>.vdp.pipeline.v1beta.UpdateOrganizationPipelineReleaseResponse\"d\xda\x41\x13release,update_mask\x82\xd3\xe4\x93\x02H2=/v1beta/{release.name=organizations/*/pipelines/*/releases/*}:\x07release\x12\xe8\x01\n!DeleteOrganizationPipelineRelease\x12=.vdp.pipeline.v1beta.DeleteOrganizationPipelineReleaseRequest\x1a>.vdp.pipeline.v1beta.DeleteOrganizationPipelineReleaseResponse\"D\xda\x41\x04name\x82\xd3\xe4\x93\x02\x37*5/v1beta/{name=organizations/*/pipelines/*/releases/*}\x12\xf3\x01\n\"RestoreOrganizationPipelineRelease\x12>.vdp.pipeline.v1beta.RestoreOrganizationPipelineReleaseRequest\x1a?.vdp.pipeline.v1beta.RestoreOrganizationPipelineReleaseResponse\"L\xda\x41\x04name\x82\xd3\xe4\x93\x02?\"=/v1beta/{name=organizations/*/pipelines/*/releases/*}/restore\x12\xeb\x01\n WatchOrganizationPipelineRelease\x12<.vdp.pipeline.v1beta.WatchOrganizationPipelineReleaseRequest\x1a=.vdp.pipeline.v1beta.WatchOrganizationPipelineReleaseResponse\"J\xda\x41\x04name\x82\xd3\xe4\x93\x02=\x12;/v1beta/{name=organizations/*/pipelines/*/releases/*}/watch\x12\x8a\x02\n!RenameOrganizationPipelineRelease\x12=.vdp.pipeline.v1beta.RenameOrganizationPipelineReleaseRequest\x1a>.vdp.pipeline.v1beta.RenameOrganizationPipelineReleaseResponse\"f\xda\x41\x1cname,new_pipeline_release_id\x82\xd3\xe4\x93\x02\x41\"</v1beta/{name=organizations/*/pipelines/*/releases/*}/rename:\x01*\x12\xfd\x01\n\"TriggerOrganizationPipelineRelease\x12>.vdp.pipeline.v1beta.TriggerOrganizationPipelineReleaseRequest\x1a?.vdp.pipeline.v1beta.TriggerOrganizationPipelineReleaseResponse\"V\xda\x41\x0bname,inputs\x82\xd3\xe4\x93\x02\x42\"=/v1beta/{name=organizations/*/pipelines/*/releases/*}/trigger:\x01*\x12\x91\x02\n\'TriggerAsyncOrganizationPipelineRelease\x12\x43.vdp.pipeline.v1beta.TriggerAsyncOrganizationPipelineReleaseRequest\x1a\x44.vdp.pipeline.v1beta.TriggerAsyncOrganizationPipelineReleaseResponse\"[\xda\x41\x0bname,inputs\x82\xd3\xe4\x93\x02G\"B/v1beta/{name=organizations/*/pipelines/*/releases/*}/triggerAsync:\x01*\x12\x8f\x01\n\x0cGetOperation\x12(.vdp.pipeline.v1beta.GetOperationRequest\x1a).vdp.pipeline.v1beta.GetOperationResponse\"*\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1beta/{name=operations/*}\x12\xae\x01\n\x18ListConnectorDefinitions\x12\x34.vdp.pipeline.v1beta.ListConnectorDefinitionsRequest\x1a\x35.vdp.pipeline.v1beta.ListConnectorDefinitionsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1beta/connector-definitions\x12\xb8\x01\n\x16GetConnectorDefinition\x12\x32.vdp.pipeline.v1beta.GetConnectorDefinitionRequest\x1a\x33.vdp.pipeline.v1beta.GetConnectorDefinitionResponse\"5\xda\x41\x04name\x82\xd3\xe4\x93\x02(\x12&/v1beta/{name=connector-definitions/*}\x12\xaa\x01\n\x17ListOperatorDefinitions\x12\x33.vdp.pipeline.v1beta.ListOperatorDefinitionsRequest\x1a\x34.vdp.pipeline.v1beta.ListOperatorDefinitionsResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1beta/operator-definitions\x12\xb4\x01\n\x15GetOperatorDefinition\x12\x31.vdp.pipeline.v1beta.GetOperatorDefinitionRequest\x1a\x32.vdp.pipeline.v1beta.GetOperatorDefinitionResponse\"4\xda\x41\x04name\x82\xd3\xe4\x93\x02\'\x12%/v1beta/{name=operator-definitions/*}\x12\x85\x01\n\x0eListConnectors\x12*.vdp.pipeline.v1beta.ListConnectorsRequest\x1a+.vdp.pipeline.v1beta.ListConnectorsResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/v1beta/connectors\x12\xa9\x01\n\x0fLookUpConnector\x12+.vdp.pipeline.v1beta.LookUpConnectorRequest\x1a,.vdp.pipeline.v1beta.LookUpConnectorResponse\";\xda\x41\tpermalink\x82\xd3\xe4\x93\x02)\x12\'/v1beta/{permalink=connectors/*}/lookUp\x12\xc3\x01\n\x13\x43reateUserConnector\x12/.vdp.pipeline.v1beta.CreateUserConnectorRequest\x1a\x30.vdp.pipeline.v1beta.CreateUserConnectorResponse\"I\xda\x41\x10parent,connector\x82\xd3\xe4\x93\x02\x30\"#/v1beta/{parent=users/*}/connectors:\tconnector\x12\xab\x01\n\x12ListUserConnectors\x12..vdp.pipeline.v1beta.ListUserConnectorsRequest\x1a/.vdp.pipeline.v1beta.ListUserConnectorsResponse\"4\xda\x41\x06parent\x82\xd3\xe4\x93\x02%\x12#/v1beta/{parent=users/*}/connectors\x12\xa3\x01\n\x10GetUserConnector\x12,.vdp.pipeline.v1beta.GetUserConnectorRequest\x1a-.vdp.pipeline.v1beta.GetUserConnectorResponse\"2\xda\x41\x04name\x82\xd3\xe4\x93\x02%\x12#/v1beta/{name=users/*/connectors/*}\x12\xd2\x01\n\x13UpdateUserConnector\x12/.vdp.pipeline.v1beta.UpdateUserConnectorRequest\x1a\x30.vdp.pipeline.v1beta.UpdateUserConnectorResponse\"X\xda\x41\x15\x63onnector,update_mask\x82\xd3\xe4\x93\x02:2-/v1beta/{connector.name=users/*/connectors/*}:\tconnector\x12\xac\x01\n\x13\x44\x65leteUserConnector\x12/.vdp.pipeline.v1beta.DeleteUserConnectorRequest\x1a\x30.vdp.pipeline.v1beta.DeleteUserConnectorResponse\"2\xda\x41\x04name\x82\xd3\xe4\x93\x02%*#/v1beta/{name=users/*/connectors/*}\x12\xba\x01\n\x14\x43onnectUserConnector\x12\x30.vdp.pipeline.v1beta.ConnectUserConnectorRequest\x1a\x31.vdp.pipeline.v1beta.ConnectUserConnectorResponse\"=\xda\x41\x04name\x82\xd3\xe4\x93\x02\x30\"+/v1beta/{name=users/*/connectors/*}/connect:\x01*\x12\xc6\x01\n\x17\x44isconnectUserConnector\x12\x33.vdp.pipeline.v1beta.DisconnectUserConnectorRequest\x1a\x34.vdp.pipeline.v1beta.DisconnectUserConnectorResponse\"@\xda\x41\x04name\x82\xd3\xe4\x93\x02\x33\"./v1beta/{name=users/*/connectors/*}/disconnect:\x01*\x12\xc7\x01\n\x13RenameUserConnector\x12/.vdp.pipeline.v1beta.RenameUserConnectorRequest\x1a\x30.vdp.pipeline.v1beta.RenameUserConnectorResponse\"M\xda\x41\x15name,new_connector_id\x82\xd3\xe4\x93\x02/\"*/v1beta/{name=users/*/connectors/*}/rename:\x01*\x12\xba\x01\n\x14\x45xecuteUserConnector\x12\x30.vdp.pipeline.v1beta.ExecuteUserConnectorRequest\x1a\x31.vdp.pipeline.v1beta.ExecuteUserConnectorResponse\"=\xda\x41\x04name\x82\xd3\xe4\x93\x02\x30\"+/v1beta/{name=users/*/connectors/*}/execute:\x01*\x12\xaf\x01\n\x12WatchUserConnector\x12..vdp.pipeline.v1beta.WatchUserConnectorRequest\x1a/.vdp.pipeline.v1beta.WatchUserConnectorResponse\"8\xda\x41\x04name\x82\xd3\xe4\x93\x02+\x12)/v1beta/{name=users/*/connectors/*}/watch\x12\xb5\x01\n\x11TestUserConnector\x12-.vdp.pipeline.v1beta.TestUserConnectorRequest\x1a..vdp.pipeline.v1beta.TestUserConnectorResponse\"A\xda\x41\x04name\x82\xd3\xe4\x93\x02\x34\"2/v1beta/{name=users/*/connectors/*}/testConnection\x12\xe3\x01\n\x1b\x43reateOrganizationConnector\x12\x37.vdp.pipeline.v1beta.CreateOrganizationConnectorRequest\x1a\x38.vdp.pipeline.v1beta.CreateOrganizationConnectorResponse\"Q\xda\x41\x10parent,connector\x82\xd3\xe4\x93\x02\x38\"+/v1beta/{parent=organizations/*}/connectors:\tconnector\x12\xcb\x01\n\x1aListOrganizationConnectors\x12\x36.vdp.pipeline.v1beta.ListOrganizationConnectorsRequest\x1a\x37.vdp.pipeline.v1beta.ListOrganizationConnectorsResponse\"<\xda\x41\x06parent\x82\xd3\xe4\x93\x02-\x12+/v1beta/{parent=organizations/*}/connectors\x12\xc3\x01\n\x18GetOrganizationConnector\x12\x34.vdp.pipeline.v1beta.GetOrganizationConnectorRequest\x1a\x35.vdp.pipeline.v1beta.GetOrganizationConnectorResponse\":\xda\x41\x04name\x82\xd3\xe4\x93\x02-\x12+/v1beta/{name=organizations/*/connectors/*}\x12\xf2\x01\n\x1bUpdateOrganizationConnector\x12\x37.vdp.pipeline.v1beta.UpdateOrganizationConnectorRequest\x1a\x38.vdp.pipeline.v1beta.UpdateOrganizationConnectorResponse\"`\xda\x41\x15\x63onnector,update_mask\x82\xd3\xe4\x93\x02\x42\x32\x35/v1beta/{connector.name=organizations/*/connectors/*}:\tconnector\x12\xcc\x01\n\x1b\x44\x65leteOrganizationConnector\x12\x37.vdp.pipeline.v1beta.DeleteOrganizationConnectorRequest\x1a\x38.vdp.pipeline.v1beta.DeleteOrganizationConnectorResponse\":\xda\x41\x04name\x82\xd3\xe4\x93\x02-*+/v1beta/{name=organizations/*/connectors/*}\x12\xda\x01\n\x1c\x43onnectOrganizationConnector\x12\x38.vdp.pipeline.v1beta.ConnectOrganizationConnectorRequest\x1a\x39.vdp.pipeline.v1beta.ConnectOrganizationConnectorResponse\"E\xda\x41\x04name\x82\xd3\xe4\x93\x02\x38\"3/v1beta/{name=organizations/*/connectors/*}/connect:\x01*\x12\xe6\x01\n\x1f\x44isconnectOrganizationConnector\x12;.vdp.pipeline.v1beta.DisconnectOrganizationConnectorRequest\x1a<.vdp.pipeline.v1beta.DisconnectOrganizationConnectorResponse\"H\xda\x41\x04name\x82\xd3\xe4\x93\x02;\"6/v1beta/{name=organizations/*/connectors/*}/disconnect:\x01*\x12\xe7\x01\n\x1bRenameOrganizationConnector\x12\x37.vdp.pipeline.v1beta.RenameOrganizationConnectorRequest\x1a\x38.vdp.pipeline.v1beta.RenameOrganizationConnectorResponse\"U\xda\x41\x15name,new_connector_id\x82\xd3\xe4\x93\x02\x37\"2/v1beta/{name=organizations/*/connectors/*}/rename:\x01*\x12\xda\x01\n\x1c\x45xecuteOrganizationConnector\x12\x38.vdp.pipeline.v1beta.ExecuteOrganizationConnectorRequest\x1a\x39.vdp.pipeline.v1beta.ExecuteOrganizationConnectorResponse\"E\xda\x41\x04name\x82\xd3\xe4\x93\x02\x38\"3/v1beta/{name=organizations/*/connectors/*}/execute:\x01*\x12\xcf\x01\n\x1aWatchOrganizationConnector\x12\x36.vdp.pipeline.v1beta.WatchOrganizationConnectorRequest\x1a\x37.vdp.pipeline.v1beta.WatchOrganizationConnectorResponse\"@\xda\x41\x04name\x82\xd3\xe4\x93\x02\x33\x12\x31/v1beta/{name=organizations/*/connectors/*}/watch\x12\xd5\x01\n\x19TestOrganizationConnector\x12\x35.vdp.pipeline.v1beta.TestOrganizationConnectorRequest\x1a\x36.vdp.pipeline.v1beta.TestOrganizationConnectorResponse\"I\xda\x41\x04name\x82\xd3\xe4\x93\x02<\":/v1beta/{name=organizations/*/connectors/*}/testConnection\x12\x80\x01\n\tCheckName\x12%.vdp.pipeline.v1beta.CheckNameRequest\x1a&.vdp.pipeline.v1beta.CheckNameResponse\"$\xda\x41\x04name\x82\xd3\xe4\x93\x02\x17\"\x12/v1beta/check-name:\x01*\x1a\x19\x92\x41\x16\x12\x14Public VDP endpointsB\xe9\x01\n\x17\x63om.vdp.pipeline.v1betaB\x1aPipelinePublicServiceProtoP\x01ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\xa2\x02\x03VPX\xaa\x02\x13Vdp.Pipeline.V1beta\xca\x02\x13Vdp\\Pipeline\\V1beta\xe2\x02\x1fVdp\\Pipeline\\V1beta\\GPBMetadata\xea\x02\x15Vdp::Pipeline::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vdp.pipeline.v1beta.pipeline_public_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.vdp.pipeline.v1betaB\032PipelinePublicServiceProtoP\001ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\242\002\003VPX\252\002\023Vdp.Pipeline.V1beta\312\002\023Vdp\\Pipeline\\V1beta\342\002\037Vdp\\Pipeline\\V1beta\\GPBMetadata\352\002\025Vdp::Pipeline::V1beta'
  _PIPELINEPUBLICSERVICE._options = None
  _PIPELINEPUBLICSERVICE._serialized_options = b'\222A\026\022\024Public VDP endpoints'
  _PIPELINEPUBLICSERVICE.methods_by_name['Liveness']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['Liveness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002/\022\022/v1beta/__livenessZ\031\022\027/v1beta/health/pipeline'
  _PIPELINEPUBLICSERVICE.methods_by_name['Readiness']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['Readiness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\025\022\023/v1beta/__readiness'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListPipelines']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListPipelines']._serialized_options = b'\202\323\344\223\002\023\022\021/v1beta/pipelines'
  _PIPELINEPUBLICSERVICE.methods_by_name['LookUpPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['LookUpPipeline']._serialized_options = b'\332A\tpermalink\202\323\344\223\002(\022&/v1beta/{permalink=pipelines/*}/lookUp'
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateUserPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateUserPipeline']._serialized_options = b'\332A\017parent,pipeline\202\323\344\223\002.\"\"/v1beta/{parent=users/*}/pipelines:\010pipeline'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListUserPipelines']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListUserPipelines']._serialized_options = b'\332A\006parent\202\323\344\223\002$\022\"/v1beta/{parent=users/*}/pipelines'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetUserPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetUserPipeline']._serialized_options = b'\332A\004name\202\323\344\223\002$\022\"/v1beta/{name=users/*/pipelines/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateUserPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateUserPipeline']._serialized_options = b'\332A\024pipeline,update_mask\202\323\344\223\00272+/v1beta/{pipeline.name=users/*/pipelines/*}:\010pipeline'
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteUserPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteUserPipeline']._serialized_options = b'\332A\004name\202\323\344\223\002$*\"/v1beta/{name=users/*/pipelines/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['ValidateUserPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ValidateUserPipeline']._serialized_options = b'\332A\004name\202\323\344\223\0020\"+/v1beta/{name=users/*/pipelines/*}/validate:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameUserPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameUserPipeline']._serialized_options = b'\332A\024name,new_pipeline_id\202\323\344\223\002.\")/v1beta/{name=users/*/pipelines/*}/rename:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['CloneUserPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CloneUserPipeline']._serialized_options = b'\332A\013name,target\202\323\344\223\002-\"(/v1beta/{name=users/*/pipelines/*}/clone:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerUserPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerUserPipeline']._serialized_options = b'\332A\013name,inputs\202\323\344\223\002/\"*/v1beta/{name=users/*/pipelines/*}/trigger:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncUserPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncUserPipeline']._serialized_options = b'\332A\013name,inputs\202\323\344\223\0024\"//v1beta/{name=users/*/pipelines/*}/triggerAsync:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateUserPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateUserPipelineRelease']._serialized_options = b'\332A\016parent,release\202\323\344\223\0028\"-/v1beta/{parent=users/*/pipelines/*}/releases:\007release'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListUserPipelineReleases']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListUserPipelineReleases']._serialized_options = b'\332A\tpipelines\202\323\344\223\002/\022-/v1beta/{parent=users/*/pipelines/*}/releases'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetUserPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetUserPipelineRelease']._serialized_options = b'\332A\004name\202\323\344\223\002/\022-/v1beta/{name=users/*/pipelines/*/releases/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateUserPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateUserPipelineRelease']._serialized_options = b'\332A\023release,update_mask\202\323\344\223\002@25/v1beta/{release.name=users/*/pipelines/*/releases/*}:\007release'
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteUserPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteUserPipelineRelease']._serialized_options = b'\332A\004name\202\323\344\223\002/*-/v1beta/{name=users/*/pipelines/*/releases/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['RestoreUserPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['RestoreUserPipelineRelease']._serialized_options = b'\332A\004name\202\323\344\223\0027\"5/v1beta/{name=users/*/pipelines/*/releases/*}/restore'
  _PIPELINEPUBLICSERVICE.methods_by_name['WatchUserPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['WatchUserPipelineRelease']._serialized_options = b'\332A\004name\202\323\344\223\0025\0223/v1beta/{name=users/*/pipelines/*/releases/*}/watch'
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameUserPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameUserPipelineRelease']._serialized_options = b'\332A\034name,new_pipeline_release_id\202\323\344\223\0029\"4/v1beta/{name=users/*/pipelines/*/releases/*}/rename:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerUserPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerUserPipelineRelease']._serialized_options = b'\332A\013name,inputs\202\323\344\223\002:\"5/v1beta/{name=users/*/pipelines/*/releases/*}/trigger:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncUserPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncUserPipelineRelease']._serialized_options = b'\332A\013name,inputs\202\323\344\223\002?\":/v1beta/{name=users/*/pipelines/*/releases/*}/triggerAsync:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateOrganizationPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateOrganizationPipeline']._serialized_options = b'\332A\017parent,pipeline\202\323\344\223\0026\"*/v1beta/{parent=organizations/*}/pipelines:\010pipeline'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListOrganizationPipelines']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListOrganizationPipelines']._serialized_options = b'\332A\006parent\202\323\344\223\002,\022*/v1beta/{parent=organizations/*}/pipelines'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOrganizationPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOrganizationPipeline']._serialized_options = b'\332A\004name\202\323\344\223\002,\022*/v1beta/{name=organizations/*/pipelines/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateOrganizationPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateOrganizationPipeline']._serialized_options = b'\332A\024pipeline,update_mask\202\323\344\223\002?23/v1beta/{pipeline.name=organizations/*/pipelines/*}:\010pipeline'
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteOrganizationPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteOrganizationPipeline']._serialized_options = b'\332A\004name\202\323\344\223\002,**/v1beta/{name=organizations/*/pipelines/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['ValidateOrganizationPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ValidateOrganizationPipeline']._serialized_options = b'\332A\004name\202\323\344\223\0028\"3/v1beta/{name=organizations/*/pipelines/*}/validate:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameOrganizationPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameOrganizationPipeline']._serialized_options = b'\332A\024name,new_pipeline_id\202\323\344\223\0026\"1/v1beta/{name=organizations/*/pipelines/*}/rename:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['CloneOrganizationPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CloneOrganizationPipeline']._serialized_options = b'\332A\013name,target\202\323\344\223\0025\"0/v1beta/{name=organizations/*/pipelines/*}/clone:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerOrganizationPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerOrganizationPipeline']._serialized_options = b'\332A\013name,inputs\202\323\344\223\0027\"2/v1beta/{name=organizations/*/pipelines/*}/trigger:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncOrganizationPipeline']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncOrganizationPipeline']._serialized_options = b'\332A\013name,inputs\202\323\344\223\002<\"7/v1beta/{name=organizations/*/pipelines/*}/triggerAsync:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateOrganizationPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateOrganizationPipelineRelease']._serialized_options = b'\332A\016parent,release\202\323\344\223\002@\"5/v1beta/{parent=organizations/*/pipelines/*}/releases:\007release'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListOrganizationPipelineReleases']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListOrganizationPipelineReleases']._serialized_options = b'\332A\tpipelines\202\323\344\223\0027\0225/v1beta/{parent=organizations/*/pipelines/*}/releases'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOrganizationPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOrganizationPipelineRelease']._serialized_options = b'\332A\004name\202\323\344\223\0027\0225/v1beta/{name=organizations/*/pipelines/*/releases/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateOrganizationPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateOrganizationPipelineRelease']._serialized_options = b'\332A\023release,update_mask\202\323\344\223\002H2=/v1beta/{release.name=organizations/*/pipelines/*/releases/*}:\007release'
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteOrganizationPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteOrganizationPipelineRelease']._serialized_options = b'\332A\004name\202\323\344\223\0027*5/v1beta/{name=organizations/*/pipelines/*/releases/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['RestoreOrganizationPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['RestoreOrganizationPipelineRelease']._serialized_options = b'\332A\004name\202\323\344\223\002?\"=/v1beta/{name=organizations/*/pipelines/*/releases/*}/restore'
  _PIPELINEPUBLICSERVICE.methods_by_name['WatchOrganizationPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['WatchOrganizationPipelineRelease']._serialized_options = b'\332A\004name\202\323\344\223\002=\022;/v1beta/{name=organizations/*/pipelines/*/releases/*}/watch'
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameOrganizationPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameOrganizationPipelineRelease']._serialized_options = b'\332A\034name,new_pipeline_release_id\202\323\344\223\002A\"</v1beta/{name=organizations/*/pipelines/*/releases/*}/rename:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerOrganizationPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerOrganizationPipelineRelease']._serialized_options = b'\332A\013name,inputs\202\323\344\223\002B\"=/v1beta/{name=organizations/*/pipelines/*/releases/*}/trigger:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncOrganizationPipelineRelease']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TriggerAsyncOrganizationPipelineRelease']._serialized_options = b'\332A\013name,inputs\202\323\344\223\002G\"B/v1beta/{name=organizations/*/pipelines/*/releases/*}/triggerAsync:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOperation']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOperation']._serialized_options = b'\332A\004name\202\323\344\223\002\035\022\033/v1beta/{name=operations/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListConnectorDefinitions']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListConnectorDefinitions']._serialized_options = b'\202\323\344\223\002\037\022\035/v1beta/connector-definitions'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetConnectorDefinition']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetConnectorDefinition']._serialized_options = b'\332A\004name\202\323\344\223\002(\022&/v1beta/{name=connector-definitions/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListOperatorDefinitions']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListOperatorDefinitions']._serialized_options = b'\202\323\344\223\002\036\022\034/v1beta/operator-definitions'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOperatorDefinition']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOperatorDefinition']._serialized_options = b'\332A\004name\202\323\344\223\002\'\022%/v1beta/{name=operator-definitions/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListConnectors']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListConnectors']._serialized_options = b'\202\323\344\223\002\024\022\022/v1beta/connectors'
  _PIPELINEPUBLICSERVICE.methods_by_name['LookUpConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['LookUpConnector']._serialized_options = b'\332A\tpermalink\202\323\344\223\002)\022\'/v1beta/{permalink=connectors/*}/lookUp'
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateUserConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateUserConnector']._serialized_options = b'\332A\020parent,connector\202\323\344\223\0020\"#/v1beta/{parent=users/*}/connectors:\tconnector'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListUserConnectors']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListUserConnectors']._serialized_options = b'\332A\006parent\202\323\344\223\002%\022#/v1beta/{parent=users/*}/connectors'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetUserConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetUserConnector']._serialized_options = b'\332A\004name\202\323\344\223\002%\022#/v1beta/{name=users/*/connectors/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateUserConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateUserConnector']._serialized_options = b'\332A\025connector,update_mask\202\323\344\223\002:2-/v1beta/{connector.name=users/*/connectors/*}:\tconnector'
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteUserConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteUserConnector']._serialized_options = b'\332A\004name\202\323\344\223\002%*#/v1beta/{name=users/*/connectors/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['ConnectUserConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ConnectUserConnector']._serialized_options = b'\332A\004name\202\323\344\223\0020\"+/v1beta/{name=users/*/connectors/*}/connect:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['DisconnectUserConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['DisconnectUserConnector']._serialized_options = b'\332A\004name\202\323\344\223\0023\"./v1beta/{name=users/*/connectors/*}/disconnect:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameUserConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameUserConnector']._serialized_options = b'\332A\025name,new_connector_id\202\323\344\223\002/\"*/v1beta/{name=users/*/connectors/*}/rename:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['ExecuteUserConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ExecuteUserConnector']._serialized_options = b'\332A\004name\202\323\344\223\0020\"+/v1beta/{name=users/*/connectors/*}/execute:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['WatchUserConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['WatchUserConnector']._serialized_options = b'\332A\004name\202\323\344\223\002+\022)/v1beta/{name=users/*/connectors/*}/watch'
  _PIPELINEPUBLICSERVICE.methods_by_name['TestUserConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TestUserConnector']._serialized_options = b'\332A\004name\202\323\344\223\0024\"2/v1beta/{name=users/*/connectors/*}/testConnection'
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateOrganizationConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CreateOrganizationConnector']._serialized_options = b'\332A\020parent,connector\202\323\344\223\0028\"+/v1beta/{parent=organizations/*}/connectors:\tconnector'
  _PIPELINEPUBLICSERVICE.methods_by_name['ListOrganizationConnectors']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ListOrganizationConnectors']._serialized_options = b'\332A\006parent\202\323\344\223\002-\022+/v1beta/{parent=organizations/*}/connectors'
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOrganizationConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['GetOrganizationConnector']._serialized_options = b'\332A\004name\202\323\344\223\002-\022+/v1beta/{name=organizations/*/connectors/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateOrganizationConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['UpdateOrganizationConnector']._serialized_options = b'\332A\025connector,update_mask\202\323\344\223\002B25/v1beta/{connector.name=organizations/*/connectors/*}:\tconnector'
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteOrganizationConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['DeleteOrganizationConnector']._serialized_options = b'\332A\004name\202\323\344\223\002-*+/v1beta/{name=organizations/*/connectors/*}'
  _PIPELINEPUBLICSERVICE.methods_by_name['ConnectOrganizationConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ConnectOrganizationConnector']._serialized_options = b'\332A\004name\202\323\344\223\0028\"3/v1beta/{name=organizations/*/connectors/*}/connect:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['DisconnectOrganizationConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['DisconnectOrganizationConnector']._serialized_options = b'\332A\004name\202\323\344\223\002;\"6/v1beta/{name=organizations/*/connectors/*}/disconnect:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameOrganizationConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['RenameOrganizationConnector']._serialized_options = b'\332A\025name,new_connector_id\202\323\344\223\0027\"2/v1beta/{name=organizations/*/connectors/*}/rename:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['ExecuteOrganizationConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['ExecuteOrganizationConnector']._serialized_options = b'\332A\004name\202\323\344\223\0028\"3/v1beta/{name=organizations/*/connectors/*}/execute:\001*'
  _PIPELINEPUBLICSERVICE.methods_by_name['WatchOrganizationConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['WatchOrganizationConnector']._serialized_options = b'\332A\004name\202\323\344\223\0023\0221/v1beta/{name=organizations/*/connectors/*}/watch'
  _PIPELINEPUBLICSERVICE.methods_by_name['TestOrganizationConnector']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['TestOrganizationConnector']._serialized_options = b'\332A\004name\202\323\344\223\002<\":/v1beta/{name=organizations/*/connectors/*}/testConnection'
  _PIPELINEPUBLICSERVICE.methods_by_name['CheckName']._options = None
  _PIPELINEPUBLICSERVICE.methods_by_name['CheckName']._serialized_options = b'\332A\004name\202\323\344\223\002\027\"\022/v1beta/check-name:\001*'
  _globals['_PIPELINEPUBLICSERVICE']._serialized_start=409
  _globals['_PIPELINEPUBLICSERVICE']._serialized_end=15611
# @@protoc_insertion_point(module_scope)
