# generated by datamodel-codegen:
#   filename:  instill_task_semantic_segmentation_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import List


@dataclass
class Object:
    category: str
    rle: str


@dataclass
class Model:
    stuffs: List[Object]
