# generated by datamodel-codegen:
#   filename:  instill_task_classification_output.json

from __future__ import annotations

from dataclasses import dataclass


@dataclass
class Model:
    category: str
    score: float
