# generated by datamodel-codegen:
#   filename:  openai_task_speech_recognition_input.json

from __future__ import annotations

from dataclasses import dataclass
from enum import Enum
from typing import Optional


class Model(Enum):
    whisper_1 = 'whisper-1'


@dataclass
class Input:
    audio: bytes
    model: Model
    language: Optional[str] = None
    prompt: Optional[str] = None
    temperature: Optional[float] = 0
