# generated by datamodel-codegen:
#   filename:  googlesearch_task_search_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import List, Optional


@dataclass
class Result:
    link: str
    snippet: str
    title: str
    link_html: Optional[str] = None
    link_text: Optional[str] = None


@dataclass
class Output:
    results: List[Result]
