# generated by datamodel-codegen:
#   filename:  huggingface_task_translation_output.json

from __future__ import annotations

from dataclasses import dataclass


@dataclass
class Output:
    translation_text: str
