# generated by datamodel-codegen:
#   filename:  image_task_draw_classification_input.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Optional


@dataclass
class Input:
    category: str
    image: str
    score: float
    showScore: Optional[bool] = None
