# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core/mgmt/v1beta/mgmt_private_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from core.mgmt.v1beta import mgmt_pb2 as core_dot_mgmt_dot_v1beta_dot_mgmt__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+core/mgmt/v1beta/mgmt_private_service.proto\x12\x10\x63ore.mgmt.v1beta\x1a\x1b\x63ore/mgmt/v1beta/mgmt.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1bgoogle/api/visibility.proto2\x98\x0b\n\x12MgmtPrivateService\x12\x80\x01\n\x0eListUsersAdmin\x12\'.core.mgmt.v1beta.ListUsersAdminRequest\x1a(.core.mgmt.v1beta.ListUsersAdminResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/v1beta/admin/users\x12\x8a\x01\n\x0cGetUserAdmin\x12%.core.mgmt.v1beta.GetUserAdminRequest\x1a&.core.mgmt.v1beta.GetUserAdminResponse\"+\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1beta/admin/{name=users/*}\x12\xa4\x01\n\x0fLookUpUserAdmin\x12(.core.mgmt.v1beta.LookUpUserAdminRequest\x1a).core.mgmt.v1beta.LookUpUserAdminResponse\"<\xda\x41\tpermalink\x82\xd3\xe4\x93\x02*\x12(/v1beta/admin/{permalink=users/*}/lookUp\x12\xa0\x01\n\x16ListOrganizationsAdmin\x12/.core.mgmt.v1beta.ListOrganizationsAdminRequest\x1a\x30.core.mgmt.v1beta.ListOrganizationsAdminResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1beta/admin/organizations\x12\xaa\x01\n\x14GetOrganizationAdmin\x12-.core.mgmt.v1beta.GetOrganizationAdminRequest\x1a..core.mgmt.v1beta.GetOrganizationAdminResponse\"3\xda\x41\x04name\x82\xd3\xe4\x93\x02&\x12$/v1beta/admin/{name=organizations/*}\x12\xc4\x01\n\x17LookUpOrganizationAdmin\x12\x30.core.mgmt.v1beta.LookUpOrganizationAdminRequest\x1a\x31.core.mgmt.v1beta.LookUpOrganizationAdminResponse\"D\xda\x41\tpermalink\x82\xd3\xe4\x93\x02\x32\x12\x30/v1beta/admin/{permalink=organizations/*}/lookUp\x12\xbf\x01\n\x18GetUserSubscriptionAdmin\x12\x31.core.mgmt.v1beta.GetUserSubscriptionAdminRequest\x1a\x32.core.mgmt.v1beta.GetUserSubscriptionAdminResponse\"<\xda\x41\x06parent\x82\xd3\xe4\x93\x02-\x12+/v1beta/admin/{parent=users/*}/subscription\x12\xdf\x01\n GetOrganizationSubscriptionAdmin\x12\x39.core.mgmt.v1beta.GetOrganizationSubscriptionAdminRequest\x1a:.core.mgmt.v1beta.GetOrganizationSubscriptionAdminResponse\"D\xda\x41\x06parent\x82\xd3\xe4\x93\x02\x35\x12\x33/v1beta/admin/{parent=organizations/*}/subscription\x1a\x10\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNALB\xd0\x01\n\x14\x63om.core.mgmt.v1betaB\x17MgmtPrivateServiceProtoP\x01Z=github.com/instill-ai/protogen-go/core/mgmt/v1beta;mgmtv1beta\xa2\x02\x03\x43MX\xaa\x02\x10\x43ore.Mgmt.V1beta\xca\x02\x10\x43ore\\Mgmt\\V1beta\xe2\x02\x1c\x43ore\\Mgmt\\V1beta\\GPBMetadata\xea\x02\x12\x43ore::Mgmt::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core.mgmt.v1beta.mgmt_private_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024com.core.mgmt.v1betaB\027MgmtPrivateServiceProtoP\001Z=github.com/instill-ai/protogen-go/core/mgmt/v1beta;mgmtv1beta\242\002\003CMX\252\002\020Core.Mgmt.V1beta\312\002\020Core\\Mgmt\\V1beta\342\002\034Core\\Mgmt\\V1beta\\GPBMetadata\352\002\022Core::Mgmt::V1beta'
  _MGMTPRIVATESERVICE._options = None
  _MGMTPRIVATESERVICE._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL'
  _MGMTPRIVATESERVICE.methods_by_name['ListUsersAdmin']._options = None
  _MGMTPRIVATESERVICE.methods_by_name['ListUsersAdmin']._serialized_options = b'\202\323\344\223\002\025\022\023/v1beta/admin/users'
  _MGMTPRIVATESERVICE.methods_by_name['GetUserAdmin']._options = None
  _MGMTPRIVATESERVICE.methods_by_name['GetUserAdmin']._serialized_options = b'\332A\004name\202\323\344\223\002\036\022\034/v1beta/admin/{name=users/*}'
  _MGMTPRIVATESERVICE.methods_by_name['LookUpUserAdmin']._options = None
  _MGMTPRIVATESERVICE.methods_by_name['LookUpUserAdmin']._serialized_options = b'\332A\tpermalink\202\323\344\223\002*\022(/v1beta/admin/{permalink=users/*}/lookUp'
  _MGMTPRIVATESERVICE.methods_by_name['ListOrganizationsAdmin']._options = None
  _MGMTPRIVATESERVICE.methods_by_name['ListOrganizationsAdmin']._serialized_options = b'\202\323\344\223\002\035\022\033/v1beta/admin/organizations'
  _MGMTPRIVATESERVICE.methods_by_name['GetOrganizationAdmin']._options = None
  _MGMTPRIVATESERVICE.methods_by_name['GetOrganizationAdmin']._serialized_options = b'\332A\004name\202\323\344\223\002&\022$/v1beta/admin/{name=organizations/*}'
  _MGMTPRIVATESERVICE.methods_by_name['LookUpOrganizationAdmin']._options = None
  _MGMTPRIVATESERVICE.methods_by_name['LookUpOrganizationAdmin']._serialized_options = b'\332A\tpermalink\202\323\344\223\0022\0220/v1beta/admin/{permalink=organizations/*}/lookUp'
  _MGMTPRIVATESERVICE.methods_by_name['GetUserSubscriptionAdmin']._options = None
  _MGMTPRIVATESERVICE.methods_by_name['GetUserSubscriptionAdmin']._serialized_options = b'\332A\006parent\202\323\344\223\002-\022+/v1beta/admin/{parent=users/*}/subscription'
  _MGMTPRIVATESERVICE.methods_by_name['GetOrganizationSubscriptionAdmin']._options = None
  _MGMTPRIVATESERVICE.methods_by_name['GetOrganizationSubscriptionAdmin']._serialized_options = b'\332A\006parent\202\323\344\223\0025\0223/v1beta/admin/{parent=organizations/*}/subscription'
  _globals['_MGMTPRIVATESERVICE']._serialized_start=179
  _globals['_MGMTPRIVATESERVICE']._serialized_end=1611
# @@protoc_insertion_point(module_scope)
