# generated by datamodel-codegen:
#   filename:  text_task_convert_to_text_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Any, Dict


@dataclass
class Output:
    body: str
    error: str
    meta: Dict[str, Any]
    msecs: float
