# generated by datamodel-codegen:
#   filename:  redis_task_chat_message_write_multi_modal_output.json

from __future__ import annotations

from dataclasses import dataclass


@dataclass
class Output:
    status: bool
