# generated by datamodel-codegen:
#   filename:  openai_definitions.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Optional


@dataclass
class OpenAIConnectorResource:
    api_key: str
    organization: Optional[str] = None
