# generated by datamodel-codegen:
#   filename:  numbers_definitions.json

from __future__ import annotations

from dataclasses import dataclass


@dataclass
class NumbersProtocolBlockchainConnectorSpec:
    capture_token: str
