# generated by datamodel-codegen:
#   filename:  pinecone_task_query_input.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Any, Dict, List, Optional


@dataclass
class Input:
    vector: List[float]
    top_k: int
    id: Optional[str] = None
    namespace: Optional[str] = None
    filter: Optional[Dict[str, Any]] = None
    min_score: Optional[float] = None
    include_metadata: Optional[bool] = False
    include_values: Optional[bool] = False
