# generated by datamodel-codegen:
#   filename:  airbyte_task_write_destination_input.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Any, Dict


@dataclass
class Input:
    data: Dict[str, Any]
