# generated by datamodel-codegen:
#   filename:  redis_task_chat_history_retrieve_input.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Optional


@dataclass
class Input:
    session_id: str
    include_system_message: Optional[bool] = True
    latest_k: Optional[int] = 5
