# generated by datamodel-codegen:
#   filename:  pinecone_task_query_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Any, Dict, List, Optional


@dataclass
class Match:
    id: str
    score: float
    metadata: Optional[Dict[str, Any]] = None
    values: Optional[List[float]] = None


@dataclass
class Output:
    matches: List[Match]
    namespace: str
