# generated by datamodel-codegen:
#   filename:  stabilityai_definitions.json

from __future__ import annotations

from dataclasses import dataclass


@dataclass
class StabilityAIConnectorResource:
    api_key: str
