# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model/controller/v1alpha/controller.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.healthcheck.v1beta import healthcheck_pb2 as common_dot_healthcheck_dot_v1beta_dot_healthcheck__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from model.model.v1alpha import model_pb2 as model_dot_model_dot_v1alpha_dot_model__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)model/controller/v1alpha/controller.proto\x12\x18model.controller.v1alpha\x1a+common/healthcheck/v1beta/healthcheck.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1fmodel/model/v1alpha/model.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\"\x96\x01\n\x0fLivenessRequest\x12j\n\x14health_check_request\x18\x01 \x01(\x0b\x32-.common.healthcheck.v1beta.HealthCheckRequestB\x04\xe2\x41\x01\x01H\x00R\x12healthCheckRequest\x88\x01\x01\x42\x17\n\x15_health_check_request\"v\n\x10LivenessResponse\x12\x62\n\x15health_check_response\x18\x01 \x01(\x0b\x32..common.healthcheck.v1beta.HealthCheckResponseR\x13healthCheckResponse\"\x97\x01\n\x10ReadinessRequest\x12j\n\x14health_check_request\x18\x01 \x01(\x0b\x32-.common.healthcheck.v1beta.HealthCheckRequestB\x04\xe2\x41\x01\x01H\x00R\x12healthCheckRequest\x88\x01\x01\x42\x17\n\x15_health_check_request\"w\n\x11ReadinessResponse\x12\x62\n\x15health_check_response\x18\x01 \x01(\x0b\x32..common.healthcheck.v1beta.HealthCheckResponseR\x13healthCheckResponse\"\xaa\x03\n\x08Resource\x12\x33\n\x12resource_permalink\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x11resourcePermalink\x12\x43\n\x0bmodel_state\x18\x02 \x01(\x0e\x32 .model.model.v1alpha.Model.StateH\x00R\nmodelState\x12\x63\n\rbackend_state\x18\x05 \x01(\x0e\x32<.common.healthcheck.v1beta.HealthCheckResponse.ServingStatusH\x00R\x0c\x62\x61\x63kendState\x12%\n\x08progress\x18\x06 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x01R\x08progress\x88\x01\x01\x12*\n\x0bworkflow_id\x18\x07 \x01(\tB\x04\xe2\x41\x01\x01H\x02R\nworkflowId\x88\x01\x01:F\xea\x41\x43\n\x19\x61pi.instill.tech/Resource\x12&resources/{resource_uuid}/types/{type}B\x07\n\x05stateB\x0b\n\t_progressB\x0e\n\x0c_workflow_id\"\x8b\x01\n\x12GetResourceRequest\x12u\n\x12resource_permalink\x18\x01 \x01(\tBF\x92\x41!\xca>\x1e\xfa\x02\x1bresource.resource_permalink\xe2\x41\x01\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/ResourceR\x11resourcePermalink\"U\n\x13GetResourceResponse\x12>\n\x08resource\x18\x01 \x01(\x0b\x32\".model.controller.v1alpha.ResourceR\x08resource\"]\n\x15UpdateResourceRequest\x12\x44\n\x08resource\x18\x01 \x01(\x0b\x32\".model.controller.v1alpha.ResourceB\x04\xe2\x41\x01\x02R\x08resource\"X\n\x16UpdateResourceResponse\x12>\n\x08resource\x18\x01 \x01(\x0b\x32\".model.controller.v1alpha.ResourceR\x08resource\"\x8e\x01\n\x15\x44\x65leteResourceRequest\x12u\n\x12resource_permalink\x18\x01 \x01(\tBF\x92\x41!\xca>\x1e\xfa\x02\x1bresource.resource_permalink\xe2\x41\x01\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/ResourceR\x11resourcePermalink\"\x18\n\x16\x44\x65leteResourceResponseB\xff\x01\n\x1c\x63om.model.controller.v1alphaB\x0f\x43ontrollerProtoP\x01ZLgithub.com/instill-ai/protogen-go/model/controller/v1alpha;controllerv1alpha\xa2\x02\x03MCX\xaa\x02\x18Model.Controller.V1alpha\xca\x02\x18Model\\Controller\\V1alpha\xe2\x02$Model\\Controller\\V1alpha\\GPBMetadata\xea\x02\x1aModel::Controller::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model.controller.v1alpha.controller_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.model.controller.v1alphaB\017ControllerProtoP\001ZLgithub.com/instill-ai/protogen-go/model/controller/v1alpha;controllerv1alpha\242\002\003MCX\252\002\030Model.Controller.V1alpha\312\002\030Model\\Controller\\V1alpha\342\002$Model\\Controller\\V1alpha\\GPBMetadata\352\002\032Model::Controller::V1alpha'
  _LIVENESSREQUEST.fields_by_name['health_check_request']._options = None
  _LIVENESSREQUEST.fields_by_name['health_check_request']._serialized_options = b'\342A\001\001'
  _READINESSREQUEST.fields_by_name['health_check_request']._options = None
  _READINESSREQUEST.fields_by_name['health_check_request']._serialized_options = b'\342A\001\001'
  _RESOURCE.fields_by_name['resource_permalink']._options = None
  _RESOURCE.fields_by_name['resource_permalink']._serialized_options = b'\342A\001\002'
  _RESOURCE.fields_by_name['progress']._options = None
  _RESOURCE.fields_by_name['progress']._serialized_options = b'\342A\001\001'
  _RESOURCE.fields_by_name['workflow_id']._options = None
  _RESOURCE.fields_by_name['workflow_id']._serialized_options = b'\342A\001\001'
  _RESOURCE._options = None
  _RESOURCE._serialized_options = b'\352AC\n\031api.instill.tech/Resource\022&resources/{resource_uuid}/types/{type}'
  _GETRESOURCEREQUEST.fields_by_name['resource_permalink']._options = None
  _GETRESOURCEREQUEST.fields_by_name['resource_permalink']._serialized_options = b'\222A!\312>\036\372\002\033resource.resource_permalink\342A\001\002\372A\033\n\031api.instill.tech/Resource'
  _UPDATERESOURCEREQUEST.fields_by_name['resource']._options = None
  _UPDATERESOURCEREQUEST.fields_by_name['resource']._serialized_options = b'\342A\001\002'
  _DELETERESOURCEREQUEST.fields_by_name['resource_permalink']._options = None
  _DELETERESOURCEREQUEST.fields_by_name['resource_permalink']._serialized_options = b'\222A!\312>\036\372\002\033resource.resource_permalink\342A\001\002\372A\033\n\031api.instill.tech/Resource'
  _globals['_LIVENESSREQUEST']._serialized_start=258
  _globals['_LIVENESSREQUEST']._serialized_end=408
  _globals['_LIVENESSRESPONSE']._serialized_start=410
  _globals['_LIVENESSRESPONSE']._serialized_end=528
  _globals['_READINESSREQUEST']._serialized_start=531
  _globals['_READINESSREQUEST']._serialized_end=682
  _globals['_READINESSRESPONSE']._serialized_start=684
  _globals['_READINESSRESPONSE']._serialized_end=803
  _globals['_RESOURCE']._serialized_start=806
  _globals['_RESOURCE']._serialized_end=1232
  _globals['_GETRESOURCEREQUEST']._serialized_start=1235
  _globals['_GETRESOURCEREQUEST']._serialized_end=1374
  _globals['_GETRESOURCERESPONSE']._serialized_start=1376
  _globals['_GETRESOURCERESPONSE']._serialized_end=1461
  _globals['_UPDATERESOURCEREQUEST']._serialized_start=1463
  _globals['_UPDATERESOURCEREQUEST']._serialized_end=1556
  _globals['_UPDATERESOURCERESPONSE']._serialized_start=1558
  _globals['_UPDATERESOURCERESPONSE']._serialized_end=1646
  _globals['_DELETERESOURCEREQUEST']._serialized_start=1649
  _globals['_DELETERESOURCEREQUEST']._serialized_end=1791
  _globals['_DELETERESOURCERESPONSE']._serialized_start=1793
  _globals['_DELETERESOURCERESPONSE']._serialized_end=1817
# @@protoc_insertion_point(module_scope)
