# generated by datamodel-codegen:
#   filename:  pinecone_task_upsert_output.json

from __future__ import annotations

from dataclasses import dataclass


@dataclass
class Output:
    upserted_count: int
