# generated by datamodel-codegen:
#   filename:  huggingface_task_object_detection_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import List


@dataclass
class Box:
    xmax: float
    xmin: float
    ymax: float
    ymin: float


@dataclass
class Object:
    box: Box
    label: str
    score: float


@dataclass
class Output:
    objects: List[Object]
