# generated by datamodel-codegen:
#   filename:  start_task_start_metadata.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Dict, Optional


@dataclass
class Items:
    instillFormat: str
    type: str


@dataclass
class MetadataItem:
    instillFormat: str
    type: str
    description: Optional[str] = None
    items: Optional[Items] = None
    title: Optional[str] = None


Metadata = Dict[str, MetadataItem]
