# generated by datamodel-codegen:
#   filename:  bigquery_definitions.json

from __future__ import annotations

from dataclasses import dataclass


@dataclass
class BigQueryConnectorSpec:
    dataset_id: str
    json_key: str
    project_id: str
    table_name: str
