# generated by datamodel-codegen:
#   filename:  pinecone_task_upsert_input.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Any, Dict, List, Optional


@dataclass
class Input:
    id: str
    values: List[float]
    metadata: Optional[Dict[str, Any]] = None
    namespace: Optional[str] = None
