# generated by datamodel-codegen:
#   filename:  openai_task_text_embeddings_input.json

from __future__ import annotations

from dataclasses import dataclass
from enum import Enum


class Model(Enum):
    text_embedding_ada_002 = 'text-embedding-ada-002'


@dataclass
class Input:
    model: Model
    text: str
