# generated by datamodel-codegen:
#   filename:  website_task_scrape_website_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import List, Optional


@dataclass
class PageInformation:
    link: str
    link_html: Optional[str] = None
    link_text: Optional[str] = None
    title: Optional[str] = None


@dataclass
class Output:
    pages: List[PageInformation]
