# generated by datamodel-codegen:
#   filename:  huggingface_task_image_segmentation_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import List


@dataclass
class Segment:
    label: str
    mask: str
    score: float


@dataclass
class Output:
    segments: List[Segment]
