# generated by datamodel-codegen:
#   filename:  huggingface_task_question_answering_input.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Optional


@dataclass
class Inputs:
    context: str
    question: str


@dataclass
class Options:
    use_cache: Optional[bool] = None
    wait_for_model: Optional[bool] = None


@dataclass
class Input:
    inputs: Inputs
    model: Optional[str] = None
    options: Optional[Options] = None
