# generated by datamodel-codegen:
#   filename:  openai_task_text_to_speech_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Optional


@dataclass
class Output:
    audio: Optional[str] = None
