# generated by datamodel-codegen:
#   filename:  huggingface_task_zero_shot_classification_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import List, Optional


@dataclass
class Output:
    labels: List[str]
    scores: List[float]
    sequence: Optional[str] = None
