# generated by datamodel-codegen:
#   filename:  googlecloudstorage_task_upload_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Optional


@dataclass
class Output:
    status: str
    authenticated_url: Optional[str] = None
    gsutil_uri: Optional[str] = None
    public_access: Optional[bool] = None
    public_url: Optional[str] = None
