# generated by datamodel-codegen:
#   filename:  huggingface_task_conversational_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import List, Optional


@dataclass
class Conversation:
    generated_responses: List[str]
    past_user_inputs: List[str]


@dataclass
class Output:
    generated_text: str
    conversation: Optional[Conversation] = None
