# generated by datamodel-codegen:
#   filename:  pinecone_definitions.json

from __future__ import annotations

from dataclasses import dataclass


@dataclass
class PineconeConnectorSpec:
    api_key: str
    url: str
