# generated by datamodel-codegen:
#   filename:  huggingface_task_sentence_similarity_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import List


@dataclass
class Output:
    scores: List[float]
