# generated by datamodel-codegen:
#   filename:  redis_task_chat_message_write_input.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Any, Dict, Optional


@dataclass
class Input:
    content: str
    role: str
    session_id: str
    metadata: Optional[Dict[str, Any]] = None
