# generated by datamodel-codegen:
#   filename:  huggingface_definitions.json

from __future__ import annotations

from dataclasses import dataclass


@dataclass
class HuggingFaceConnectorSpec:
    api_key: str
    base_url: str
    is_custom_endpoint: bool
