# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model/model/v1alpha/model_public_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from model.model.v1alpha import model_pb2 as model_dot_model_dot_v1alpha_dot_model__pb2
from model.model.v1alpha import model_definition_pb2 as model_dot_model_dot_v1alpha_dot_model__definition__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.model/model/v1alpha/model_public_service.proto\x12\x13model.model.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1fmodel/model/v1alpha/model.proto\x1a*model/model/v1alpha/model_definition.proto\x1a.protoc-gen-openapiv2/options/annotations.proto2\xad\x35\n\x12ModelPublicService\x12\x9d\x01\n\x08Liveness\x12$.model.model.v1alpha.LivenessRequest\x1a%.model.model.v1alpha.LivenessResponse\"D\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02.\x12\x13/v1alpha/__livenessZ\x17\x12\x15/v1alpha/health/model\x12\xa0\x01\n\tReadiness\x12%.model.model.v1alpha.ReadinessRequest\x1a&.model.model.v1alpha.ReadinessResponse\"D\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02.\x12\x14/v1alpha/__readinessZ\x16\x12\x14/v1alpha/ready/model\x12\x9f\x01\n\x14ListModelDefinitions\x12\x30.model.model.v1alpha.ListModelDefinitionsRequest\x1a\x31.model.model.v1alpha.ListModelDefinitionsResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1alpha/model-definitions\x12\xa9\x01\n\x12GetModelDefinition\x12..model.model.v1alpha.GetModelDefinitionRequest\x1a/.model.model.v1alpha.GetModelDefinitionResponse\"2\xda\x41\x04name\x82\xd3\xe4\x93\x02%\x12#/v1alpha/{name=model-definitions/*}\x12v\n\nListModels\x12&.model.model.v1alpha.ListModelsRequest\x1a\'.model.model.v1alpha.ListModelsResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1alpha/models\x12\x9a\x01\n\x0bLookUpModel\x12\'.model.model.v1alpha.LookUpModelRequest\x1a(.model.model.v1alpha.LookUpModelResponse\"8\xda\x41\tpermalink\x82\xd3\xe4\x93\x02&\x12$/v1alpha/{permalink=models/*}/lookUp\x12\x9c\x01\n\x0eListUserModels\x12*.model.model.v1alpha.ListUserModelsRequest\x1a+.model.model.v1alpha.ListUserModelsResponse\"1\xda\x41\x06parent\x82\xd3\xe4\x93\x02\"\x12 /v1alpha/{parent=users/*}/models\x12\xac\x01\n\x0f\x43reateUserModel\x12+.model.model.v1alpha.CreateUserModelRequest\x1a,.model.model.v1alpha.CreateUserModelResponse\">\xda\x41\x0cparent,model\x82\xd3\xe4\x93\x02)\" /v1alpha/{parent=users/*}/models:\x05model\x12\xc5\x01\n\x1f\x43reateUserModelBinaryFileUpload\x12;.model.model.v1alpha.CreateUserModelBinaryFileUploadRequest\x1a<.model.model.v1alpha.CreateUserModelBinaryFileUploadResponse\"%\xda\x41\"id,model_definition,content,parent(\x01\x12\x94\x01\n\x0cGetUserModel\x12(.model.model.v1alpha.GetUserModelRequest\x1a).model.model.v1alpha.GetUserModelResponse\"/\xda\x41\x04name\x82\xd3\xe4\x93\x02\"\x12 /v1alpha/{name=users/*/models/*}\x12\xb7\x01\n\x0fUpdateUserModel\x12+.model.model.v1alpha.UpdateUserModelRequest\x1a,.model.model.v1alpha.UpdateUserModelResponse\"I\xda\x41\x11model,update_mask\x82\xd3\xe4\x93\x02/2&/v1alpha/{model.name=users/*/models/*}:\x05model\x12\x9d\x01\n\x0f\x44\x65leteUserModel\x12+.model.model.v1alpha.DeleteUserModelRequest\x1a,.model.model.v1alpha.DeleteUserModelResponse\"/\xda\x41\x04name\x82\xd3\xe4\x93\x02\"* /v1alpha/{name=users/*/models/*}\x12\xb4\x01\n\x0fRenameUserModel\x12+.model.model.v1alpha.RenameUserModelRequest\x1a,.model.model.v1alpha.RenameUserModelResponse\"F\xda\x41\x11name,new_model_id\x82\xd3\xe4\x93\x02,\"\'/v1alpha/{name=users/*/models/*}/rename:\x01*\x12\xab\x01\n\x10PublishUserModel\x12,.model.model.v1alpha.PublishUserModelRequest\x1a-.model.model.v1alpha.PublishUserModelResponse\":\xda\x41\x04name\x82\xd3\xe4\x93\x02-\"(/v1alpha/{name=users/*/models/*}/publish:\x01*\x12\xb3\x01\n\x12UnpublishUserModel\x12..model.model.v1alpha.UnpublishUserModelRequest\x1a/.model.model.v1alpha.UnpublishUserModelResponse\"<\xda\x41\x04name\x82\xd3\xe4\x93\x02/\"*/v1alpha/{name=users/*/models/*}/unpublish:\x01*\x12\xa7\x01\n\x0f\x44\x65ployUserModel\x12+.model.model.v1alpha.DeployUserModelRequest\x1a,.model.model.v1alpha.DeployUserModelResponse\"9\xda\x41\x04name\x82\xd3\xe4\x93\x02,\"\'/v1alpha/{name=users/*/models/*}/deploy:\x01*\x12\xaf\x01\n\x11UndeployUserModel\x12-.model.model.v1alpha.UndeployUserModelRequest\x1a..model.model.v1alpha.UndeployUserModelResponse\";\xda\x41\x04name\x82\xd3\xe4\x93\x02.\")/v1alpha/{name=users/*/models/*}/undeploy:\x01*\x12\xa7\x01\n\x10GetUserModelCard\x12,.model.model.v1alpha.GetUserModelCardRequest\x1a-.model.model.v1alpha.GetUserModelCardResponse\"6\xda\x41\x04name\x82\xd3\xe4\x93\x02)\x12\'/v1alpha/{name=users/*/models/*/readme}\x12\xa0\x01\n\x0eWatchUserModel\x12*.model.model.v1alpha.WatchUserModelRequest\x1a+.model.model.v1alpha.WatchUserModelResponse\"5\xda\x41\x04name\x82\xd3\xe4\x93\x02(\x12&/v1alpha/{name=users/*/models/*}/watch\x12\xb2\x01\n\x10TriggerUserModel\x12,.model.model.v1alpha.TriggerUserModelRequest\x1a-.model.model.v1alpha.TriggerUserModelResponse\"A\xda\x41\x0bname,inputs\x82\xd3\xe4\x93\x02-\"(/v1alpha/{name=users/*/models/*}/trigger:\x01*\x12\xaf\x01\n TriggerUserModelBinaryFileUpload\x12<.model.model.v1alpha.TriggerUserModelBinaryFileUploadRequest\x1a=.model.model.v1alpha.TriggerUserModelBinaryFileUploadResponse\"\x0c\xda\x41\tname,file(\x01\x12\xbc\x01\n\x16ListOrganizationModels\x12\x32.model.model.v1alpha.ListOrganizationModelsRequest\x1a\x33.model.model.v1alpha.ListOrganizationModelsResponse\"9\xda\x41\x06parent\x82\xd3\xe4\x93\x02*\x12(/v1alpha/{parent=organizations/*}/models\x12\xcc\x01\n\x17\x43reateOrganizationModel\x12\x33.model.model.v1alpha.CreateOrganizationModelRequest\x1a\x34.model.model.v1alpha.CreateOrganizationModelResponse\"F\xda\x41\x0cparent,model\x82\xd3\xe4\x93\x02\x31\"(/v1alpha/{parent=organizations/*}/models:\x05model\x12\xdd\x01\n\'CreateOrganizationModelBinaryFileUpload\x12\x43.model.model.v1alpha.CreateOrganizationModelBinaryFileUploadRequest\x1a\x44.model.model.v1alpha.CreateOrganizationModelBinaryFileUploadResponse\"%\xda\x41\"id,model_definition,content,parent(\x01\x12\xb4\x01\n\x14GetOrganizationModel\x12\x30.model.model.v1alpha.GetOrganizationModelRequest\x1a\x31.model.model.v1alpha.GetOrganizationModelResponse\"7\xda\x41\x04name\x82\xd3\xe4\x93\x02*\x12(/v1alpha/{name=organizations/*/models/*}\x12\xd7\x01\n\x17UpdateOrganizationModel\x12\x33.model.model.v1alpha.UpdateOrganizationModelRequest\x1a\x34.model.model.v1alpha.UpdateOrganizationModelResponse\"Q\xda\x41\x11model,update_mask\x82\xd3\xe4\x93\x02\x37\x32./v1alpha/{model.name=organizations/*/models/*}:\x05model\x12\xbd\x01\n\x17\x44\x65leteOrganizationModel\x12\x33.model.model.v1alpha.DeleteOrganizationModelRequest\x1a\x34.model.model.v1alpha.DeleteOrganizationModelResponse\"7\xda\x41\x04name\x82\xd3\xe4\x93\x02**(/v1alpha/{name=organizations/*/models/*}\x12\xd4\x01\n\x17RenameOrganizationModel\x12\x33.model.model.v1alpha.RenameOrganizationModelRequest\x1a\x34.model.model.v1alpha.RenameOrganizationModelResponse\"N\xda\x41\x11name,new_model_id\x82\xd3\xe4\x93\x02\x34\"//v1alpha/{name=organizations/*/models/*}/rename:\x01*\x12\xcb\x01\n\x18PublishOrganizationModel\x12\x34.model.model.v1alpha.PublishOrganizationModelRequest\x1a\x35.model.model.v1alpha.PublishOrganizationModelResponse\"B\xda\x41\x04name\x82\xd3\xe4\x93\x02\x35\"0/v1alpha/{name=organizations/*/models/*}/publish:\x01*\x12\xd3\x01\n\x1aUnpublishOrganizationModel\x12\x36.model.model.v1alpha.UnpublishOrganizationModelRequest\x1a\x37.model.model.v1alpha.UnpublishOrganizationModelResponse\"D\xda\x41\x04name\x82\xd3\xe4\x93\x02\x37\"2/v1alpha/{name=organizations/*/models/*}/unpublish:\x01*\x12\xc7\x01\n\x17\x44\x65ployOrganizationModel\x12\x33.model.model.v1alpha.DeployOrganizationModelRequest\x1a\x34.model.model.v1alpha.DeployOrganizationModelResponse\"A\xda\x41\x04name\x82\xd3\xe4\x93\x02\x34\"//v1alpha/{name=organizations/*/models/*}/deploy:\x01*\x12\xcf\x01\n\x19UndeployOrganizationModel\x12\x35.model.model.v1alpha.UndeployOrganizationModelRequest\x1a\x36.model.model.v1alpha.UndeployOrganizationModelResponse\"C\xda\x41\x04name\x82\xd3\xe4\x93\x02\x36\"1/v1alpha/{name=organizations/*/models/*}/undeploy:\x01*\x12\xc7\x01\n\x18GetOrganizationModelCard\x12\x34.model.model.v1alpha.GetOrganizationModelCardRequest\x1a\x35.model.model.v1alpha.GetOrganizationModelCardResponse\">\xda\x41\x04name\x82\xd3\xe4\x93\x02\x31\x12//v1alpha/{name=organizations/*/models/*/readme}\x12\xc0\x01\n\x16WatchOrganizationModel\x12\x32.model.model.v1alpha.WatchOrganizationModelRequest\x1a\x33.model.model.v1alpha.WatchOrganizationModelResponse\"=\xda\x41\x04name\x82\xd3\xe4\x93\x02\x30\x12./v1alpha/{name=organizations/*/models/*}/watch\x12\xd2\x01\n\x18TriggerOrganizationModel\x12\x34.model.model.v1alpha.TriggerOrganizationModelRequest\x1a\x35.model.model.v1alpha.TriggerOrganizationModelResponse\"I\xda\x41\x0bname,inputs\x82\xd3\xe4\x93\x02\x35\"0/v1alpha/{name=organizations/*/models/*}/trigger:\x01*\x12\xc7\x01\n(TriggerOrganizationModelBinaryFileUpload\x12\x44.model.model.v1alpha.TriggerOrganizationModelBinaryFileUploadRequest\x1a\x45.model.model.v1alpha.TriggerOrganizationModelBinaryFileUploadResponse\"\x0c\xda\x41\tname,file(\x01\x12\x9f\x01\n\x11GetModelOperation\x12-.model.model.v1alpha.GetModelOperationRequest\x1a..model.model.v1alpha.GetModelOperationResponse\"+\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1alpha/{name=operations/*}\x1a\x1b\x92\x41\x18\x12\x16Public Model endpointsB\xe4\x01\n\x17\x63om.model.model.v1alphaB\x17ModelPublicServiceProtoP\x01ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\xa2\x02\x03MMX\xaa\x02\x13Model.Model.V1alpha\xca\x02\x13Model\\Model\\V1alpha\xe2\x02\x1fModel\\Model\\V1alpha\\GPBMetadata\xea\x02\x15Model::Model::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model.model.v1alpha.model_public_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.model.model.v1alphaB\027ModelPublicServiceProtoP\001ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\242\002\003MMX\252\002\023Model.Model.V1alpha\312\002\023Model\\Model\\V1alpha\342\002\037Model\\Model\\V1alpha\\GPBMetadata\352\002\025Model::Model::V1alpha'
  _MODELPUBLICSERVICE._options = None
  _MODELPUBLICSERVICE._serialized_options = b'\222A\030\022\026Public Model endpoints'
  _MODELPUBLICSERVICE.methods_by_name['Liveness']._options = None
  _MODELPUBLICSERVICE.methods_by_name['Liveness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002.\022\023/v1alpha/__livenessZ\027\022\025/v1alpha/health/model'
  _MODELPUBLICSERVICE.methods_by_name['Readiness']._options = None
  _MODELPUBLICSERVICE.methods_by_name['Readiness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002.\022\024/v1alpha/__readinessZ\026\022\024/v1alpha/ready/model'
  _MODELPUBLICSERVICE.methods_by_name['ListModelDefinitions']._options = None
  _MODELPUBLICSERVICE.methods_by_name['ListModelDefinitions']._serialized_options = b'\202\323\344\223\002\034\022\032/v1alpha/model-definitions'
  _MODELPUBLICSERVICE.methods_by_name['GetModelDefinition']._options = None
  _MODELPUBLICSERVICE.methods_by_name['GetModelDefinition']._serialized_options = b'\332A\004name\202\323\344\223\002%\022#/v1alpha/{name=model-definitions/*}'
  _MODELPUBLICSERVICE.methods_by_name['ListModels']._options = None
  _MODELPUBLICSERVICE.methods_by_name['ListModels']._serialized_options = b'\202\323\344\223\002\021\022\017/v1alpha/models'
  _MODELPUBLICSERVICE.methods_by_name['LookUpModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['LookUpModel']._serialized_options = b'\332A\tpermalink\202\323\344\223\002&\022$/v1alpha/{permalink=models/*}/lookUp'
  _MODELPUBLICSERVICE.methods_by_name['ListUserModels']._options = None
  _MODELPUBLICSERVICE.methods_by_name['ListUserModels']._serialized_options = b'\332A\006parent\202\323\344\223\002\"\022 /v1alpha/{parent=users/*}/models'
  _MODELPUBLICSERVICE.methods_by_name['CreateUserModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['CreateUserModel']._serialized_options = b'\332A\014parent,model\202\323\344\223\002)\" /v1alpha/{parent=users/*}/models:\005model'
  _MODELPUBLICSERVICE.methods_by_name['CreateUserModelBinaryFileUpload']._options = None
  _MODELPUBLICSERVICE.methods_by_name['CreateUserModelBinaryFileUpload']._serialized_options = b'\332A\"id,model_definition,content,parent'
  _MODELPUBLICSERVICE.methods_by_name['GetUserModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['GetUserModel']._serialized_options = b'\332A\004name\202\323\344\223\002\"\022 /v1alpha/{name=users/*/models/*}'
  _MODELPUBLICSERVICE.methods_by_name['UpdateUserModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['UpdateUserModel']._serialized_options = b'\332A\021model,update_mask\202\323\344\223\002/2&/v1alpha/{model.name=users/*/models/*}:\005model'
  _MODELPUBLICSERVICE.methods_by_name['DeleteUserModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['DeleteUserModel']._serialized_options = b'\332A\004name\202\323\344\223\002\"* /v1alpha/{name=users/*/models/*}'
  _MODELPUBLICSERVICE.methods_by_name['RenameUserModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['RenameUserModel']._serialized_options = b'\332A\021name,new_model_id\202\323\344\223\002,\"\'/v1alpha/{name=users/*/models/*}/rename:\001*'
  _MODELPUBLICSERVICE.methods_by_name['PublishUserModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['PublishUserModel']._serialized_options = b'\332A\004name\202\323\344\223\002-\"(/v1alpha/{name=users/*/models/*}/publish:\001*'
  _MODELPUBLICSERVICE.methods_by_name['UnpublishUserModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['UnpublishUserModel']._serialized_options = b'\332A\004name\202\323\344\223\002/\"*/v1alpha/{name=users/*/models/*}/unpublish:\001*'
  _MODELPUBLICSERVICE.methods_by_name['DeployUserModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['DeployUserModel']._serialized_options = b'\332A\004name\202\323\344\223\002,\"\'/v1alpha/{name=users/*/models/*}/deploy:\001*'
  _MODELPUBLICSERVICE.methods_by_name['UndeployUserModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['UndeployUserModel']._serialized_options = b'\332A\004name\202\323\344\223\002.\")/v1alpha/{name=users/*/models/*}/undeploy:\001*'
  _MODELPUBLICSERVICE.methods_by_name['GetUserModelCard']._options = None
  _MODELPUBLICSERVICE.methods_by_name['GetUserModelCard']._serialized_options = b'\332A\004name\202\323\344\223\002)\022\'/v1alpha/{name=users/*/models/*/readme}'
  _MODELPUBLICSERVICE.methods_by_name['WatchUserModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['WatchUserModel']._serialized_options = b'\332A\004name\202\323\344\223\002(\022&/v1alpha/{name=users/*/models/*}/watch'
  _MODELPUBLICSERVICE.methods_by_name['TriggerUserModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerUserModel']._serialized_options = b'\332A\013name,inputs\202\323\344\223\002-\"(/v1alpha/{name=users/*/models/*}/trigger:\001*'
  _MODELPUBLICSERVICE.methods_by_name['TriggerUserModelBinaryFileUpload']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerUserModelBinaryFileUpload']._serialized_options = b'\332A\tname,file'
  _MODELPUBLICSERVICE.methods_by_name['ListOrganizationModels']._options = None
  _MODELPUBLICSERVICE.methods_by_name['ListOrganizationModels']._serialized_options = b'\332A\006parent\202\323\344\223\002*\022(/v1alpha/{parent=organizations/*}/models'
  _MODELPUBLICSERVICE.methods_by_name['CreateOrganizationModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['CreateOrganizationModel']._serialized_options = b'\332A\014parent,model\202\323\344\223\0021\"(/v1alpha/{parent=organizations/*}/models:\005model'
  _MODELPUBLICSERVICE.methods_by_name['CreateOrganizationModelBinaryFileUpload']._options = None
  _MODELPUBLICSERVICE.methods_by_name['CreateOrganizationModelBinaryFileUpload']._serialized_options = b'\332A\"id,model_definition,content,parent'
  _MODELPUBLICSERVICE.methods_by_name['GetOrganizationModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['GetOrganizationModel']._serialized_options = b'\332A\004name\202\323\344\223\002*\022(/v1alpha/{name=organizations/*/models/*}'
  _MODELPUBLICSERVICE.methods_by_name['UpdateOrganizationModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['UpdateOrganizationModel']._serialized_options = b'\332A\021model,update_mask\202\323\344\223\00272./v1alpha/{model.name=organizations/*/models/*}:\005model'
  _MODELPUBLICSERVICE.methods_by_name['DeleteOrganizationModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['DeleteOrganizationModel']._serialized_options = b'\332A\004name\202\323\344\223\002**(/v1alpha/{name=organizations/*/models/*}'
  _MODELPUBLICSERVICE.methods_by_name['RenameOrganizationModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['RenameOrganizationModel']._serialized_options = b'\332A\021name,new_model_id\202\323\344\223\0024\"//v1alpha/{name=organizations/*/models/*}/rename:\001*'
  _MODELPUBLICSERVICE.methods_by_name['PublishOrganizationModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['PublishOrganizationModel']._serialized_options = b'\332A\004name\202\323\344\223\0025\"0/v1alpha/{name=organizations/*/models/*}/publish:\001*'
  _MODELPUBLICSERVICE.methods_by_name['UnpublishOrganizationModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['UnpublishOrganizationModel']._serialized_options = b'\332A\004name\202\323\344\223\0027\"2/v1alpha/{name=organizations/*/models/*}/unpublish:\001*'
  _MODELPUBLICSERVICE.methods_by_name['DeployOrganizationModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['DeployOrganizationModel']._serialized_options = b'\332A\004name\202\323\344\223\0024\"//v1alpha/{name=organizations/*/models/*}/deploy:\001*'
  _MODELPUBLICSERVICE.methods_by_name['UndeployOrganizationModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['UndeployOrganizationModel']._serialized_options = b'\332A\004name\202\323\344\223\0026\"1/v1alpha/{name=organizations/*/models/*}/undeploy:\001*'
  _MODELPUBLICSERVICE.methods_by_name['GetOrganizationModelCard']._options = None
  _MODELPUBLICSERVICE.methods_by_name['GetOrganizationModelCard']._serialized_options = b'\332A\004name\202\323\344\223\0021\022//v1alpha/{name=organizations/*/models/*/readme}'
  _MODELPUBLICSERVICE.methods_by_name['WatchOrganizationModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['WatchOrganizationModel']._serialized_options = b'\332A\004name\202\323\344\223\0020\022./v1alpha/{name=organizations/*/models/*}/watch'
  _MODELPUBLICSERVICE.methods_by_name['TriggerOrganizationModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerOrganizationModel']._serialized_options = b'\332A\013name,inputs\202\323\344\223\0025\"0/v1alpha/{name=organizations/*/models/*}/trigger:\001*'
  _MODELPUBLICSERVICE.methods_by_name['TriggerOrganizationModelBinaryFileUpload']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerOrganizationModelBinaryFileUpload']._serialized_options = b'\332A\tname,file'
  _MODELPUBLICSERVICE.methods_by_name['GetModelOperation']._options = None
  _MODELPUBLICSERVICE.methods_by_name['GetModelOperation']._serialized_options = b'\332A\004name\202\323\344\223\002\036\022\034/v1alpha/{name=operations/*}'
  _globals['_MODELPUBLICSERVICE']._serialized_start=281
  _globals['_MODELPUBLICSERVICE']._serialized_end=7110
# @@protoc_insertion_point(module_scope)
