# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core/mgmt/v1beta/metric.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63ore/mgmt/v1beta/metric.proto\x12\x10\x63ore.mgmt.v1beta\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe5\x03\n\x15PipelineTriggerRecord\x12=\n\x0ctrigger_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0btriggerTime\x12.\n\x13pipeline_trigger_id\x18\x02 \x01(\tR\x11pipelineTriggerId\x12\x1f\n\x0bpipeline_id\x18\x03 \x01(\tR\npipelineId\x12!\n\x0cpipeline_uid\x18\x04 \x01(\tR\x0bpipelineUid\x12\x39\n\x0ctrigger_mode\x18\x05 \x01(\x0e\x32\x16.core.mgmt.v1beta.ModeR\x0btriggerMode\x12\x38\n\x15\x63ompute_time_duration\x18\x06 \x01(\x02\x42\x04\xe2\x41\x01\x03R\x13\x63omputeTimeDuration\x12\x36\n\x06status\x18\x07 \x01(\x0e\x32\x18.core.mgmt.v1beta.StatusB\x04\xe2\x41\x01\x03R\x06status\x12\x34\n\x13pipeline_release_id\x18\x08 \x01(\tB\x04\xe2\x41\x01\x03R\x11pipelineReleaseId\x12\x36\n\x14pipeline_release_uid\x18\t \x01(\tB\x04\xe2\x41\x01\x03R\x12pipelineReleaseUid\"\xc6\x02\n\x1aPipelineTriggerTableRecord\x12\x1f\n\x0bpipeline_id\x18\x01 \x01(\tR\npipelineId\x12!\n\x0cpipeline_uid\x18\x02 \x01(\tR\x0bpipelineUid\x12<\n\x17trigger_count_completed\x18\x03 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x15triggerCountCompleted\x12\x38\n\x15trigger_count_errored\x18\x04 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x13triggerCountErrored\x12\x34\n\x13pipeline_release_id\x18\x05 \x01(\tB\x04\xe2\x41\x01\x03R\x11pipelineReleaseId\x12\x36\n\x14pipeline_release_uid\x18\x06 \x01(\tB\x04\xe2\x41\x01\x03R\x12pipelineReleaseUid\"\xed\x03\n\x1aPipelineTriggerChartRecord\x12\x1f\n\x0bpipeline_id\x18\x01 \x01(\tR\npipelineId\x12!\n\x0cpipeline_uid\x18\x02 \x01(\tR\x0bpipelineUid\x12\x39\n\x0ctrigger_mode\x18\x03 \x01(\x0e\x32\x16.core.mgmt.v1beta.ModeR\x0btriggerMode\x12\x36\n\x06status\x18\x04 \x01(\x0e\x32\x18.core.mgmt.v1beta.StatusB\x04\xe2\x41\x01\x03R\x06status\x12\x43\n\x0ctime_buckets\x18\x05 \x03(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\x0btimeBuckets\x12+\n\x0etrigger_counts\x18\x06 \x03(\x05\x42\x04\xe2\x41\x01\x03R\rtriggerCounts\x12\x38\n\x15\x63ompute_time_duration\x18\x07 \x03(\x02\x42\x04\xe2\x41\x01\x03R\x13\x63omputeTimeDuration\x12\x34\n\x13pipeline_release_id\x18\x08 \x01(\tB\x04\xe2\x41\x01\x03R\x11pipelineReleaseId\x12\x36\n\x14pipeline_release_uid\x18\t \x01(\tB\x04\xe2\x41\x01\x03R\x12pipelineReleaseUid\"\xc0\x01\n!ListPipelineTriggerRecordsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12!\n\x06\x66ilter\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01H\x02R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\t\n\x07_filter\"\xce\x01\n\"ListPipelineTriggerRecordsResponse\x12\x61\n\x18pipeline_trigger_records\x18\x01 \x03(\x0b\x32\'.core.mgmt.v1beta.PipelineTriggerRecordR\x16pipelineTriggerRecords\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\xc5\x01\n&ListPipelineTriggerTableRecordsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12!\n\x06\x66ilter\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01H\x02R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\t\n\x07_filter\"\xe3\x01\n\'ListPipelineTriggerTableRecordsResponse\x12q\n\x1epipeline_trigger_table_records\x18\x01 \x03(\x0b\x32,.core.mgmt.v1beta.PipelineTriggerTableRecordR\x1bpipelineTriggerTableRecords\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\x85\x01\n&ListPipelineTriggerChartRecordsRequest\x12-\n\x12\x61ggregation_window\x18\x01 \x01(\x05R\x11\x61ggregationWindow\x12!\n\x06\x66ilter\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x00R\x06\x66ilter\x88\x01\x01\x42\t\n\x07_filter\"\x9c\x01\n\'ListPipelineTriggerChartRecordsResponse\x12q\n\x1epipeline_trigger_chart_records\x18\x01 \x03(\x0b\x32,.core.mgmt.v1beta.PipelineTriggerChartRecordR\x1bpipelineTriggerChartRecords\"\xf1\x03\n\x16\x43onnectorExecuteRecord\x12=\n\x0c\x65xecute_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x65xecuteTime\x12\x30\n\x14\x63onnector_execute_id\x18\x02 \x01(\tR\x12\x63onnectorExecuteId\x12!\n\x0c\x63onnector_id\x18\x03 \x01(\tR\x0b\x63onnectorId\x12#\n\rconnector_uid\x18\x04 \x01(\tR\x0c\x63onnectorUid\x12\x38\n\x18\x63onnector_definition_uid\x18\x05 \x01(\tR\x16\x63onnectorDefinitionUid\x12\x1f\n\x0bpipeline_id\x18\x06 \x01(\tR\npipelineId\x12!\n\x0cpipeline_uid\x18\x07 \x01(\tR\x0bpipelineUid\x12.\n\x13pipeline_trigger_id\x18\x08 \x01(\tR\x11pipelineTriggerId\x12\x38\n\x15\x63ompute_time_duration\x18\t \x01(\x02\x42\x04\xe2\x41\x01\x03R\x13\x63omputeTimeDuration\x12\x36\n\x06status\x18\n \x01(\x0e\x32\x18.core.mgmt.v1beta.StatusB\x04\xe2\x41\x01\x03R\x06status\"\xdd\x01\n\x1b\x43onnectorExecuteTableRecord\x12!\n\x0c\x63onnector_id\x18\x01 \x01(\tR\x0b\x63onnectorId\x12#\n\rconnector_uid\x18\x02 \x01(\tR\x0c\x63onnectorUid\x12<\n\x17\x65xecute_count_completed\x18\x03 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x15\x65xecuteCountCompleted\x12\x38\n\x15\x65xecute_count_errored\x18\x04 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x13\x65xecuteCountErrored\"\xc9\x02\n\x1b\x43onnectorExecuteChartRecord\x12!\n\x0c\x63onnector_id\x18\x01 \x01(\tR\x0b\x63onnectorId\x12#\n\rconnector_uid\x18\x02 \x01(\tR\x0c\x63onnectorUid\x12\x36\n\x06status\x18\x03 \x01(\x0e\x32\x18.core.mgmt.v1beta.StatusB\x04\xe2\x41\x01\x03R\x06status\x12\x43\n\x0ctime_buckets\x18\x04 \x03(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\x0btimeBuckets\x12+\n\x0e\x65xecute_counts\x18\x05 \x03(\x05\x42\x04\xe2\x41\x01\x03R\rexecuteCounts\x12\x38\n\x15\x63ompute_time_duration\x18\x06 \x03(\x02\x42\x04\xe2\x41\x01\x03R\x13\x63omputeTimeDuration\"\xc1\x01\n\"ListConnectorExecuteRecordsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12!\n\x06\x66ilter\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01H\x02R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\t\n\x07_filter\"\xd2\x01\n#ListConnectorExecuteRecordsResponse\x12\x64\n\x19\x63onnector_execute_records\x18\x01 \x03(\x0b\x32(.core.mgmt.v1beta.ConnectorExecuteRecordR\x17\x63onnectorExecuteRecords\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\xc6\x01\n\'ListConnectorExecuteTableRecordsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12!\n\x06\x66ilter\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01H\x02R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\t\n\x07_filter\"\xe7\x01\n(ListConnectorExecuteTableRecordsResponse\x12t\n\x1f\x63onnector_execute_table_records\x18\x01 \x03(\x0b\x32-.core.mgmt.v1beta.ConnectorExecuteTableRecordR\x1c\x63onnectorExecuteTableRecords\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\x86\x01\n\'ListConnectorExecuteChartRecordsRequest\x12-\n\x12\x61ggregation_window\x18\x01 \x01(\x05R\x11\x61ggregationWindow\x12!\n\x06\x66ilter\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x00R\x06\x66ilter\x88\x01\x01\x42\t\n\x07_filter\"\xa0\x01\n(ListConnectorExecuteChartRecordsResponse\x12t\n\x1f\x63onnector_execute_chart_records\x18\x01 \x03(\x0b\x32-.core.mgmt.v1beta.ConnectorExecuteChartRecordR\x1c\x63onnectorExecuteChartRecords*;\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\r\n\tMODE_SYNC\x10\x01\x12\x0e\n\nMODE_ASYNC\x10\x02*J\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x14\n\x10STATUS_COMPLETED\x10\x01\x12\x12\n\x0eSTATUS_ERRORED\x10\x02\x42\xc4\x01\n\x14\x63om.core.mgmt.v1betaB\x0bMetricProtoP\x01Z=github.com/instill-ai/protogen-go/core/mgmt/v1beta;mgmtv1beta\xa2\x02\x03\x43MX\xaa\x02\x10\x43ore.Mgmt.V1beta\xca\x02\x10\x43ore\\Mgmt\\V1beta\xe2\x02\x1c\x43ore\\Mgmt\\V1beta\\GPBMetadata\xea\x02\x12\x43ore::Mgmt::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core.mgmt.v1beta.metric_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024com.core.mgmt.v1betaB\013MetricProtoP\001Z=github.com/instill-ai/protogen-go/core/mgmt/v1beta;mgmtv1beta\242\002\003CMX\252\002\020Core.Mgmt.V1beta\312\002\020Core\\Mgmt\\V1beta\342\002\034Core\\Mgmt\\V1beta\\GPBMetadata\352\002\022Core::Mgmt::V1beta'
  _PIPELINETRIGGERRECORD.fields_by_name['compute_time_duration']._options = None
  _PIPELINETRIGGERRECORD.fields_by_name['compute_time_duration']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERRECORD.fields_by_name['status']._options = None
  _PIPELINETRIGGERRECORD.fields_by_name['status']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERRECORD.fields_by_name['pipeline_release_id']._options = None
  _PIPELINETRIGGERRECORD.fields_by_name['pipeline_release_id']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERRECORD.fields_by_name['pipeline_release_uid']._options = None
  _PIPELINETRIGGERRECORD.fields_by_name['pipeline_release_uid']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERTABLERECORD.fields_by_name['trigger_count_completed']._options = None
  _PIPELINETRIGGERTABLERECORD.fields_by_name['trigger_count_completed']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERTABLERECORD.fields_by_name['trigger_count_errored']._options = None
  _PIPELINETRIGGERTABLERECORD.fields_by_name['trigger_count_errored']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERTABLERECORD.fields_by_name['pipeline_release_id']._options = None
  _PIPELINETRIGGERTABLERECORD.fields_by_name['pipeline_release_id']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERTABLERECORD.fields_by_name['pipeline_release_uid']._options = None
  _PIPELINETRIGGERTABLERECORD.fields_by_name['pipeline_release_uid']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['status']._options = None
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['status']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['time_buckets']._options = None
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['time_buckets']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['trigger_counts']._options = None
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['trigger_counts']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['compute_time_duration']._options = None
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['compute_time_duration']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['pipeline_release_id']._options = None
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['pipeline_release_id']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['pipeline_release_uid']._options = None
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['pipeline_release_uid']._serialized_options = b'\342A\001\003'
  _LISTPIPELINETRIGGERRECORDSREQUEST.fields_by_name['page_size']._options = None
  _LISTPIPELINETRIGGERRECORDSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTPIPELINETRIGGERRECORDSREQUEST.fields_by_name['page_token']._options = None
  _LISTPIPELINETRIGGERRECORDSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTPIPELINETRIGGERRECORDSREQUEST.fields_by_name['filter']._options = None
  _LISTPIPELINETRIGGERRECORDSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTPIPELINETRIGGERTABLERECORDSREQUEST.fields_by_name['page_size']._options = None
  _LISTPIPELINETRIGGERTABLERECORDSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTPIPELINETRIGGERTABLERECORDSREQUEST.fields_by_name['page_token']._options = None
  _LISTPIPELINETRIGGERTABLERECORDSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTPIPELINETRIGGERTABLERECORDSREQUEST.fields_by_name['filter']._options = None
  _LISTPIPELINETRIGGERTABLERECORDSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTPIPELINETRIGGERCHARTRECORDSREQUEST.fields_by_name['filter']._options = None
  _LISTPIPELINETRIGGERCHARTRECORDSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _CONNECTOREXECUTERECORD.fields_by_name['compute_time_duration']._options = None
  _CONNECTOREXECUTERECORD.fields_by_name['compute_time_duration']._serialized_options = b'\342A\001\003'
  _CONNECTOREXECUTERECORD.fields_by_name['status']._options = None
  _CONNECTOREXECUTERECORD.fields_by_name['status']._serialized_options = b'\342A\001\003'
  _CONNECTOREXECUTETABLERECORD.fields_by_name['execute_count_completed']._options = None
  _CONNECTOREXECUTETABLERECORD.fields_by_name['execute_count_completed']._serialized_options = b'\342A\001\003'
  _CONNECTOREXECUTETABLERECORD.fields_by_name['execute_count_errored']._options = None
  _CONNECTOREXECUTETABLERECORD.fields_by_name['execute_count_errored']._serialized_options = b'\342A\001\003'
  _CONNECTOREXECUTECHARTRECORD.fields_by_name['status']._options = None
  _CONNECTOREXECUTECHARTRECORD.fields_by_name['status']._serialized_options = b'\342A\001\003'
  _CONNECTOREXECUTECHARTRECORD.fields_by_name['time_buckets']._options = None
  _CONNECTOREXECUTECHARTRECORD.fields_by_name['time_buckets']._serialized_options = b'\342A\001\003'
  _CONNECTOREXECUTECHARTRECORD.fields_by_name['execute_counts']._options = None
  _CONNECTOREXECUTECHARTRECORD.fields_by_name['execute_counts']._serialized_options = b'\342A\001\003'
  _CONNECTOREXECUTECHARTRECORD.fields_by_name['compute_time_duration']._options = None
  _CONNECTOREXECUTECHARTRECORD.fields_by_name['compute_time_duration']._serialized_options = b'\342A\001\003'
  _LISTCONNECTOREXECUTERECORDSREQUEST.fields_by_name['page_size']._options = None
  _LISTCONNECTOREXECUTERECORDSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTCONNECTOREXECUTERECORDSREQUEST.fields_by_name['page_token']._options = None
  _LISTCONNECTOREXECUTERECORDSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTCONNECTOREXECUTERECORDSREQUEST.fields_by_name['filter']._options = None
  _LISTCONNECTOREXECUTERECORDSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTCONNECTOREXECUTETABLERECORDSREQUEST.fields_by_name['page_size']._options = None
  _LISTCONNECTOREXECUTETABLERECORDSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTCONNECTOREXECUTETABLERECORDSREQUEST.fields_by_name['page_token']._options = None
  _LISTCONNECTOREXECUTETABLERECORDSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTCONNECTOREXECUTETABLERECORDSREQUEST.fields_by_name['filter']._options = None
  _LISTCONNECTOREXECUTETABLERECORDSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTCONNECTOREXECUTECHARTRECORDSREQUEST.fields_by_name['filter']._options = None
  _LISTCONNECTOREXECUTECHARTRECORDSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_MODE']._serialized_start=4759
  _globals['_MODE']._serialized_end=4818
  _globals['_STATUS']._serialized_start=4820
  _globals['_STATUS']._serialized_end=4894
  _globals['_PIPELINETRIGGERRECORD']._serialized_start=118
  _globals['_PIPELINETRIGGERRECORD']._serialized_end=603
  _globals['_PIPELINETRIGGERTABLERECORD']._serialized_start=606
  _globals['_PIPELINETRIGGERTABLERECORD']._serialized_end=932
  _globals['_PIPELINETRIGGERCHARTRECORD']._serialized_start=935
  _globals['_PIPELINETRIGGERCHARTRECORD']._serialized_end=1428
  _globals['_LISTPIPELINETRIGGERRECORDSREQUEST']._serialized_start=1431
  _globals['_LISTPIPELINETRIGGERRECORDSREQUEST']._serialized_end=1623
  _globals['_LISTPIPELINETRIGGERRECORDSRESPONSE']._serialized_start=1626
  _globals['_LISTPIPELINETRIGGERRECORDSRESPONSE']._serialized_end=1832
  _globals['_LISTPIPELINETRIGGERTABLERECORDSREQUEST']._serialized_start=1835
  _globals['_LISTPIPELINETRIGGERTABLERECORDSREQUEST']._serialized_end=2032
  _globals['_LISTPIPELINETRIGGERTABLERECORDSRESPONSE']._serialized_start=2035
  _globals['_LISTPIPELINETRIGGERTABLERECORDSRESPONSE']._serialized_end=2262
  _globals['_LISTPIPELINETRIGGERCHARTRECORDSREQUEST']._serialized_start=2265
  _globals['_LISTPIPELINETRIGGERCHARTRECORDSREQUEST']._serialized_end=2398
  _globals['_LISTPIPELINETRIGGERCHARTRECORDSRESPONSE']._serialized_start=2401
  _globals['_LISTPIPELINETRIGGERCHARTRECORDSRESPONSE']._serialized_end=2557
  _globals['_CONNECTOREXECUTERECORD']._serialized_start=2560
  _globals['_CONNECTOREXECUTERECORD']._serialized_end=3057
  _globals['_CONNECTOREXECUTETABLERECORD']._serialized_start=3060
  _globals['_CONNECTOREXECUTETABLERECORD']._serialized_end=3281
  _globals['_CONNECTOREXECUTECHARTRECORD']._serialized_start=3284
  _globals['_CONNECTOREXECUTECHARTRECORD']._serialized_end=3613
  _globals['_LISTCONNECTOREXECUTERECORDSREQUEST']._serialized_start=3616
  _globals['_LISTCONNECTOREXECUTERECORDSREQUEST']._serialized_end=3809
  _globals['_LISTCONNECTOREXECUTERECORDSRESPONSE']._serialized_start=3812
  _globals['_LISTCONNECTOREXECUTERECORDSRESPONSE']._serialized_end=4022
  _globals['_LISTCONNECTOREXECUTETABLERECORDSREQUEST']._serialized_start=4025
  _globals['_LISTCONNECTOREXECUTETABLERECORDSREQUEST']._serialized_end=4223
  _globals['_LISTCONNECTOREXECUTETABLERECORDSRESPONSE']._serialized_start=4226
  _globals['_LISTCONNECTOREXECUTETABLERECORDSRESPONSE']._serialized_end=4457
  _globals['_LISTCONNECTOREXECUTECHARTRECORDSREQUEST']._serialized_start=4460
  _globals['_LISTCONNECTOREXECUTECHARTRECORDSREQUEST']._serialized_end=4594
  _globals['_LISTCONNECTOREXECUTECHARTRECORDSRESPONSE']._serialized_start=4597
  _globals['_LISTCONNECTOREXECUTECHARTRECORDSRESPONSE']._serialized_end=4757
# @@protoc_insertion_point(module_scope)
