# generated by datamodel-codegen:
#   filename:  website_task_scrape_website_input.json

from __future__ import annotations

from dataclasses import dataclass
from typing import List, Optional


@dataclass
class Input:
    max_k: int
    target_url: str
    allowed_domains: Optional[List[str]] = None
    include_link_html: Optional[bool] = False
    include_link_text: Optional[bool] = False
