# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vdp/pipeline/v1beta/pipeline_private_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from vdp.pipeline.v1beta import connector_pb2 as vdp_dot_pipeline_dot_v1beta_dot_connector__pb2
from vdp.pipeline.v1beta import connector_definition_pb2 as vdp_dot_pipeline_dot_v1beta_dot_connector__definition__pb2
from vdp.pipeline.v1beta import operator_definition_pb2 as vdp_dot_pipeline_dot_v1beta_dot_operator__definition__pb2
from vdp.pipeline.v1beta import pipeline_pb2 as vdp_dot_pipeline_dot_v1beta_dot_pipeline__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2vdp/pipeline/v1beta/pipeline_private_service.proto\x12\x13vdp.pipeline.v1beta\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1bgoogle/api/visibility.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a#vdp/pipeline/v1beta/connector.proto\x1a.vdp/pipeline/v1beta/connector_definition.proto\x1a-vdp/pipeline/v1beta/operator_definition.proto\x1a\"vdp/pipeline/v1beta/pipeline.proto2\xc2\x0c\n\x16PipelinePrivateService\x12\x96\x01\n\x12ListPipelinesAdmin\x12..vdp.pipeline.v1beta.ListPipelinesAdminRequest\x1a/.vdp.pipeline.v1beta.ListPipelinesAdminResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1beta/admin/pipelines\x12\xba\x01\n\x13LookUpPipelineAdmin\x12/.vdp.pipeline.v1beta.LookUpPipelineAdminRequest\x1a\x30.vdp.pipeline.v1beta.LookUpPipelineAdminResponse\"@\xda\x41\tpermalink\x82\xd3\xe4\x93\x02.\x12,/v1beta/admin/{permalink=pipelines/*}/lookUp\x12\xe3\x01\n\x1dLookUpOperatorDefinitionAdmin\x12\x39.vdp.pipeline.v1beta.LookUpOperatorDefinitionAdminRequest\x1a:.vdp.pipeline.v1beta.LookUpOperatorDefinitionAdminResponse\"K\xda\x41\tpermalink\x82\xd3\xe4\x93\x02\x39\x12\x37/v1beta/admin/{permalink=operator-definitions/*}/lookUp\x12\xaa\x01\n\x19ListPipelineReleasesAdmin\x12\x35.vdp.pipeline.v1beta.ListPipelineReleasesAdminRequest\x1a\x36.vdp.pipeline.v1beta.ListPipelineReleasesAdminResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/v1beta/admin/releases\x12\xe7\x01\n\x1eLookUpConnectorDefinitionAdmin\x12:.vdp.pipeline.v1beta.LookUpConnectorDefinitionAdminRequest\x1a;.vdp.pipeline.v1beta.LookUpConnectorDefinitionAdminResponse\"L\xda\x41\tpermalink\x82\xd3\xe4\x93\x02:\x12\x38/v1beta/admin/{permalink=connector-definitions/*}/lookUp\x12\x9a\x01\n\x13ListConnectorsAdmin\x12/.vdp.pipeline.v1beta.ListConnectorsAdminRequest\x1a\x30.vdp.pipeline.v1beta.ListConnectorsAdminResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1beta/admin/connectors\x12\xbe\x01\n\x14LookUpConnectorAdmin\x12\x30.vdp.pipeline.v1beta.LookUpConnectorAdminRequest\x1a\x31.vdp.pipeline.v1beta.LookUpConnectorAdminResponse\"A\xda\x41\tpermalink\x82\xd3\xe4\x93\x02/\x12-/v1beta/admin/{permalink=connectors/*}/lookUp\x12\xab\x01\n\x0e\x43heckConnector\x12*.vdp.pipeline.v1beta.CheckConnectorRequest\x1a+.vdp.pipeline.v1beta.CheckConnectorResponse\"@\xda\x41\tpermalink\x82\xd3\xe4\x93\x02.\x12,/v1beta/admin/{permalink=connectors/*}/check\x1aI\x92\x41\x36\x12\x34Private methods to interact with Pipeline resources.\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNALB\xea\x01\n\x17\x63om.vdp.pipeline.v1betaB\x1bPipelinePrivateServiceProtoP\x01ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\xa2\x02\x03VPX\xaa\x02\x13Vdp.Pipeline.V1beta\xca\x02\x13Vdp\\Pipeline\\V1beta\xe2\x02\x1fVdp\\Pipeline\\V1beta\\GPBMetadata\xea\x02\x15Vdp::Pipeline::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vdp.pipeline.v1beta.pipeline_private_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.vdp.pipeline.v1betaB\033PipelinePrivateServiceProtoP\001ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\242\002\003VPX\252\002\023Vdp.Pipeline.V1beta\312\002\023Vdp\\Pipeline\\V1beta\342\002\037Vdp\\Pipeline\\V1beta\\GPBMetadata\352\002\025Vdp::Pipeline::V1beta'
  _PIPELINEPRIVATESERVICE._options = None
  _PIPELINEPRIVATESERVICE._serialized_options = b'\222A6\0224Private methods to interact with Pipeline resources.\372\322\344\223\002\n\022\010INTERNAL'
  _PIPELINEPRIVATESERVICE.methods_by_name['ListPipelinesAdmin']._options = None
  _PIPELINEPRIVATESERVICE.methods_by_name['ListPipelinesAdmin']._serialized_options = b'\202\323\344\223\002\031\022\027/v1beta/admin/pipelines'
  _PIPELINEPRIVATESERVICE.methods_by_name['LookUpPipelineAdmin']._options = None
  _PIPELINEPRIVATESERVICE.methods_by_name['LookUpPipelineAdmin']._serialized_options = b'\332A\tpermalink\202\323\344\223\002.\022,/v1beta/admin/{permalink=pipelines/*}/lookUp'
  _PIPELINEPRIVATESERVICE.methods_by_name['LookUpOperatorDefinitionAdmin']._options = None
  _PIPELINEPRIVATESERVICE.methods_by_name['LookUpOperatorDefinitionAdmin']._serialized_options = b'\332A\tpermalink\202\323\344\223\0029\0227/v1beta/admin/{permalink=operator-definitions/*}/lookUp'
  _PIPELINEPRIVATESERVICE.methods_by_name['ListPipelineReleasesAdmin']._options = None
  _PIPELINEPRIVATESERVICE.methods_by_name['ListPipelineReleasesAdmin']._serialized_options = b'\202\323\344\223\002\030\022\026/v1beta/admin/releases'
  _PIPELINEPRIVATESERVICE.methods_by_name['LookUpConnectorDefinitionAdmin']._options = None
  _PIPELINEPRIVATESERVICE.methods_by_name['LookUpConnectorDefinitionAdmin']._serialized_options = b'\332A\tpermalink\202\323\344\223\002:\0228/v1beta/admin/{permalink=connector-definitions/*}/lookUp'
  _PIPELINEPRIVATESERVICE.methods_by_name['ListConnectorsAdmin']._options = None
  _PIPELINEPRIVATESERVICE.methods_by_name['ListConnectorsAdmin']._serialized_options = b'\202\323\344\223\002\032\022\030/v1beta/admin/connectors'
  _PIPELINEPRIVATESERVICE.methods_by_name['LookUpConnectorAdmin']._options = None
  _PIPELINEPRIVATESERVICE.methods_by_name['LookUpConnectorAdmin']._serialized_options = b'\332A\tpermalink\202\323\344\223\002/\022-/v1beta/admin/{permalink=connectors/*}/lookUp'
  _PIPELINEPRIVATESERVICE.methods_by_name['CheckConnector']._options = None
  _PIPELINEPRIVATESERVICE.methods_by_name['CheckConnector']._serialized_options = b'\332A\tpermalink\202\323\344\223\002.\022,/v1beta/admin/{permalink=connectors/*}/check'
  _globals['_PIPELINEPRIVATESERVICE']._serialized_start=376
  _globals['_PIPELINEPRIVATESERVICE']._serialized_end=1978
# @@protoc_insertion_point(module_scope)
