# generated by datamodel-codegen:
#   filename:  image_task_draw_classification_output.json

from __future__ import annotations

from dataclasses import dataclass


@dataclass
class Output:
    image: str
