# generated by datamodel-codegen:
#   filename:  huggingface_task_fill_mask_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import List, Optional


@dataclass
class Result:
    score: Optional[float] = None
    sequence: Optional[str] = None
    token: Optional[int] = None
    token_str: Optional[str] = None


@dataclass
class Output:
    results: List[Result]
