# generated by datamodel-codegen:
#   filename:  huggingface_task_table_question_answering_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import List, Optional


@dataclass
class Output:
    answer: str
    aggregator: Optional[str] = None
    cells: Optional[List[str]] = None
    coordinates: Optional[List[List[int]]] = None
