# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core/mgmt/v1beta/mgmt_public_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from core.mgmt.v1beta import metric_pb2 as core_dot_mgmt_dot_v1beta_dot_metric__pb2
from core.mgmt.v1beta import mgmt_pb2 as core_dot_mgmt_dot_v1beta_dot_mgmt__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*core/mgmt/v1beta/mgmt_public_service.proto\x12\x10\x63ore.mgmt.v1beta\x1a\x1d\x63ore/mgmt/v1beta/metric.proto\x1a\x1b\x63ore/mgmt/v1beta/mgmt.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1bgoogle/api/visibility.proto\x1a.protoc-gen-openapiv2/options/annotations.proto2\xe0\x35\n\x11MgmtPublicService\x12\xca\x01\n\x1c\x44\x65leteOrganizationMembership\x12\x35.core.mgmt.v1beta.DeleteOrganizationMembershipRequest\x1a\x36.core.mgmt.v1beta.DeleteOrganizationMembershipResponse\";\xda\x41\x04name\x82\xd3\xe4\x93\x02.*,/v1beta/{name=organizations/*/memberships/*}\x12\x94\x01\n\x08Liveness\x12!.core.mgmt.v1beta.LivenessRequest\x1a\".core.mgmt.v1beta.LivenessResponse\"A\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02+\x12\x12/v1beta/__livenessZ\x15\x12\x13/v1beta/health/mgmt\x12\x97\x01\n\tReadiness\x12\".core.mgmt.v1beta.ReadinessRequest\x1a#.core.mgmt.v1beta.ReadinessResponse\"A\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02+\x12\x13/v1beta/__readinessZ\x14\x12\x12/v1beta/ready/mgmt\x12\xa3\x01\n\x0e\x43heckNamespace\x12\'.core.mgmt.v1beta.CheckNamespaceRequest\x1a(.core.mgmt.v1beta.CheckNamespaceResponse\">\xda\x41\tnamespace\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x1c\"\x17/v1beta/check-namespace:\x01*\x12\x9e\x01\n\x14GetAuthenticatedUser\x12-.core.mgmt.v1beta.GetAuthenticatedUserRequest\x1a..core.mgmt.v1beta.GetAuthenticatedUserResponse\"\'\xda\x41\x10user,update_mask\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1beta/user\x12\xaa\x01\n\x16PatchAuthenticatedUser\x12/.core.mgmt.v1beta.PatchAuthenticatedUserRequest\x1a\x30.core.mgmt.v1beta.PatchAuthenticatedUserResponse\"-\xda\x41\x10user,update_mask\x82\xd3\xe4\x93\x02\x14\x32\x0c/v1beta/user:\x04user\x12k\n\tListUsers\x12\".core.mgmt.v1beta.ListUsersRequest\x1a#.core.mgmt.v1beta.ListUsersResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/v1beta/users\x12\x85\x01\n\x07GetUser\x12 .core.mgmt.v1beta.GetUserRequest\x1a!.core.mgmt.v1beta.GetUserResponse\"5\xda\x41\x04name\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x18\x12\x16/v1beta/{name=users/*}\x12\xb9\x01\n\x13ListUserMemberships\x12,.core.mgmt.v1beta.ListUserMembershipsRequest\x1a-.core.mgmt.v1beta.ListUserMembershipsResponse\"E\xda\x41\x06parent\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02&\x12$/v1beta/{parent=users/*}/memberships\x12\xb1\x01\n\x11GetUserMembership\x12*.core.mgmt.v1beta.GetUserMembershipRequest\x1a+.core.mgmt.v1beta.GetUserMembershipResponse\"C\xda\x41\x04name\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02&\x12$/v1beta/{name=users/*/memberships/*}\x12\xe3\x01\n\x14UpdateUserMembership\x12-.core.mgmt.v1beta.UpdateUserMembershipRequest\x1a..core.mgmt.v1beta.UpdateUserMembershipResponse\"l\xda\x41\x16membership,update_mask\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02=\x1a//v1beta/{membership.name=users/*/memberships/*}:\nmembership\x12\xaa\x01\n\x14\x44\x65leteUserMembership\x12-.core.mgmt.v1beta.DeleteUserMembershipRequest\x1a..core.mgmt.v1beta.DeleteUserMembershipResponse\"3\xda\x41\x04name\x82\xd3\xe4\x93\x02&*$/v1beta/{name=users/*/memberships/*}\x12\x9b\x01\n\x11ListOrganizations\x12*.core.mgmt.v1beta.ListOrganizationsRequest\x1a+.core.mgmt.v1beta.ListOrganizationsResponse\"-\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x17\x12\x15/v1beta/organizations\x12\xbb\x01\n\x12\x43reateOrganization\x12+.core.mgmt.v1beta.CreateOrganizationRequest\x1a,.core.mgmt.v1beta.CreateOrganizationResponse\"J\xda\x41\x0corganization\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02%\"\x15/v1beta/organizations:\x0corganization\x12\xa5\x01\n\x0fGetOrganization\x12(.core.mgmt.v1beta.GetOrganizationRequest\x1a).core.mgmt.v1beta.GetOrganizationResponse\"=\xda\x41\x04name\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02 \x12\x1e/v1beta/{name=organizations/*}\x12\xdd\x01\n\x12UpdateOrganization\x12+.core.mgmt.v1beta.UpdateOrganizationRequest\x1a,.core.mgmt.v1beta.UpdateOrganizationResponse\"l\xda\x41\x18organization,update_mask\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02;2+/v1beta/{organization.name=organizations/*}:\x0corganization\x12\xae\x01\n\x12\x44\x65leteOrganization\x12+.core.mgmt.v1beta.DeleteOrganizationRequest\x1a,.core.mgmt.v1beta.DeleteOrganizationResponse\"=\xda\x41\x04name\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02 *\x1e/v1beta/{name=organizations/*}\x12\xd9\x01\n\x1bListOrganizationMemberships\x12\x34.core.mgmt.v1beta.ListOrganizationMembershipsRequest\x1a\x35.core.mgmt.v1beta.ListOrganizationMembershipsResponse\"M\xda\x41\x06parent\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02.\x12,/v1beta/{parent=organizations/*}/memberships\x12\xd1\x01\n\x19GetOrganizationMembership\x12\x32.core.mgmt.v1beta.GetOrganizationMembershipRequest\x1a\x33.core.mgmt.v1beta.GetOrganizationMembershipResponse\"K\xda\x41\x04name\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02.\x12,/v1beta/{name=organizations/*/memberships/*}\x12\x83\x02\n\x1cUpdateOrganizationMembership\x12\x35.core.mgmt.v1beta.UpdateOrganizationMembershipRequest\x1a\x36.core.mgmt.v1beta.UpdateOrganizationMembershipResponse\"t\xda\x41\x16membership,update_mask\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x45\x1a\x37/v1beta/{membership.name=organizations/*/memberships/*}:\nmembership\x12\xcc\x01\n GetAuthenticatedUserSubscription\x12\x39.core.mgmt.v1beta.GetAuthenticatedUserSubscriptionRequest\x1a:.core.mgmt.v1beta.GetAuthenticatedUserSubscriptionResponse\"1\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1beta/user/subscription\x12\xda\x01\n\x1bGetOrganizationSubscription\x12\x34.core.mgmt.v1beta.GetOrganizationSubscriptionRequest\x1a\x35.core.mgmt.v1beta.GetOrganizationSubscriptionResponse\"N\xda\x41\x06parent\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02/\x12-/v1beta/{parent=organizations/*}/subscription\x12\x91\x01\n\x0b\x43reateToken\x12$.core.mgmt.v1beta.CreateTokenRequest\x1a%.core.mgmt.v1beta.CreateTokenResponse\"5\xda\x41\x05token\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x17\"\x0e/v1beta/tokens:\x05token\x12\x7f\n\nListTokens\x12#.core.mgmt.v1beta.ListTokensRequest\x1a$.core.mgmt.v1beta.ListTokensResponse\"&\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x10\x12\x0e/v1beta/tokens\x12\x89\x01\n\x08GetToken\x12!.core.mgmt.v1beta.GetTokenRequest\x1a\".core.mgmt.v1beta.GetTokenResponse\"6\xda\x41\x04name\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x19\x12\x17/v1beta/{name=tokens/*}\x12\x92\x01\n\x0b\x44\x65leteToken\x12$.core.mgmt.v1beta.DeleteTokenRequest\x1a%.core.mgmt.v1beta.DeleteTokenResponse\"6\xda\x41\x04name\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x19*\x17/v1beta/{name=tokens/*}\x12\x90\x01\n\rValidateToken\x12&.core.mgmt.v1beta.ValidateTokenRequest\x1a\'.core.mgmt.v1beta.ValidateTokenResponse\".\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x18\"\x16/v1beta/validate_token\x12\xc6\x01\n\x1aListPipelineTriggerRecords\x12\x33.core.mgmt.v1beta.ListPipelineTriggerRecordsRequest\x1a\x34.core.mgmt.v1beta.ListPipelineTriggerRecordsResponse\"=\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\'\x12%/v1beta/metrics/vdp/pipeline/triggers\x12\xd3\x01\n\x1fListPipelineTriggerTableRecords\x12\x38.core.mgmt.v1beta.ListPipelineTriggerTableRecordsRequest\x1a\x39.core.mgmt.v1beta.ListPipelineTriggerTableRecordsResponse\";\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02%\x12#/v1beta/metrics/vdp/pipeline/tables\x12\xd3\x01\n\x1fListPipelineTriggerChartRecords\x12\x38.core.mgmt.v1beta.ListPipelineTriggerChartRecordsRequest\x1a\x39.core.mgmt.v1beta.ListPipelineTriggerChartRecordsResponse\";\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02%\x12#/v1beta/metrics/vdp/pipeline/charts\x12\xca\x01\n\x1bListConnectorExecuteRecords\x12\x34.core.mgmt.v1beta.ListConnectorExecuteRecordsRequest\x1a\x35.core.mgmt.v1beta.ListConnectorExecuteRecordsResponse\">\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02(\x12&/v1beta/metrics/vdp/connector/executes\x12\xd7\x01\n ListConnectorExecuteTableRecords\x12\x39.core.mgmt.v1beta.ListConnectorExecuteTableRecordsRequest\x1a:.core.mgmt.v1beta.ListConnectorExecuteTableRecordsResponse\"<\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02&\x12$/v1beta/metrics/vdp/connector/tables\x12\xd7\x01\n ListConnectorExecuteChartRecords\x12\x39.core.mgmt.v1beta.ListConnectorExecuteChartRecordsRequest\x1a:.core.mgmt.v1beta.ListConnectorExecuteChartRecordsResponse\"<\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02&\x12$/v1beta/metrics/vdp/connector/charts\x12\x9c\x01\n\x0f\x41uthTokenIssuer\x12(.core.mgmt.v1beta.AuthTokenIssuerRequest\x1a).core.mgmt.v1beta.AuthTokenIssuerResponse\"4\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x1e\"\x19/v1beta/auth/token_issuer:\x01*\x12\x80\x01\n\tAuthLogin\x12\".core.mgmt.v1beta.AuthLoginRequest\x1a#.core.mgmt.v1beta.AuthLoginResponse\"*\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x14\"\x12/v1beta/auth/login\x12\x84\x01\n\nAuthLogout\x12#.core.mgmt.v1beta.AuthLogoutRequest\x1a$.core.mgmt.v1beta.AuthLogoutResponse\"+\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x15\"\x13/v1beta/auth/logout\x12\xa8\x01\n\x12\x41uthChangePassword\x12+.core.mgmt.v1beta.AuthChangePasswordRequest\x1a,.core.mgmt.v1beta.AuthChangePasswordResponse\"7\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02!\"\x1c/v1beta/auth/change_password:\x01*\x12\xba\x01\n\x17\x41uthValidateAccessToken\x12\x30.core.mgmt.v1beta.AuthValidateAccessTokenRequest\x1a\x31.core.mgmt.v1beta.AuthValidateAccessTokenResponse\":\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02$\"\"/v1beta/auth/validate_access_token\x1a\x1a\x92\x41\x17\x12\x15Public Core endpointsB\xcf\x01\n\x14\x63om.core.mgmt.v1betaB\x16MgmtPublicServiceProtoP\x01Z=github.com/instill-ai/protogen-go/core/mgmt/v1beta;mgmtv1beta\xa2\x02\x03\x43MX\xaa\x02\x10\x43ore.Mgmt.V1beta\xca\x02\x10\x43ore\\Mgmt\\V1beta\xe2\x02\x1c\x43ore\\Mgmt\\V1beta\\GPBMetadata\xea\x02\x12\x43ore::Mgmt::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core.mgmt.v1beta.mgmt_public_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024com.core.mgmt.v1betaB\026MgmtPublicServiceProtoP\001Z=github.com/instill-ai/protogen-go/core/mgmt/v1beta;mgmtv1beta\242\002\003CMX\252\002\020Core.Mgmt.V1beta\312\002\020Core\\Mgmt\\V1beta\342\002\034Core\\Mgmt\\V1beta\\GPBMetadata\352\002\022Core::Mgmt::V1beta'
  _MGMTPUBLICSERVICE._options = None
  _MGMTPUBLICSERVICE._serialized_options = b'\222A\027\022\025Public Core endpoints'
  _MGMTPUBLICSERVICE.methods_by_name['DeleteOrganizationMembership']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['DeleteOrganizationMembership']._serialized_options = b'\332A\004name\202\323\344\223\002.*,/v1beta/{name=organizations/*/memberships/*}'
  _MGMTPUBLICSERVICE.methods_by_name['Liveness']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['Liveness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002+\022\022/v1beta/__livenessZ\025\022\023/v1beta/health/mgmt'
  _MGMTPUBLICSERVICE.methods_by_name['Readiness']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['Readiness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002+\022\023/v1beta/__readinessZ\024\022\022/v1beta/ready/mgmt'
  _MGMTPUBLICSERVICE.methods_by_name['CheckNamespace']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['CheckNamespace']._serialized_options = b'\332A\tnamespace\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\034\"\027/v1beta/check-namespace:\001*'
  _MGMTPUBLICSERVICE.methods_by_name['GetAuthenticatedUser']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetAuthenticatedUser']._serialized_options = b'\332A\020user,update_mask\202\323\344\223\002\016\022\014/v1beta/user'
  _MGMTPUBLICSERVICE.methods_by_name['PatchAuthenticatedUser']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['PatchAuthenticatedUser']._serialized_options = b'\332A\020user,update_mask\202\323\344\223\002\0242\014/v1beta/user:\004user'
  _MGMTPUBLICSERVICE.methods_by_name['ListUsers']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListUsers']._serialized_options = b'\202\323\344\223\002\017\022\r/v1beta/users'
  _MGMTPUBLICSERVICE.methods_by_name['GetUser']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetUser']._serialized_options = b'\332A\004name\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\030\022\026/v1beta/{name=users/*}'
  _MGMTPUBLICSERVICE.methods_by_name['ListUserMemberships']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListUserMemberships']._serialized_options = b'\332A\006parent\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002&\022$/v1beta/{parent=users/*}/memberships'
  _MGMTPUBLICSERVICE.methods_by_name['GetUserMembership']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetUserMembership']._serialized_options = b'\332A\004name\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002&\022$/v1beta/{name=users/*/memberships/*}'
  _MGMTPUBLICSERVICE.methods_by_name['UpdateUserMembership']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['UpdateUserMembership']._serialized_options = b'\332A\026membership,update_mask\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002=\032//v1beta/{membership.name=users/*/memberships/*}:\nmembership'
  _MGMTPUBLICSERVICE.methods_by_name['DeleteUserMembership']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['DeleteUserMembership']._serialized_options = b'\332A\004name\202\323\344\223\002&*$/v1beta/{name=users/*/memberships/*}'
  _MGMTPUBLICSERVICE.methods_by_name['ListOrganizations']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListOrganizations']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\027\022\025/v1beta/organizations'
  _MGMTPUBLICSERVICE.methods_by_name['CreateOrganization']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['CreateOrganization']._serialized_options = b'\332A\014organization\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002%\"\025/v1beta/organizations:\014organization'
  _MGMTPUBLICSERVICE.methods_by_name['GetOrganization']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetOrganization']._serialized_options = b'\332A\004name\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002 \022\036/v1beta/{name=organizations/*}'
  _MGMTPUBLICSERVICE.methods_by_name['UpdateOrganization']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['UpdateOrganization']._serialized_options = b'\332A\030organization,update_mask\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002;2+/v1beta/{organization.name=organizations/*}:\014organization'
  _MGMTPUBLICSERVICE.methods_by_name['DeleteOrganization']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['DeleteOrganization']._serialized_options = b'\332A\004name\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002 *\036/v1beta/{name=organizations/*}'
  _MGMTPUBLICSERVICE.methods_by_name['ListOrganizationMemberships']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListOrganizationMemberships']._serialized_options = b'\332A\006parent\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002.\022,/v1beta/{parent=organizations/*}/memberships'
  _MGMTPUBLICSERVICE.methods_by_name['GetOrganizationMembership']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetOrganizationMembership']._serialized_options = b'\332A\004name\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002.\022,/v1beta/{name=organizations/*/memberships/*}'
  _MGMTPUBLICSERVICE.methods_by_name['UpdateOrganizationMembership']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['UpdateOrganizationMembership']._serialized_options = b'\332A\026membership,update_mask\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002E\0327/v1beta/{membership.name=organizations/*/memberships/*}:\nmembership'
  _MGMTPUBLICSERVICE.methods_by_name['GetAuthenticatedUserSubscription']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetAuthenticatedUserSubscription']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\033\022\031/v1beta/user/subscription'
  _MGMTPUBLICSERVICE.methods_by_name['GetOrganizationSubscription']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetOrganizationSubscription']._serialized_options = b'\332A\006parent\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002/\022-/v1beta/{parent=organizations/*}/subscription'
  _MGMTPUBLICSERVICE.methods_by_name['CreateToken']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['CreateToken']._serialized_options = b'\332A\005token\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\027\"\016/v1beta/tokens:\005token'
  _MGMTPUBLICSERVICE.methods_by_name['ListTokens']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListTokens']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\020\022\016/v1beta/tokens'
  _MGMTPUBLICSERVICE.methods_by_name['GetToken']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetToken']._serialized_options = b'\332A\004name\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\031\022\027/v1beta/{name=tokens/*}'
  _MGMTPUBLICSERVICE.methods_by_name['DeleteToken']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['DeleteToken']._serialized_options = b'\332A\004name\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\031*\027/v1beta/{name=tokens/*}'
  _MGMTPUBLICSERVICE.methods_by_name['ValidateToken']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ValidateToken']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\030\"\026/v1beta/validate_token'
  _MGMTPUBLICSERVICE.methods_by_name['ListPipelineTriggerRecords']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListPipelineTriggerRecords']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\'\022%/v1beta/metrics/vdp/pipeline/triggers'
  _MGMTPUBLICSERVICE.methods_by_name['ListPipelineTriggerTableRecords']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListPipelineTriggerTableRecords']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002%\022#/v1beta/metrics/vdp/pipeline/tables'
  _MGMTPUBLICSERVICE.methods_by_name['ListPipelineTriggerChartRecords']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListPipelineTriggerChartRecords']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002%\022#/v1beta/metrics/vdp/pipeline/charts'
  _MGMTPUBLICSERVICE.methods_by_name['ListConnectorExecuteRecords']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListConnectorExecuteRecords']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002(\022&/v1beta/metrics/vdp/connector/executes'
  _MGMTPUBLICSERVICE.methods_by_name['ListConnectorExecuteTableRecords']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListConnectorExecuteTableRecords']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002&\022$/v1beta/metrics/vdp/connector/tables'
  _MGMTPUBLICSERVICE.methods_by_name['ListConnectorExecuteChartRecords']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListConnectorExecuteChartRecords']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002&\022$/v1beta/metrics/vdp/connector/charts'
  _MGMTPUBLICSERVICE.methods_by_name['AuthTokenIssuer']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['AuthTokenIssuer']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\036\"\031/v1beta/auth/token_issuer:\001*'
  _MGMTPUBLICSERVICE.methods_by_name['AuthLogin']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['AuthLogin']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\024\"\022/v1beta/auth/login'
  _MGMTPUBLICSERVICE.methods_by_name['AuthLogout']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['AuthLogout']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\025\"\023/v1beta/auth/logout'
  _MGMTPUBLICSERVICE.methods_by_name['AuthChangePassword']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['AuthChangePassword']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002!\"\034/v1beta/auth/change_password:\001*'
  _MGMTPUBLICSERVICE.methods_by_name['AuthValidateAccessToken']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['AuthValidateAccessToken']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002$\"\"/v1beta/auth/validate_access_token'
  _globals['_MGMTPUBLICSERVICE']._serialized_start=257
  _globals['_MGMTPUBLICSERVICE']._serialized_end=7137
# @@protoc_insertion_point(module_scope)
