# generated by datamodel-codegen:
#   filename:  googlecloudstorage_task_upload_input.json

from __future__ import annotations

from dataclasses import dataclass


@dataclass
class Input:
    data: str
    object_name: str
